<?php

namespace App\Http\Livewire\User;

use App\Models\User;
use App\Models\Deposit;
use Livewire\Component;
use Illuminate\Support\Str;
use App\Models\GeneralSetting;
use App\Models\GatewayCurrency;
use App\Models\AdminNotification;

class DepositComponent extends Component
{
    public $amount;
    public $method_code;
    public $methodId;
    public $tabId, $data;
    public $currency = 'USD', $selected_method;
    public $activeTab;
    public $msg = []; 

    public function mount()
    {
        $this->activeTab = 'tab1';
        $this->tabId = Str::uuid()->toString();
        $this->methodId = 1004;
    }
    public function render()
    {
        return view('livewire.user.deposit-component', [
            'methods' => GatewayCurrency::whereHas('method', function ($gate) {
                $gate->where('status', 1);
            })->with('method')->orderby('method_code')->get(),
        ]);
    }
    public function methodChanged($id)
    {
        $this->methodId = $id;
        $this->selected_method = GatewayCurrency::where('method_code', $this->methodId)->with('method')->first();
    }
    public function moveToSecound()
    {
        if ($this->method_code == "") {
            $this->msg['status'] = 'error';
            $this->msg['message'] = 'Please select a method';
            // $this->dispatchBrowserEvent('error', ['msg' => 'Please select a method']);
        } else {
            $this->reset('msg');
            $this->selected_method = GatewayCurrency::where('method_code', $this->methodId)->first();
            $this->activeTab = 'tab2';
        }
    }
    public function moveToThird()
    {

        $amount = User::currencyToUsd($this->amount);
        if ($this->method_code == "") {
            $this->msg['status'] = 'error';
            $this->msg['message'] = 'Please select a method';
            // $this->dispatchBrowserEvent('error', ['msg' => 'Please Select A Method']);
        } else if ($this->currency == "") {
            $this->msg['status'] = 'error';
            $this->msg['message'] = 'Please Select A Currency';
            // $this->dispatchBrowserEvent('error', ['msg' => 'Please Select A Currency']);
        } else {
            $user = auth()->user();
            $gate = GatewayCurrency::where('method_code', $this->method_code)->where('currency', $this->currency)->first();
            if (!$gate) {
                $this->msg['status'] = 'error';
                $this->msg['message'] = 'Invalid Gateway';
                // $this->dispatchBrowserEvent('error', ['msg' => 'Invalid Gateway']);
            } else if ($gate->min_amount > $amount || $gate->max_amount < $amount) {
                $this->msg['status'] = 'error';
                $this->msg['message'] = 'Please Follow Deposit Limit';
                // $this->dispatchBrowserEvent('error', ['msg' => 'Please Follow Deposit Limit']);
            } else {
                $charge = getAmount($gate->fixed_charge + ($amount * $gate->percent_charge / 100));
                $payable = getAmount($amount + $charge);
                $final_amo = getAmount($payable * $gate->rate);

                $data = new Deposit();
                $data->user_id = $user->id;
                $data->method_code = $gate->method_code;
                $data->method_currency = strtoupper($gate->currency);
                $data->amount = $amount;
                $data->charge = $charge;
                $data->rate = $gate->rate;
                $data->final_amo = getAmount($final_amo);
                $data->btc_amo = 0;
                $data->btc_wallet = "";
                $data->trx = getTrx();
                $data->try = 0;
                $data->status = 0;
                $data->save();
                session()->put('Track', $data['trx']);
                $this->data = $data;
                $this->activeTab = 'tab3';
            }
        }
    }
    public function depositConfirm()
    {
        $deposit = $this->data;
        if (is_null($deposit)) {
            $notify[] = ['error', 'Invalid Deposit Request'];
            return redirect()->route(gatewayRedirectUrl())->withNotify($notify);
        }
        if ($deposit->status != 0) {
            $notify[] = ['error', 'Invalid Deposit Request'];
            return redirect()->route(gatewayRedirectUrl())->withNotify($notify);
        }

        if ($deposit->method_code >= 1000) {
            $this->userDataUpdate($deposit);
            $notify[] = ['success', 'Your deposit request is queued for approval.'];
            return back()->withNotify($notify);
        }

        $dirName = $deposit->gateway->alias;
        $new = 'App\Http\Controllers\Gateway' . '\\' . $dirName . '\\ProcessController';
        $data = $new::process($deposit);
        $data = json_decode($data);
        if (isset($data->error)) {
            $notify[] = ['error', $data->msg];
            return redirect()->route(gatewayRedirectUrl())->withNotify($notify);
        }
        if (isset($data->redirect)) {
            return redirect($data->redirect_url);
        }

        // for Stripe V3
        if (@$data->session) {
            $deposit->btc_wallet = $data->session->id;
            $deposit->save();
        }
        $this->dispatchBrowserEvent('success', ['msg' => 'Deposit Done']);
    }
    public function depositManualConfirm()
    {
        $data = $this->data;
        if (!$data) {
            return redirect()->route(gatewayRedirectUrl());
        }
        if ($data->status != 0) {
            return redirect()->route(gatewayRedirectUrl());
        }
        if ($data->method_code > 999) {

            $method = $data->gateway_currency();
            return view('user.deposit-manual', compact('data', 'method'));
        }
        abort(404);
    }

    public function backToPrevious($position)
    {
        $this->activeTab = 'tab' . $position;
    }
}
