<?php

namespace App\Http\Livewire\User;

use App\Models\User;
use App\Mail\OtpMail;
use Livewire\Component;
use App\Models\Withdrawal;
use Illuminate\Support\Str;
use App\Models\WithdrawMethod;
use Illuminate\Support\Facades\Mail;
use Livewire\WithPagination;

class WithdrawComponent extends Component
{
    use WithPagination;
    protected $paginationTheme = 'bootstrap';
    public $methodId;
    public $amount;
    public $method;
    public $activeTab;
    public $tabId, $pin, $otp, $withdraw, $paymentid;
    public $msg = [];
    public function mount()
    {
        $this->methodId = 2;
        $this->activeTab = 'tab1';
        $this->tabId = Str::uuid()->toString();
    }
    public function render()
    {
        return view('livewire.user.withdraw-component', [
            'methods' => WithdrawMethod::whereStatus(1)->get(),
            'selectedMethod' => WithdrawMethod::where('id', $this->methodId)->first(),
            'history' => Withdrawal::where('user_id', auth()->user()->id)->latest()->paginate(5),
        ]);
    }
    public function methodChanged($id)
    {
        $this->methodId = $id;
    }
    public function store()
    {
        if ($this->method == "") {
            $this->msg['status'] = 'error';
            $this->msg['message'] = 'Please select a method';
            // $this->dispatchBrowserEvent('error', ['msg' => 'Please Select A Method']);
        }
        $method = WithdrawMethod::where('id', $this->method)->where('status', 1)->firstOrFail();
        $user = auth()->user();
        $amount = User::currencyToUsd($this->amount);
        if ($amount < $method->min_limit) {
            $this->msg['status'] = 'error';
            $this->msg['message'] = 'Your thised Amount is Smaller Than Minimum Amount.';
            // $this->dispatchBrowserEvent('error', ['msg' => 'Your thised Amount is Smaller Than Minimum Amount.']);
        } else if ($amount > $method->max_limit) {
            $this->msg['status'] = 'error';
            $this->msg['message'] = 'Your Requested Amount is Larger Than Maximum Amount.';
            // $this->dispatchBrowserEvent('error', ['msg' => 'Your Requested Amount is Larger Than Maximum Amount.']);
        } else if ($amount > $user->balance) {
            $this->msg['status'] = 'error';
            $this->msg['message'] = 'You do not have Sufficient Balance For Withdraw.';
            // $this->dispatchBrowserEvent('error', ['msg' => 'You do not have Sufficient Balance For Withdraw.']);
        } elseif ($this->pin != auth()->user()->personal_pin) {
            $this->msg['status'] = 'error';
            $this->msg['message'] = 'Your pin does not matched.';
        } else {
            $charge = $method->fixed_charge + ($amount * $method->percent_charge / 100);
            $afterCharge = $amount - $charge;
            $finalAmount = getAmount($afterCharge * $method->rate);

            $withdraw = new Withdrawal();
            $withdraw->method_id = $method->id; // wallet method ID
            $withdraw->user_id = $user->id;
            $withdraw->amount = getAmount($amount);
            $withdraw->currency = $method->currency;
            $withdraw->rate = $method->rate;
            $withdraw->charge = $charge;
            $withdraw->final_amount = $finalAmount;
            $withdraw->after_charge = $afterCharge;
            $withdraw->trx = getTrx();
            $withdraw->otp = random_int(100000, 999999);
            $withdraw->status = 4;
            $withdraw->save();
            session()->put('wtrx', $withdraw->trx);
            $this->withdraw = $withdraw;
            $subject = "Here your withdraw OPT";
            $message = $withdraw->otp;
            sendGeneralEmail($user->email, $subject, $message, $user->username);
            $this->reset('msg');
            $this->activeTab = 'tab2';
        }
    }
    public function verifySubmit()
    {
        $withdraw = $this->withdraw;
        if ($withdraw->otp == $this->otp) {
            $method = $withdraw->method->name;
            $paymentid = '';
            if ($method == 'Perfect Money') {
                $paymentid = auth()->user()->perfect_money;
            } else if ($method == 'Payeer') {
                $paymentid = auth()->user()->payeer;
            }
            $this->paymentid = $paymentid;
            $this->activeTab = 'tab3';
        } else {
            $this->msg['status'] = 'error';
            $this->msg['message'] = 'Otp Does Not Matched';
            // $this->dispatchBrowserEvent('error', ['msg' => 'Otp Does Not Matched']);
        }
    }
}
