<?php

namespace App\Http\Controllers\Admin;

use App\Models\Gateway;
use App\Models\GatewayCurrency;
use App\Http\Controllers\Controller;
use App\Rules\FileTypeValidate;
use Illuminate\Http\Request;

class ManualGatewayController extends Controller
{
    public function index()
    {
        $page_title = 'Manual Deposit Methods';
        $methods = GatewayCurrency::latest()->get();
        $empty_message = 'No deposit methods available.';
        return view('backend.pages.deposit_method.index', compact('page_title', 'methods', 'empty_message'));
    }

    public function create()
    {
        $page_title = 'Deposit Method';
        return view('backend.pages.deposit_method.create', compact('page_title'));
    }


    public function store(Request $request)
    {
        $validation_rule = [
            'name'           => 'required|max: 60',
            'image'          => [new FileTypeValidate(['jpeg', 'jpg', 'png'])],
            'rate'           => 'required|gt:0',
            'currency'       => 'required',
            'min_limit'      => 'required|gt:0',
            'max_limit'      => 'required|gte:0',
            'fixed_charge'   => 'required|gte:0',
            'percent_charge' => 'required|between:0,100',
            'instruction'    => 'required|max:64000',
        ];

        $request->validate($validation_rule);
        $last_method = Gateway::manual()->latest()->first();
        $method_code = 1000;
        if ($last_method) {
            $method_code = $last_method->code + 1;
        }

        $filename = '';
        $path = imagePath()['gateway']['path'];
        $size = imagePath()['gateway']['size'];
        if ($request->hasFile('image')) {
            try {
                // $filename = uploadImage($request->image, $path, $size);
                $filename = $request->image->store('/', 'public');
            } catch (\Exception $exp) {
                return back()->with('error', 'Image could not be uploaded.');
            }
        }


        $input_form = [];
        if ($request->has('field_name')) {
            for ($a = 0; $a < count($request->field_name); $a++) {
                $arr = array();
                $arr['field_name'] = strtolower(str_replace(' ', '_', trim($request->field_name[$a])));
                $arr['field_level'] = trim($request->field_name[$a]);
                $arr['type'] = $request->type[$a];
                $arr['validation'] = $request->validation[$a];
                $input_form[$arr['field_name']] = $arr;
            }
        }
        $method = new Gateway();
        $method->code = $method_code;
        $method->name = $request->name;
        $method->alias = strtolower(trim(str_replace(' ', '_', $request->name)));
        $method->image = $filename;
        $method->status = 1;
        $method->parameters = json_encode([]);
        $method->input_form = $input_form;
        $method->supported_currencies = json_encode([]);
        $method->crypto = 0;
        $method->description = $request->instruction;
        $method->save();

        $method->single_currency()->save(new GatewayCurrency([
            'name' => $request->name,
            'gateway_alias' => strtolower(trim(str_replace(' ', '_', $request->name))),
            'currency' => $request->currency,
            'symbol' => '',
            'min_amount' => $request->min_limit,
            'max_amount' => $request->max_limit,
            'fixed_charge' => $request->fixed_charge,
            'percent_charge' => $request->percent_charge,
            'rate' => $request->rate,
            'image' => $filename,
            'gateway_parameter' => json_encode($input_form),
        ]));

        return back()->with('success', $method->name . ' Manual Gateway has been added.');
    }

    public function edit($code)
    {
        $page_title = "This payment gateway";
        $method = GatewayCurrency::where('method_code', $code)->first();
        $gatway = Gateway::where('code', $code)->first();
        return view('backend.pages.deposit_method.edit', compact('page_title', 'method', 'gatway'));
    }

    public function update(Request $request, $code)
    {
        $validation_rule = [
            'name'           => 'required|max: 60',
            'rate'           => 'required|gt:0',
            'currency'       => 'required',
            'min_limit'      => 'required|gt:0',
            'max_limit'      => 'required|gte:0',
            'fixed_charge'   => 'required|gte:0',
            'percent_charge' => 'required|between:0,100',
            'instruction'    => 'required|max:64000'
        ];

        $request->validate($validation_rule);
        $method = Gateway::manual()->where('code', $code)->firstOrFail();

        $filename = $method->image;

        $path = imagePath()['gateway']['path'];
        $size = imagePath()['gateway']['size'];
        if ($request->hasFile('image')) {
            try {
                // $filename = uploadImage($request->image, $path, $size);
                $filename = $request->image->store('/', 'public');
            } catch (\Exception $exp) {
                return back()->with('error', 'Image could not be uploaded.');
            }
        }

        $input_form = [];
        if ($request->has('field_name')) {
            for ($a = 0; $a < count($request->field_name); $a++) {
                $arr = array();
                $arr['field_name'] = strtolower(str_replace(' ', '_', trim($request->field_name[$a])));
                $arr['field_level'] = trim($request->field_name[$a]);
                $arr['type'] = $request->type[$a];
                $arr['validation'] = $request->validation[$a];
                $input_form[$arr['field_name']] = $arr;
            }
        }

        $method->name = $request->name;
        $method->alias = strtolower(trim(str_replace(' ', '_', $request->name)));
        $method->image = $filename;
        $method->parameters = json_encode([]);
        $method->supported_currencies = json_encode([]);
        $method->crypto = 0;
        $method->description = $request->instruction;
        $method->input_form = $input_form;
        $method->save();


        $single_currency = $method->single_currency;

        $single_currency->name = $request->name;
        $single_currency->gateway_alias = strtolower(trim(str_replace(' ', '_', $method->name)));
        $single_currency->currency = $request->currency;
        $single_currency->symbol = '';
        $single_currency->min_amount = $request->min_limit;
        $single_currency->max_amount = $request->max_limit;
        $single_currency->fixed_charge = $request->fixed_charge;
        $single_currency->percent_charge = $request->percent_charge;
        $single_currency->rate = $request->rate;
        $single_currency->image = $filename;
        $single_currency->gateway_parameter = json_encode($input_form);
        $single_currency->save();

        return redirect()->route('admin.deposit-method.blue.index')->with('success', $method->name . ' Manual Gateway has been updated.');
    }

    public function activate(Request $request)
    {
        $code = $request->code;

        $method = Gateway::where('code', $code)->first();
        $method_currency = GatewayCurrency::where('method_code', $code)->first();

        if ($method && $method_currency) {
            $method->status = 1;
            $method_currency->status = 1;

            $method->save();
            $method_currency->save();

            return back()->with('success', $method->name . ' has been deactivated.');
        }

        return back()->withErrors('Invalid code. Could not find matching records.');
    }

    public function deactivate(Request $request)
    {
        $code = $request->code;

        $method = Gateway::where('code', $code)->first();
        $method_currency = GatewayCurrency::where('method_code', $code)->first();

        if ($method && $method_currency) {
            $method->status = 0;
            $method_currency->status = 0;

            $method->save();
            $method_currency->save();

            return back()->with('success', $method->name . ' has been deactivated.');
        }

        return back()->withErrors('Invalid code. Could not find matching records.');
    }
}
