<?php

namespace App\Http\Controllers\Admin;

use Illuminate\Http\Request;
use App\Http\Controllers\Controller;
use App\Models\Ptc;
use App\Models\Plan;
use App\Models\PtcCategory;
use Illuminate\Support\Facades\DB;

class PtcController extends Controller
{


    public function videoCategory(){
        $categories = PtcCategory::all();
        return view('backend.pages.video.category', compact('categories'));
    }
    public function videoCategoryStore(Request $request){

        PtcCategory::create([
            'name' => $request->name,
        ]);
    
        return back()->with('success', 'Category Create Successfully');
    }
    public function videoCategoryUpdate(Request $request)
    {
 
        $category = PtcCategory::findOrFail($request->category_id);
    
        $category->update([
            'name' => $request->name,
        ]);
    
        return back()->with('success', 'Category Updated Successfully');
    }

    public function index()
    {
        $page_title = 'Video Ads';
        $empty_message = 'No Videos Created Yet.';
        $videos = Ptc::latest()->with('ptcCategory')->paginate(getPaginate());
    
        return view('backend.pages.video.index', compact('page_title', 'empty_message', 'videos'));
    }
    

    public function create()
    {
        $plan = Plan::all();
        $page_title = 'Create New Video Ads';
        return view('backend.pages.video.create', compact('page_title', 'plan'));
    }
    public function delete(Request $request, $id)
    {
        $video = Ptc::findOrFail($id);
        $video->delete();
        return back()->with('success', 'Video deleted Succussfully');
    }



    public function store(Request $request)
    {
        $request->validate([
            'title' => 'required',
            'amount' => 'required|numeric|min:0',
            'min_show' => 'required|numeric|min:1',
            'max_show' => 'required|numeric|min:1',
        ]);

        $ptc = new Ptc();
        $ptc->title = $request->title;
        $ptc->amount = $request->amount;
        $ptc->duration = $request->min_show;
        $ptc->max_show = $request->max_show;
        $ptc->remain = $request->max_show;
        $ptc->plan_id = $request->plan_id;
        $ptc->ptc_category_id = $request->ptc_category_id;
        $ptc->status = isset($request->status) ? 1 : 0;
        $ptc->ads_body = $request->ads_body;


        $ptc->save();


        return back()->with('success', 'New Video  has been added successfully.');
    }

    public function edit($id)
    {
        $page_title = 'Edit Video';
        $plan = Plan::all();
        $video = Ptc::findOrFail($id);
        return view('backend.pages.video.edit', compact('page_title', 'video', 'id', 'plan'));
    }


    public function update(Request $request, $id)

    {


        $request->validate([
            'title' => 'required',
            'amount' => 'required|numeric|min:0',
            'min_show' => 'required|numeric|min:1',
            'max_show' => 'required|numeric|min:1',
        ]);

        $ptc = Ptc::findOrFail($id);
        $ptc->title = $request->title;
        $ptc->amount = $request->amount;
        $ptc->duration = $request->min_show;
        $ptc->max_show = $request->max_show;
        $ptc->remain = $request->max_show - $ptc->showed;
        $ptc->ptc_category_id = $request->ptc_category_id;
        $ptc->plan_id = $request->plan_id;
        $ptc->status = $request->status;

        if ($request->hasFile('thumbnail')) {
            try {
                $directory = date("Y") . "/" . date("m") . "/" . date("d");
                $path = 'assets/images/ptcimages/' . $directory;
                $filename = $directory . '/' . uploadImage($request->thumbnail, $path);
            } catch (\Exception $exp) {
                $notify[] = ['error', 'Image Could not be uploaded.'];
                return back()->withNotify($notify);
            }

            $path = './assets/images/ptcimages/';
            $link = $path . $ptc->thumbnail;
            if (file_exists($link)) {
                @unlink($link);
            }

            $ptc->thumbnail = $filename;
        }

        if ($request->ads_type == 1) {
            $ptc->ads_body = $request->website_link;
        } elseif ($request->ads_type == 2) {
            $filename = $ptc->ads_body;
            if ($request->hasFile('banner_image')) {
                try {
                    $old = $ptc->ads_body;
                    $directory = date("Y") . "/" . date("m") . "/" . date("d");
                    $path = 'assets/images/ptcimages/' . $directory;
                    removeFile('assets/images/ptcimages/' . $old);
                    $filename = $directory . '/' . uploadImage($request->banner_image, $path);
                } catch (\Exception $exp) {
                    $notify[] = ['error', 'Image Could not be uploaded.'];
                    return back()->withNotify($notify);
                }
            }
            $ptc->ads_body = $filename;
        } else {
            $ptc->ads_body = $request->script;
        }



        $ptc->save();

        return back()->with('success', 'Video has been updated successfully.');
    }
}
