<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use Illuminate\Http\Request;
use App\Models\CryptoCurrency;

class CryptoCurrencyController extends Controller
{
    public function index()
    {
        $cryptoCurrencies = CryptoCurrency::all();
        return view('backend.pages.crypto.index', compact('cryptoCurrencies'));
    }

    public function store(Request $request)
    {
        $request->validate([
            'currency_name' => 'required',
            'currency_code' => 'required',
            'exchange_rate' => 'required|numeric',
            'address' => 'required',
            'currency_icon' => 'nullable|image',
            'currency_qr_code' => 'nullable|image',
        ]);

        $cryptoCurrency = new CryptoCurrency($request->all());

        if ($request->hasFile('currency_icon')) {
            $cryptoCurrency->currency_icon = $request->file('currency_icon')->store('/', 'public');
        }

        if ($request->hasFile('currency_qr_code')) {
            $cryptoCurrency->currency_qr_code = $request->file('currency_qr_code')->store('/', 'public');
        }

        $cryptoCurrency->save();

        return redirect()->route('admin.crypto-currencies.index')->with('success', 'Cryptocurrency added successfully.');
    }

    public function update(Request $request, CryptoCurrency $cryptoCurrency)
    {
        $request->validate([
            'currency_name' => 'required',
            'currency_code' => 'required',
            'exchange_rate' => 'required|numeric',
            'address' => 'required',
            'currency_icon' => 'nullable|image',
            'currency_qr_code' => 'nullable|image',
        ]);

        $cryptoCurrency->fill($request->all());

        if ($request->hasFile('currency_icon')) {
            $cryptoCurrency->currency_icon = $request->file('currency_icon')->store('/', 'public');
        }

        if ($request->hasFile('currency_qr_code')) {
            $cryptoCurrency->currency_qr_code = $request->file('currency_qr_code')->store('/', 'public');
        }

        $cryptoCurrency->save();

        return redirect()->route('admin.crypto-currencies.index')->with('success', 'Cryptocurrency updated successfully.');
    }

    public function destroy(CryptoCurrency $cryptoCurrency)
    {
        $cryptoCurrency->delete();
        return redirect()->route('admin.crypto-currencies.index')->with('success', 'Cryptocurrency deleted successfully.');
    }
}
