<?php

namespace App\Http\Controllers\Admin;

use App\Models\Deposit;
use App\Models\BvLog;
use App\Models\Gateway;
use App\Models\GeneralSetting;
use App\Http\Controllers\Controller;
use App\Models\SupportTicket;
use App\Models\Transaction;
use App\Models\User;
use App\Models\UserLogin;
use App\Models\WithdrawMethod;
use App\Models\Withdrawal;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\Hash;
use App\Mail\UserActive;
use App\Mail\UserInactive;
use App\Mail\BanlanceAddSub;
use App\Mail\SendMailAll;
use App\Mail\SendMailUser;
use App\Mail\EarningBalanceUpdate;
use Illuminate\Support\Facades\Mail;
use Illuminate\Support\Facades\Session;


class ManageUsersController extends Controller
{

    public function allUsers()
    {
        $page_title = 'Manage Users';
        $empty_message = 'No user found';
        $users = User::latest()->paginate(getPaginate(30));
        return view('backend.pages.users', compact('page_title', 'empty_message', 'users'));
    }

    public function activeUsers()
    {
        $page_title = 'Manage Active Users';
        $empty_message = 'No active user found';
        $users = User::active()->latest()->paginate(getPaginate());
        return view('backend.pages.active', compact('page_title', 'empty_message', 'users'));
    }

    public function bannedUsers()
    {
        $page_title = 'Banned Users';
        $empty_message = 'No banned user found';
        $users = User::banned()->latest()->paginate(getPaginate());
        return view('backend.pages.deactive', compact('page_title', 'empty_message', 'users'));
    }

    public function emailUnverifiedUsers()
    {
        $page_title = 'Email Unverified Users';
        $empty_message = 'No email unverified user found';
        $users = User::emailUnverified()->latest()->paginate(getPaginate());
        return view('admin.users.list', compact('page_title', 'empty_message', 'users'));
    }
    public function emailVerifiedUsers()
    {
        $page_title = 'Email Verified Users';
        $empty_message = 'No email verified user found';
        $users = User::emailVerified()->latest()->paginate(getPaginate());
        return view('admin.users.list', compact('page_title', 'empty_message', 'users'));
    }


    public function smsUnverifiedUsers()
    {
        $page_title = 'SMS Unverified Users';
        $empty_message = 'No sms unverified user found';
        $users = User::smsUnverified()->latest()->paginate(getPaginate());
        return view('admin.users.list', compact('page_title', 'empty_message', 'users'));
    }
    public function smsVerifiedUsers()
    {
        $page_title = 'SMS Verified Users';
        $empty_message = 'No sms verified user found';
        $users = User::smsVerified()->latest()->paginate(getPaginate());
        return view('admin.users.list', compact('page_title', 'empty_message', 'users'));
    }



    public function search(Request $request, $scope)
    {
        $search = $request->search;
        $users = User::where(function ($user) use ($search) {
            $user->where('username', 'like', "%$search%")
                ->orWhere('email', 'like', "%$search%")
                ->orWhere('mobile', 'like', "%$search%")
                ->orWhere('firstname', 'like', "%$search%")
                ->orWhere('lastname', 'like', "%$search%");
        });
        $page_title = '';
        switch ($scope) {
            case 'active':
                $page_title .= 'Active ';
                $users = $users->where('status', 1);
                break;
            case 'banned':
                $page_title .= 'Banned';
                $users = $users->where('status', 0);
                break;
            case 'emailUnverified':
                $page_title .= 'Email Unerified ';
                $users = $users->where('ev', 0);
                break;
            case 'smsUnverified':
                $page_title .= 'SMS Unverified ';
                $users = $users->where('sv', 0);
                break;
        }
        $users = $users->paginate(getPaginate());
        $page_title .= 'User Search - ' . $search;
        $empty_message = 'No search result found';
        return view('backend.pages.users', compact('page_title', 'search', 'scope', 'empty_message', 'users'));
    }


    public function fulDetail($id)
    {
        $user = User::findOrFail($id);
        $page_title = 'User Transactions : ' . $user->username;
        $transactions = $user->transactions()->with('user')->latest()->paginate(getPaginate());
        $empty_message = 'No transactions';

        $page_title         = 'User Detail';
        $user               = User::where('id', $id)->with('userExtra')->firstOrFail();
        $totalReferrals = 0;
        $refUser = User::find($user->ref_id);
        if ($refUser) {
            $totalReferrals = $refUser->count();
        }
        
        // Usage of $totalReferrals in your code...
        $user = User::findOrFail($id);
        $page_title = 'User Login History - ' . $user->username;
        $login_logs = $user->login_logs()->latest()->paginate(getPaginate());

        $totalDeposit       = Deposit::where('user_id', $user->id)->where('status', 1)->sum('amount');
        $totalWithdraw      = Withdrawal::where('user_id', $user->id)->where('status', 1)->sum('amount');
        $totalTransaction   = Transaction::where('user_id', $user->id)->count();

        $totalBvCut         = BvLog::where('user_id', $user->id)->where('trx_type', '-')->sum('amount');
        return view('backend.pages.user-details', compact(
            'page_title',
            'totalReferrals',
            'user',
            'totalDeposit',
            'login_logs',
            'totalWithdraw',
            'transactions',
            'totalTransaction',
            'totalBvCut'
        ));
    }
    public function deactive($id)
    {
        $user = User::find($id);
        $general = GeneralSetting::first();
        if ($user) {
            $user->status = 0;
            $user->save();
    
            if ($general->mail_notification == 1) {
                $subject = "We regret to inform you that your account has been deactivated.";
                $message = "<h4>We regret to inform you that your account has been deactivated..</h4> <p>If you have any questions or concerns, please contact our support team.</p>";
                sendGeneralEmail($user->email, $subject, $message, $user->username);
            }
    
            return redirect()->route('admin.users.all')->with('success', 'User deactivated successfully.');
        }
    
        return redirect()->route('admin.users.all');
    }
    public function live($id)
    {
        $user = User::find($id);
        $general = GeneralSetting::first();
    
        if ($user) {
            $user->status = 1;
            $user->save();
    
            if ($general->mail_notification == 1) {
                        
                $subject = "Congratulations! Your account has been activated.";
                $message = "<h4>Congratulations! Your account has been activated.</h4> <p>You can now access all the features and functionalities of our platform.</p>";
                sendGeneralEmail($user->email, $subject, $message, $user->username);
            }
    
            return redirect()->route('admin.users.all')->with('success', 'User activated successfully.');
        }
    
        return redirect()->route('admin.users.all');
    }
    
    public function showUsers()
    {
        $limit = request('kt_customers_table_length', 10); // Default limit is 10, change as needed
    
        $users = User::paginate($limit);
    
        return view('backend.pages.users', compact('users'));
    }
    

    public function update(Request $request, $id)
    {
        $user = User::findOrFail($id);
        $request->validate([
            'firstname' => 'required|max:60',
            'lastname' => 'required|max:60',
            'email' => 'required|email|max:160|unique:users,email,' . $user->id,
        ]);

        if ($request->email != $user->email && User::whereEmail($request->email)->whereId('!=', $user->id)->count() > 0) {
            $notify[] = ['error', 'Email already exists.'];
            return back()->withNotify($notify);
        }
        if ($request->mobile != $user->mobile && User::where('mobile', $request->mobile)->whereId('!=', $user->id)->count() > 0) {
            $notify[] = ['error', 'Phone number already exists.'];
            return back()->withNotify($notify);
        }

        $user->mobile = $request->mobile;
        $user->firstname = $request->firstname;
        $user->lastname = $request->lastname;
        $user->lastname = $request->lastname;
        $user->email = $request->email;
        $user->address = [
            'address' => $request->address,
            'city' => $request->city,
            'state' => $request->state,
            'zip' => $request->zip,
            'country' => $request->country,
        ];
        $user->status = $request->account_status;
        $user->ev = $request->email_verification;
        $user->sv = $request->sv ? 1 : 0;
        $user->ts = $request->ts ? 1 : 0;
        $user->tv = $request->tv ? 1 : 0;
        $user->save();


        return redirect()->back()->with('success', 'User detail has been updated');
    }

    public function addSubBalance(Request $request, $id)
    {
        $request->validate(['amount' => 'required|numeric|gt:0']);
    
        $user = User::findOrFail($id);
        $amount = getAmount($request->amount);
        $general = GeneralSetting::first(['cur_text', 'cur_sym']);
        $gener = GeneralSetting::first();
        $trx = getTrx();
    
        if ($request->act == 'on') {
            $user->total_invest += $amount;
            $user->save();
            $notify = ['success', $general->cur_sym . $amount . ' has been added to ' . $user->username . ' balance'];
    
            $transaction = new Transaction();
            $transaction->user_id = $user->id;
            $transaction->amount = $amount;
            $transaction->post_balance = getAmount($user->total_invest);
            $transaction->charge = 0;
            $transaction->trx_type = '+';
            $transaction->details = ' DEPOSIT WALLET Added Balance Via Admin';
            $transaction->trx =  $trx;
            $transaction->save();
    
            notify($user, 'BAL_ADD', [
                'trx' => $trx,
                'amount' => $amount,
                'currency' => $general->cur_text,
                'post_balance' => getAmount($user->total_invest),
            ]);
    
            if ($gener->mail_notification == 1) {
                $subject = "An amount of $amount USD has been added to your  balance";
                $message = "<p>Your new  balance is: $user->total_invest USD</p> <p>Transaction : $trx </p> <p>Thank you for using our services!</p>";
                // sendGeneralEmail($user->email, $subject, $message, $user->username);
            }
        } elseif ($request->act == 'off') {
    
            if ($amount > $user->total_invest) {
                return back()->with('error', $user->username . ' has insufficient balance.');
            }
            $user->total_invest -= $amount;
            $user->save();
    
            $transaction = new Transaction();
            $transaction->user_id = $user->id;
            $transaction->amount = $amount;
            $transaction->post_balance = getAmount($user->balance);
            $transaction->charge = 0;
            $transaction->trx_type = '-';
            $transaction->details = ' DEPOSIT WALLET Subtract Balance Via Admin';
            $transaction->trx =  $trx;
            $transaction->save();
    
            if ($gener->mail_notification == 1) {
                $subject = "An amount of  $amount  USD has been subtracted from your balance";
                $message = "<p>Your new balance is: $user->total_invest USD</p> <p>Transaction : $trx </p> <p>Thank you for using our services!</p>";
                sendGeneralEmail($user->email, $subject, $message, $user->username);
            }
        }
    
        return back()->with('success', $general->cur_sym . $amount . ' has been subtracted from ' . $user->username . ' balance');
    }

    public function UserMail(Request $request, User $user)
    {
        $subject = $request->input('subject');
        $message = $request->input('message');
        
        sendGeneralEmail($user->email, $subject, $message, $user->username);
        
        return back()->with('success', 'Mail sent successfully to ' . $user->firstname . ' ' . $user->lastname);
    }


    public function allUserMail(Request $request)
    {

        $subject = $request->input('subject');
        $message = $request->input('message');
        $userType = $request->input('user_type');

        // Increase the maximum execution time temporarily
        ini_set('max_execution_time', 500); // Set the maximum execution time to 500 seconds (8 minutes)

        if ($userType === 'all') {
            $users = User::all();
        } elseif ($userType === 'active') {
            $users = User::where('status', 1)->get();
        } elseif ($userType === 'deactive') {
            $users = User::where('status', 0)->get();
        }

        foreach ($users as $user) {
            sendGeneralEmail($user->email, $subject, $message, $user->username);
        }

        // Reset the maximum execution time to the default value
        ini_restore('max_execution_time');

        return back()->with('success', 'Mail sent successfully to ' . $userType . ' users.');
    }
    
    
    

    public function addSubEarning(Request $request, $id)
    {
        $request->validate(['amount' => 'required|numeric|gt:0']);
    
        $user = User::findOrFail($id);
        $amount = getAmount($request->amount);
        $general = GeneralSetting::first(['cur_text', 'cur_sym']);
        $gener = GeneralSetting::first();
        $trx = getTrx();
    
        if ($request->act == 'on') {
            $user->balance += $amount;
            $user->save();
            $notify = ['success', $general->cur_sym . $amount . ' has been added to ' . $user->username . ' balance'];
    
            $transaction = new Transaction();
            $transaction->user_id = $user->id;
            $transaction->amount = $amount;
            $transaction->post_balance = getAmount($user->balance);
            $transaction->charge = 0;
            $transaction->trx_type = '+';
            $transaction->details = ' WATCH BALANCE Added Balance Via Admin';
            $transaction->trx =  $trx;
            $transaction->save();
    
            notify($user, 'BAL_ADD', [
                'trx' => $trx,
                'amount' => $amount,
                'currency' => $general->cur_text,
                'post_balance' => getAmount($user->balance),
            ]);
    
            if ($gener->mail_notification == 1) {
                $subject = "An amount of  $amount  USD has been added to your balance";
                $message = "<p>Your new earning balance is: $user->balance USD</p> <p>Transaction : $trx </p> <p>Thank you for using our services!</p>";
                
                // sendGeneralEmail($user->email, $subject, $message, $user->username);
                
            }
        } elseif ($request->act == 'off') {
    
            if ($amount > $user->balance) {
                return back()->with('error', $user->username . ' WATCH BALANCE has insufficient balance.');
            }
            $user->balance -= $amount;
            $user->save();
    
            $transaction = new Transaction();
            $transaction->user_id = $user->id;
            $transaction->amount = $amount;
            $transaction->post_balance = getAmount($user->balance);
            $transaction->charge = 0;
            $transaction->trx_type = '-';
            $transaction->details = 'WATCH BALANCE Subtract Balance Via Admin';
            $transaction->trx =  $trx;
            $transaction->save();
    
            notify($user, 'BAL_SUB', [
                'trx' => $trx,
                'amount' => $amount,
                'currency' => $general->cur_text,
                'post_balance' => getAmount($user->balance)
            ]);
    
            if ($gener->mail_notification == 1) {
                
                $subject = "An amount of $amount  USD has been subtracted from your balance";
                $message = "<p>Your new earning balance is: $user->balance USD</p> <p>Transaction : $trx </p> <p>Thank you for using our services!</p>";
                
                // sendGeneralEmail($user->email, $subject, $message, $user->username);
            }
    
        }
        return back()->with('success', $general->cur_sym . $amount . ' has been subtracted from ' . $user->username . ' balance');  
    }
    
    

    public function userLoginHistory($id)
    {
        $user = User::findOrFail($id);
        $page_title = 'User Login History - ' . $user->username;
        $login_logs = $user->login_logs()->latest()->paginate(getPaginate());
        return view('admin.users.logins', compact('page_title', 'empty_message', 'login_logs'));
    }

    public function userRef($id)
    {

        $empty_message = 'No user found';
        $user = User::findOrFail($id);
        $page_title = 'Referred By ' . $user->username;
        $users = User::where('ref_id', $id)->latest()->paginate(getPaginate());
        return view('admin.users.list', compact('page_title', 'empty_message', 'users'));
    }

    public function showEmailSingleForm($id)
    {
        $user = User::findOrFail($id);
        return back()->with('sucess', 'Mail Send Successfully !');
    }

    public function sendEmailSingle(Request $request, $id)
    {
        $request->validate([
            'message' => 'required|string|max:65000',
            'subject' => 'required|string|max:190',
        ]);

        $user = User::findOrFail($id);
        sendGeneralEmail($user->email, $request->subject, $request->message, $user->username);
        return back()->with('success', $user->username . ' will receive an email shortly.');
    }

    public function transactions(Request $request, $id)
    {
        $user = User::findOrFail($id);
        if ($request->search) {
            $search = $request->search;
            $page_title = 'Search User Transactions : ' . $user->username;
            $transactions = $user->transactions()->where('trx', $search)->with('user')->latest()->paginate(getPaginate());
            $empty_message = 'No transactions';
            return view('admin.reports.transactions', compact('page_title', 'search', 'user', 'transactions', 'empty_message'));
        }
        $page_title = 'User Transactions : ' . $user->username;
        $transactions = $user->transactions()->with('user')->latest()->paginate(getPaginate());
        $empty_message = 'No transactions';
        return view('admin.reports.transactions', compact('page_title', 'user', 'transactions', 'empty_message'));
    }

    public function deposits(Request $request, $id)
    {
        $user = User::findOrFail($id);
        $userId = $user->id;
        if ($request->search) {
            $search = $request->search;
            $page_title = 'Search User Deposits : ' . $user->username;
            $deposits = $user->deposits()->where('trx', $search)->latest()->paginate(getPaginate());
            $empty_message = 'No deposits';
            return view('admin.deposit.log', compact('page_title', 'search', 'user', 'deposits', 'empty_message', 'userId'));
        }

        $page_title = 'User Deposit : ' . $user->username;
        $deposits = $user->deposits()->latest()->paginate(getPaginate());
        $empty_message = 'No deposits';
        $scope = 'all';
        return view('admin.deposit.log', compact('page_title', 'user', 'deposits', 'empty_message', 'userId', 'scope'));
    }


    public function depViaMethod($method, $type = null, $userId)
    {
        $method = Gateway::where('alias', $method)->firstOrFail();
        $user = User::findOrFail($userId);
        if ($type == 'approved') {
            $page_title = 'Approved Payment Via ' . $method->name;
            $deposits = Deposit::where('method_code', '>=', 1000)->where('user_id', $user->id)->where('method_code', $method->code)->where('status', 1)->latest()->with(['user', 'gateway'])->paginate(getPaginate());
        } elseif ($type == 'rejected') {
            $page_title = 'Rejected Payment Via ' . $method->name;
            $deposits = Deposit::where('method_code', '>=', 1000)->where('user_id', $user->id)->where('method_code', $method->code)->where('status', 3)->latest()->with(['user', 'gateway'])->paginate(getPaginate());
        } elseif ($type == 'successful') {
            $page_title = 'Successful Payment Via ' . $method->name;
            $deposits = Deposit::where('status', 1)->where('user_id', $user->id)->where('method_code', $method->code)->latest()->with(['user', 'gateway'])->paginate(getPaginate());
        } elseif ($type == 'pending') {
            $page_title = 'Pending Payment Via ' . $method->name;
            $deposits = Deposit::where('method_code', '>=', 1000)->where('user_id', $user->id)->where('method_code', $method->code)->where('status', 2)->latest()->with(['user', 'gateway'])->paginate(getPaginate());
        } else {
            $page_title = 'Payment Via ' . $method->name;
            $deposits = Deposit::where('status', '!=', 0)->where('user_id', $user->id)->where('method_code', $method->code)->latest()->with(['user', 'gateway'])->paginate(getPaginate());
        }
        $page_title = 'Deposit History: ' . $user->username . ' Via ' . $method->name;
        $methodAlias = $method->alias;
        $empty_message = 'Deposit Log';
        return view('admin.deposit.log', compact('page_title', 'empty_message', 'deposits', 'methodAlias', 'userId'));
    }



    public function withdrawals(Request $request, $id)
    {
        $user = User::findOrFail($id);
        if ($request->search) {
            $search = $request->search;
            $page_title = 'Search User Withdrawals : ' . $user->username;
            $withdrawals = $user->withdrawals()->where('trx', 'like', "%$search%")->latest()->paginate(getPaginate());
            $empty_message = 'No withdrawals';
            return view('admin.withdraw.withdrawals', compact('page_title', 'user', 'search', 'withdrawals', 'empty_message'));
        }
        $page_title = 'User Withdrawals : ' . $user->username;
        $withdrawals = $user->withdrawals()->latest()->paginate(getPaginate());
        $empty_message = 'No withdrawals';
        $userId = $user->id;
        return view('admin.withdraw.withdrawals', compact('page_title', 'user', 'withdrawals', 'empty_message', 'userId'));
    }

    public  function withdrawalsViaMethod($method, $type, $userId)
    {
        $method = WithdrawMethod::findOrFail($method);
        $user = User::findOrFail($userId);
        if ($type == 'approved') {
            $page_title = 'Approved Withdrawal of ' . $user->username . ' Via ' . $method->name;
            $withdrawals = Withdrawal::where('status', 1)->where('user_id', $user->id)->with(['user', 'method'])->latest()->paginate(getPaginate());
        } elseif ($type == 'rejected') {
            $page_title = 'Rejected Withdrawals of ' . $user->username . ' Via ' . $method->name;
            $withdrawals = Withdrawal::where('status', 3)->where('user_id', $user->id)->with(['user', 'method'])->latest()->paginate(getPaginate());
        } elseif ($type == 'pending') {
            $page_title = 'Pending Withdrawals of ' . $user->username . ' Via ' . $method->name;
            $withdrawals = Withdrawal::where('status', 2)->where('user_id', $user->id)->with(['user', 'method'])->latest()->paginate(getPaginate());
        } else {
            $page_title = 'Withdrawals of ' . $user->username . ' Via ' . $method->name;
            $withdrawals = Withdrawal::where('status', '!=', 0)->where('user_id', $user->id)->with(['user', 'method'])->latest()->paginate(getPaginate());
        }
        $empty_message = 'Withdraw Log Not Found';
        return view('admin.withdraw.withdrawals', compact('page_title', 'withdrawals', 'empty_message', 'method'));
    }

    public function showEmailAllForm()
    {
        $page_title = 'Send Email To All Users';
        return view('admin.users.email_all', compact('page_title'));
    }

    public function sendEmailAll(Request $request)
    {
        $request->validate([
            'message' => 'required|string|max:65000',
            'subject' => 'required|string|max:190',
        ]);

        foreach (User::where('status', 1)->cursor() as $user) {
            sendGeneralEmail($user->email, $request->subject, $request->message, $user->username);
        }

        $notify[] = ['success', 'All users will receive an email shortly.'];
        return back()->withNotify($notify);
    }

    public function tree($username)
    {

        $user = User::where('username', $username)->first();

        if ($user) {
            $data['tree'] = showTreePage($user->id);
            $data['page_title'] = "Tree of " . $user->fullname;
            return view('admin.users.tree', $data);
        }

        $notify[] = ['error', 'Tree Not Found!!'];
        return redirect()->route('admin.dashboard')->withNotify($notify);
    }

    public function otherTree(Request $request, $username = null)
    {
        if ($request->username) {
            $user = User::where('username', $request->username)->first();
        } else {
            $user = User::where('username', $username)->first();
        }
        if ($user) {
            $data['tree'] = showTreePage($user->id);
            $data['page_title'] = "Tree of " . $user->fullname;
            return view('admin.users.tree', $data);
        }

        $notify[] = ['error', 'Tree Not Found!!'];
        return redirect()->route('admin.dashboard')->withNotify($notify);
    }


    public function userloginAdmin($id)
    {
        $user = User::findOrFail($id);
        if(auth()->user()) {
            // If there is an authenticated user, log them out
            Auth::logout();
        }

        Auth::login($user);
    
        // Flash a success message and redirect to user dashboard
        Session::flash('success', 'You have successfully logged in as the user account.');
        return redirect()->route('user.dashboard');
    }    
}
