<?php

namespace App\Http\Controllers;

use Auth;
use App\Models\User;
use App\Models\Agent;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\DB;
use App\Models\GeneralSetting;
use App\Mail\AgentRequestAccepted;
use App\Mail\AgentRequestRejected;
use Illuminate\Support\Facades\Mail;

class AgentController extends Controller
{
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {
        $agents = User::where('is_agent', 1)->orWhere('is_agent', 2)->orWhere('is_agent', 3)->latest()->paginate(10);
        return view('backend.pages.agent.index', compact('agents'));
    }

    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function userIndex()
    {
        $agents = User::where([
                ['is_agent', '=', 2],
                ['country', '!=', '']
            
            ])->select('country', DB::raw('count(*) as count'))->groupBy('country')->get();
        return view(activeTemplate() . 'user.agent', compact('agents'));
    }
    public function agentByCountry($country)
    {
        $agents = User::where('country', $country)->where('is_agent', 2)->get();
        return view(activeTemplate() . 'user.agentlist', compact('agents', 'country'));
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        User::where('id', Auth::id())->update(['is_agent' => 1, 'skype' => $request->get('skype'), 'facebook' => $request->get('facebook')]);
        $notify[] = ['success', 'Agent request successfully, Please Wait for confirmation'];
        return back()->withNotify($notify);
    }

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */

     public function accept($id)
     {
         User::where('id', $id)->update(['is_agent' => 2]);
         $general = GeneralSetting::first();
         $user = User::find($id);
     
         if ($user && $user->email && $user->is_agent == 2) {
             if ($general->mail_notification == 1) {
                 $subject = "Congratulations! Your agent request has been accepted";
                 $message = "<p>Congratulations! Your agent request has been accepted.</p> <p>Thank you for joining our team as an agent.</p>";
                 sendGeneralEmail($user->email, $subject, $message, $user->username);
             }
         }
         return back()->with('success', 'Agent request Accepted');
     }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function reject($id)
    {
        User::where('id', $id)->update(['is_agent' => 3]);
        $general = GeneralSetting::first();
        $user = User::find($id);
    
        if ($user && $user->email && $user->is_agent == 3) {
            if ($general->mail_notification == 1) {
                 $subject = "We regret to inform you that your agent request has been rejected";
                 $message = "<p>We regret to inform you that your agent request has been rejected.</p> <p>Thank you for your interest, but we are unable to proceed with your request at this time.</p>";
                 sendGeneralEmail($user->email, $subject, $message, $user->username);
            }
        }
    
        return back()->with('success', 'Agent request Rejected');
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request)
    {
        User::where('id', Auth::id())->update(['is_agent' => 0]);
        $notify[] = ['success', 'Agent Cancel successfully'];
        return back()->withNotify($notify);
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        return view(activeTemplate() . 'user.agent_form');
    }
}
