<?php

namespace App\Http\Controllers\Auth;

use App\Models\User;
use App\Mail\OtpMail;
use App\Models\Frontend;
use Illuminate\Http\Request;
use App\Models\PasswordReset;
use App\Models\GeneralSetting;
use App\Http\Controllers\Controller;
use Illuminate\Support\Facades\Mail;
use Illuminate\Foundation\Auth\SendsPasswordResetEmails;

class ForgotPasswordController extends Controller
{
    /*
    |--------------------------------------------------------------------------
    | Password Reset Controller
    |--------------------------------------------------------------------------
    |
    | This controller is responsible for handling password reset emails and
    | includes a trait which assists in sending these notifications from
    | your application to your users. Feel free to explore this trait.
    |
    */

    use SendsPasswordResetEmails;

    public function __construct()
    {
        $this->middleware('guest');
    }


    public function showLinkRequestForm()
    {
        $page_title = "Forgot Password";
        $content    = Frontend::where('data_keys', 'sign_in.content')->first();
        return view('user.email', compact('page_title', 'content'));
    }

    public function sendResetLinkEmail(Request $request)
    {
        if ($request->type == 'email') {
            $validationRule = [
                'value' => 'required|email'
            ];
            $validationMessage = [
                'value.required' => 'Email field is required',
                'value.email' => 'Email must be an valide email'
            ];
        } elseif ($request->type == 'username') {
            $validationRule = [
                'value' => 'required'
            ];
            $validationMessage = ['value.required' => 'Username field is required'];
        } else {
            $notify[] = ['error', 'Invalid selection'];
            return back()->withNotify($notify);
        }

        $request->validate($validationRule, $validationMessage);

        $user = User::where($request->type, $request->value)->first();

        if (!$user) {
            $notify[] = ['error', 'User not found.'];
            return back()->withNotify($notify);
        }

        PasswordReset::where('email', $user->email)->delete();
        $code = verificationCode(4);
        $password = new PasswordReset();
        $password->email = $user->email;
        $password->token = $code;
        $password->created_at = \Carbon\Carbon::now();
        $password->save();

        $userIpInfo = getIpInfo();
        $userBrowserInfo = osBrowser();
        // sendEmail($user, 'PASS_RESET_CODE', [
        //     'code' => $code,
        //     'operating_system' => @$userBrowserInfo['os_platform'],
        //     'browser' => @$userBrowserInfo['browser'],
        //     'ip' => @$userIpInfo['ip'],
        //     'time' => @$userIpInfo['time']
        // ]);

        $subject = 'Reset Password Email';
        $message = 'For password reset use this code : ' . $password->token;

        sendGeneralEmail($user->email, $subject, $message, $user->username);


        // Mail::to($user->email)->send(new OtpMail($password->token));

        $page_title = 'Account Recovery';
        $email = $user->email;
        session()->put('pass_res_mail', $email);
        $notify[] = ['success', 'Password reset email sent successfully'];
        return redirect()->route('user.password.code_verify')->withNotify($notify);
    }

    public function codeVerify()
    {
        $page_title = 'Account Recovery';
        $email = session()->get('pass_res_mail');
        if (!$email) {
            $notify[] = ['error', 'Opps! session expired'];
            return redirect()->route('user.password.request')->withNotify($notify);
        }

        $content    = Frontend::where('data_keys', 'sign_in.content')->first();
        return view('user.code_verify', compact('page_title', 'email', 'content'));
    }

    public function verifyCode(Request $request)
    {
        $request->validate(['code.*' => 'required', 'email' => 'required']);
        $code =   $request->code;

        if (PasswordReset::where('token', $code)->where('email', $request->email)->count() != 1) {
            $notify[] = ['error', 'Invalid token'];
            return redirect()->route('user.password.request')->withNotify($notify);
        }
        $notify[] = ['success', 'You can change your password.'];
        session()->flash('fpass_email', $request->email);
        return redirect()->route('user.password.reset', $code)->withNotify($notify);
    }
}
