<?php

namespace App\Http\Controllers;

use App\Models\Plan;
use App\Models\User;
use App\Models\BvLog;
use App\Models\Deposit;
use App\Models\UserExtra;
use App\Models\Transaction;
use Illuminate\Http\Request;
use App\Models\GeneralSetting;
use App\Models\GatewayCurrency;
use Illuminate\Support\Facades\Auth;

class PlanController extends Controller
{

    public function __construct()
    {
        $this->activeTemplate = activeTemplate();
    }

    function planIndex()
    {
        $methods = GatewayCurrency::whereHas('method', function ($gate) {
            $gate->where('status', 1);
        })->with('method')->orderby('method_code')->get();
        $data['page_title'] = "Plans";
        $data['plans'] = Plan::whereStatus(1)->orderBy('price')->get();
        $plan = Plan::where('id', Auth::user()->plan_id)->first();

        $data['user_plan_price'] = isset($plan->price) ? $plan->price : 0;

        return view($this->activeTemplate . '.user.plan', $data)->with('methods', $methods);
    }
    function upgradIndex()
    {
                $methods = GatewayCurrency::whereHas('method', function ($gate) {
            $gate->where('status', 1);
        })->with('method')->orderby('method_code')->get();
        $data['page_title'] = "Plans";
        $data['plans'] = Plan::whereStatus(1)->orderBy('price')->get();
        $plan = Plan::where('id', Auth::user()->plan_id)->first();

        $data['user_plan_price'] = isset($plan->price) ? $plan->price : 0;

        return view($this->activeTemplate . '.user.upgrad', $data)->with('methods', $methods);

    }
 public function planUpgrade(Request $request)
    {
        $this->validate($request, ['plan_id' => 'required|integer']);
        $plan = Plan::find($request->plan_id);

        $gnl = GeneralSetting::first();

        if ($request->type == 'accountbalance') {
            if ($plan) {
                $user = User::find(Auth::id());
                $oldPlanId = $user->plan_id;
                if ($oldPlanId) {
                    $oldPlan = Plan::find($oldPlanId);
                    $oldPlanPrice = $oldPlan->price;
                    if ($oldPlanPrice > $plan->price) {
                        if ($user->total_invest >= $plan->price) {

                            $user->plan_id = $plan->id;
                            $user->plan_updated_at = now();
                            $user->total_invest -= $plan->price;
                            $user->dpl  = $plan->daily_ad_limit;
                            $user->save();

                            $trx = $user->transactions()->create([
                                'amount' => $plan->price,
                                'trx_type' => '-',
                                'details' => 'Purchased ' . $plan->name,
                                'remark' => 'purchased_plan',
                                'trx' => getTrx(),
                                'post_balance' => getAmount($user->total_invest),
                            ]);

                            notify($user, 'plan_purchased', [
                                'plan' => $plan->name,
                                'amount' => getAmount($plan->price),
                                'currency' => $gnl->cur_text,
                                'trx' => $trx->trx,
                                'post_balance' => getAmount($user->total_invest) . ' ' . $gnl->cur_text,
                            ]);


                            $details = Auth::user()->username . ' Subscribed to ' . $plan->name . ' plan.';

                            updateBV($user->id, $plan->bv, $details);

                            if ($plan->tree_com > 0) {
                                treeComission($user->id, $plan->tree_com, $details);
                            }

                            referralComission($user->id, $details);

                            $notify[] = ['success', 'Purchased ' . $plan->name . ' Successfully and Balance is not refundable'];
                            return redirect()->route('user.home')->withNotify($notify);
                        }
                    } else {
                        if ($user->total_invest >= ($plan->price - $oldPlanPrice)) {

                            $user->plan_id = $plan->id;
                            $user->total_invest -= ($plan->price - $oldPlanPrice);
                            $user->plan_updated_at = now();

                            $user->dpl  = $plan->daily_ad_limit;
                            $user->save();

                            $trx = $user->transactions()->create([
                                'amount' => ($plan->price - $oldPlanPrice),
                                'trx_type' => '-',
                                'details' => 'Purchased ' . $plan->name,
                                'remark' => 'purchased_plan',
                                'trx' => getTrx(),
                                'post_balance' => getAmount($user->total_invest),
                            ]);

                            notify($user, 'plan_purchased', [
                                'plan' => $plan->name,
                                'amount' => getAmount(($plan->price - $oldPlanPrice)),
                                'currency' => $gnl->cur_text,
                                'trx' => $trx->trx,
                                'post_balance' => getAmount($user->total_invest) . ' ' . $gnl->cur_text,
                            ]);


                            $details = Auth::user()->username . ' Subscribed to ' . $plan->name . ' plan.';

                            updateBV($user->id, $plan->bv, $details);

                            if ($plan->tree_com > 0) {
                                treeComission($user->id, $plan->tree_com, $details);
                            }

                            referralComission($user->id, $details);

                            $notify[] = ['success', 'Purchased ' . $plan->name . ' Successfully'];
                            return redirect()->route('user.home')->withNotify($notify);
                        }
                    }
                    $notify[] = ['error', 'You do not have enough balance to buy this plan. Increase your balance through our deposit system'];
                    return redirect()->route('user.deposit')->withNotify($notify);
                } else {
                    if ($user->total_invest >= $plan->price) {

                        $user->plan_id = $plan->id;
                        $user->total_invest -= $plan->price;
                        $user->plan_updated_at = now();

                        $user->dpl  = $plan->daily_ad_limit;
                        $user->save();

                        $trx = $user->transactions()->create([
                            'amount' => $plan->price,
                            'trx_type' => '-',
                            'details' => 'Purchased ' . $plan->name,
                            'remark' => 'purchased_plan',
                            'trx' => getTrx(),
                            'post_balance' => getAmount($user->total_invest),
                        ]);

                        notify($user, 'plan_purchased', [
                            'plan' => $plan->name,
                            'amount' => getAmount($plan->price),
                            'currency' => $gnl->cur_text,
                            'trx' => $trx->trx,
                            'post_balance' => getAmount($user->total_invest) . ' ' . $gnl->cur_text,
                        ]);


                        $details = Auth::user()->username . ' Subscribed to ' . $plan->name . ' plan.';

                        updateBV($user->id, $plan->bv, $details);

                        if ($plan->tree_com > 0) {
                            treeComission($user->id, $plan->tree_com, $details);
                        }

                        referralComission($user->id, $details);

                        $notify[] = ['success', 'Purchased ' . $plan->name . ' Successfully'];
                        return redirect()->route('user.home')->withNotify($notify);
                    }
                }
            }
        } else {
            // $amount = User::convertToUsd($plan->price);
            $amount = $plan->price;

            $user = auth()->user();
            $gate = GatewayCurrency::where('method_code', $request->type)->where('currency', 'USD')->first();
            if (!$gate) {
                $notify[] = ['error', 'Invalid Gateway'];
                return back()->withNotify($notify);
            }

            // if ($gate->min_amount > $amount || $gate->max_amount < $amount) {
            //     $notify[] = ['error', 'Please Follow Deposit Limit'];
            //     return back()->withNotify($notify);
            // }

            $charge = getAmount($gate->fixed_charge + ($amount * $gate->percent_charge / 100));
            $payable = getAmount($amount + $charge);
            $final_amo = getAmount($payable * $gate->rate);

            $data = new Deposit();
            $data->user_id = $user->id;
            $data->method_code = $gate->method_code;
            $data->method_currency = strtoupper($gate->currency);
            $data->amount = $amount;
            $data->charge = $charge;
            $data->rate = $gate->rate;
            $data->final_amo = getAmount($final_amo);
            $data->btc_amo = 0;
            $data->btc_wallet = "";
            $data->trx = getTrx();
            $data->try = 0;
            $data->plan_id = $plan->id;
            $data->status = 0;
            $data->save();
            session()->put('Track', $data['trx']);
            return redirect()->route('user.deposit.preview');
        }
        $notify[] = ['error', 'Something Went Wrong!'];
        return back()->withNotify($notify);
    }
    function planStore(Request $request)
    {
        $this->validate($request, ['plan_id' => 'required|integer']);
        $plan = Plan::find($request->plan_id);

        $gnl = GeneralSetting::first();

        if ($plan) {
            $user = User::find(Auth::id());
            $oldPlanId = $user->plan_id;
            if ($oldPlanId) {
                $oldPlan = Plan::find($oldPlanId);
                $oldPlanPrice = $oldPlan->price;
                if ($oldPlanPrice > $plan->price) {
                    if ($user->total_invest >= $plan->price) {

                        $user->plan_id = $plan->id;
                        $user->plan_updated_at = now();
                        $user->total_invest -= $plan->price;
                        $user->dpl  = $plan->daily_ad_limit;
                        $user->save();

                        $trx = $user->transactions()->create([
                            'amount' => $plan->price,
                            'trx_type' => '-',
                            'details' => 'Purchased ' . $plan->name,
                            'remark' => 'purchased_plan',
                            'trx' => getTrx(),
                            'post_balance' => getAmount($user->total_invest),
                        ]);

                        notify($user, 'plan_purchased', [
                            'plan' => $plan->name,
                            'amount' => getAmount($plan->price),
                            'currency' => $gnl->cur_text,
                            'trx' => $trx->trx,
                            'post_balance' => getAmount($user->total_invest) . ' ' . $gnl->cur_text,
                        ]);


                        $details = Auth::user()->username . ' Subscribed to ' . $plan->name . ' plan.';

                        updateBV($user->id, $plan->bv, $details);

                        if ($plan->tree_com > 0) {
                            treeComission($user->id, $plan->tree_com, $details);
                        }

                        referralComission($user->id, $details);

                        $notify[] = ['success', 'Purchased ' . $plan->name . ' Successfully and Balance is not refundable'];
                        return redirect()->route('user.home')->withNotify($notify);
                    }
                } else {
                    if ($user->total_invest >= ($plan->price - $oldPlanPrice)) {

                        $user->plan_id = $plan->id;
                        $user->plan_updated_at = now();
                        $user->total_invest -= ($plan->price - $oldPlanPrice);
                        $user->dpl  = $plan->daily_ad_limit;
                        $user->save();

                        $trx = $user->transactions()->create([
                            'amount' => ($plan->price - $oldPlanPrice),
                            'trx_type' => '-',
                            'details' => 'Purchased ' . $plan->name,
                            'remark' => 'purchased_plan',
                            'trx' => getTrx(),
                            'post_balance' => getAmount($user->total_invest),
                        ]);

                        notify($user, 'plan_purchased', [
                            'plan' => $plan->name,
                            'amount' => getAmount(($plan->price - $oldPlanPrice)),
                            'currency' => $gnl->cur_text,
                            'trx' => $trx->trx,
                            'post_balance' => getAmount($user->total_invest) . ' ' . $gnl->cur_text,
                        ]);


                        $details = Auth::user()->username . ' Subscribed to ' . $plan->name . ' plan.';

                        updateBV($user->id, $plan->bv, $details);

                        if ($plan->tree_com > 0) {
                            treeComission($user->id, $plan->tree_com, $details);
                        }

                        referralComission($user->id, $details);

                        $notify[] = ['success', 'Purchased ' . $plan->name . ' Successfully'];
                        return redirect()->route('user.home')->withNotify($notify);
                    }
                }
                $notify[] = ['error', 'You do not have enough balance to buy this plan. Increase your balance through our deposit system'];
                return redirect()->route('user.deposit')->withNotify($notify);
            }
        }
        $notify[] = ['error', 'Something Went Wrong!'];
        return back()->withNotify($notify);
    }
    function planStoreGatewaye(Request $request)
    {

        $this->validate($request, ['plan_id' => 'required|integer']);
        $plan = Plan::find($request->plan_id);

        $gnl = GeneralSetting::first();

        if ($plan) {
            $user = User::find(Auth::id());
            $oldPlanId = $user->plan_id;
            if ($user->total_invest >= $plan->price) {

                $user->plan_id = $plan->id;
                $user->total_invest -= $plan->price;
                $user->dpl  = $plan->daily_ad_limit;
                $user->save();

                $trx = $user->transactions()->create([
                    'amount' => $plan->price,
                    'trx_type' => '-',
                    'details' => 'Purchased ' . $plan->name,
                    'remark' => 'purchased_plan',
                    'trx' => getTrx(),
                    'post_balance' => getAmount($user->total_invest),
                ]);

                notify($user, 'plan_purchased', [
                    'plan' => $plan->name,
                    'amount' => getAmount($plan->price),
                    'currency' => $gnl->cur_text,
                    'trx' => $trx->trx,
                    'post_balance' => getAmount($user->total_invest) . ' ' . $gnl->cur_text,
                ]);

                $details = Auth::user()->username . ' Subscribed to ' . $plan->name . ' plan.';

                updateBV($user->id, $plan->bv, $details);

                if ($plan->tree_com > 0) {
                    treeComission($user->id, $plan->tree_com, $details);
                }

                referralComission($user->id, $details);

                $notify[] = ['success', 'Purchased ' . $plan->name . ' Successfully'];
                return redirect()->route('user.home')->withNotify($notify);
            }
            $notify[] = ['error', 'You do not have enough balance to buy this plan. Increase your balance through our deposit system'];
            return redirect()->route('user.deposit')->withNotify($notify);
        }
        $notify[] = ['error', 'Something Went Wrong!'];
        return back()->withNotify($notify);
    }


    public function binaryCom()
    {
        $data['page_title'] = "Binary Commission";
        $data['logs'] = Transaction::where('user_id', auth()->id())->where('remark', 'binary_commission')->orderBy('id', 'DESC')->paginate(config('constants.table.default'));
        $data['empty_message'] = 'No data found';
        return view($this->activeTemplate . '.user.transactions', $data);
    }

    public function binarySummery()
    {
        $data['page_title'] = "Binary Summery";
        $data['logs'] = UserExtra::where('user_id', auth()->id())->firstOrFail();
        return view($this->activeTemplate . '.user.binarySummery', $data);
    }

    public function bvlog(Request $request)
    {

        if ($request->type) {
            if ($request->type == 'leftBV') {
                $data['page_title'] = "Left BV";
                $data['logs'] = BvLog::where('user_id', auth()->id())->where('position', 1)->where('trx_type', '+')->orderBy('id', 'desc')->paginate(config('constants.table.default'));
            } elseif ($request->type == 'rightBV') {
                $data['page_title'] = "Right BV";
                $data['logs'] = BvLog::where('user_id', auth()->id())->where('position', 2)->where('trx_type', '+')->orderBy('id', 'desc')->paginate(config('constants.table.default'));
            } elseif ($request->type == 'cutBV') {
                $data['page_title'] = "Cut BV";
                $data['logs'] = BvLog::where('user_id', auth()->id())->where('trx_type', '-')->orderBy('id', 'desc')->paginate(config('constants.table.default'));
            } else {
                $data['page_title'] = "All Paid BV";
                $data['logs'] = BvLog::where('user_id', auth()->id())->where('trx_type', '+')->orderBy('id', 'desc')->paginate(config('constants.table.default'));
            }
        } else {
            $data['page_title'] = "BV LOG";
            $data['logs'] = BvLog::where('user_id', auth()->id())->orderBy('id', 'desc')->paginate(config('constants.table.default'));
        }

        $data['empty_message'] = 'No data found';
        return view($this->activeTemplate . '.user.bvLog', $data);
    }

    public function myRefLog()
    {
        $data['page_title'] = "My Referral";
        $data['empty_message'] = 'No data found';
        $data['logs'] = User::where('ref_id', auth()->id())->latest()->paginate(config('constants.table.default'));
        return view($this->activeTemplate . '.user.myRef', $data);
    }

    public function myTree()
    {
        $data['tree'] = showTreePage(Auth::id());
        $data['page_title'] = "My Tree";
        // $data['logs'] = User::where('ref_id', auth()->id())->latest()->paginate(config('constants.table.default'));
        $data['logs'] = User::where('ref_id', auth()->id())->latest()->get();

        return view($this->activeTemplate . 'user.myTree', $data);
    }


    public function otherTree(Request $request, $username = null)
    {
        if ($request->username) {
            $user = User::where('username', $request->username)->first();
        } else {
            $user = User::where('username', $username)->first();
        }
        if ($user && treeAuth($user->id, auth()->id())) {
            $data['tree'] = showTreePage($user->id);
            $data['page_title'] = "Tree of " . $user->fullname;
            return view($this->activeTemplate . 'user.myTree', $data);
        }

        $notify[] = ['error', 'Tree Not Found or You do not have Permission to view that!!'];
        return redirect()->route('user.my.tree')->withNotify($notify);
    }
}
