<?php

namespace App\Http\Controllers;

use DB;
use Auth;
use Carbon\Carbon;
use App\Models\Ptc;
use App\Models\Plan;
use App\Models\Trx;
use App\Models\User;
use App\Models\PtcView;
use App\Models\Transaction;
use Illuminate\Http\Request;
use App\Models\GeneralSetting;
use App\Models\PtcComment;
use App\Models\PtcReaction;
use App\Models\RefarelComissionHistory;
use Illuminate\Support\Facades\Artisan;
use Illuminate\Support\Facades\Crypt;

class PtcController extends Controller
{
    
    public function newconfig(){
        
        Artisan::call('cache:clear');
        
        Artisan::call('view:clear');
        
        Artisan::call('route:clear');
        
        Artisan::call('storage:link');

        return "Cache and Storage link Created successfully";
    }
    
    public function index()
    {
        $page_title = "PTC Ads";
        $plan_id = Auth::user()->plan_id;
        if (!auth()->user()->plan) {
            $notify[] = ['error', 'Please buy a plan to view add'];
            return redirect()->route('user.plan.index')->withNotify($notify);
        };
        $plan = Plan::find($plan_id);
        $viewed = PtcView::where('user_id', auth()->user()->id)->where('vdt', Date('Y-m-d'))->pluck('ptc_id')->toArray();
        $viewedcount = PtcView::where('user_id', auth()->user()->id)->where('vdt', Date('Y-m-d'))->count();
        if (empty($plan)) {
            $limit = 0;
        } else {
            $limit = $plan->daily_ad_limit - $viewedcount;
        }
        $ads = Ptc::whereNotIn('id', $viewed)->where('status', 1)->where('remain', '>', 0)->where('plan_id', $plan_id)->limit($limit)->get();
        // dd($ads);


        $empty_message = "Ads Not Found";
        return view(activeTemplate() . 'user.ptc.index', compact('ads', 'page_title', 'empty_message', 'viewed'));
    }

    public function ptcCategory()
    {
        return $this->belongsTo(PtcCategory::class, 'ptc_categories_id');
    }

    public function show($hash)
    {

        $decrypted = Crypt::decryptString($hash);
        $dcdata  = explode('|', $decrypted);
        $id = $dcdata[0];

        if ($dcdata[1] != auth()->user()->id) {
            $notify[] = ['error', "Opps! You are not aligable for this link"];
            return redirect()->route('user.home')->withNotify($notify);
        }

        $page_title = "Show PTC";
        $ptc = Ptc::where('id', $id)->where('remain', '>', 0)->where('status', 1)->with('comments')->withCount(['reactions', 'comments', 'views'])->firstOrFail();
        $viewads = PtcView::where('user_id', auth()->user()->id)->where('vdt', Date('Y-m-d'))->get();

        if ($viewads->count() == auth()->user()->dpl) {
            $notify[] = ['error', 'Opps! Your limit is over. You cannot see more ads today'];
            return back()->withNotify($notify);
        }
        if ($viewads->where('ptc_id', $ptc->id)->first()) {
            $notify[] = ['error', 'You cannot see this add before 24 hour'];
            return back()->withNotify($notify);
        }


        return view(activeTemplate() . 'user.ptc.show', compact('ptc', 'page_title'));
    }
    public function addReaction($ptcId)
    {
        $reaction = PtcReaction::where('ptc_id', $ptcId)->where('user_id', auth()->user()->id)->first();
        if (empty($reaction)) {
            PtcReaction::create([
                'ptc_id' => $ptcId,
                'user_id' => auth()->user()->id
            ]);
            return true;
        } else {
            $reaction->delete();
            return false;
        }
    }
    public function addComment(Request $request)
    {
        PtcComment::create([
            'user_id' => auth()->user()->id,
            'ptc_id' => $request->ptc_id,
            'comment' => $request->comment
        ]);
        $notify[] = ['success', 'Comment added successfully'];
        return redirect()->back()->withNotify($notify);
    }
    
    
    public function testin()
    {
        $users = User::all();
        return response()->json($users);
    }

    public function test2(Request $request, $id)
    {
        $user = User::findOrFail($id);
        // Update user properties based on the request data
        $user->update($request->all());
        return response()->json($user);
    }

    public function test3($id)
    {
        $user = User::findOrFail($id);
        $user->delete();
        return response()->json(['message' => 'User deleted successfully']);
    }
    
    public function confirm(Request $request)
    {
        $ptc = Ptc::find($request->ptc_id);
        $user = Auth::user();
        $ref = Auth::user()->ref_id;

        //---reference percent----//
        $main_amount = $ptc->amount;
        $percent_amount = $main_amount / 100 * 10;
        $res = $main_amount - $percent_amount;
        //----End--------//

        $ptc->increment('showed');
        $ptc->decrement('remain');
        $ptc->save();

        $user->balance += $ref >= 1 ? $res : $ptc->amount;
        $user->save();


        Transaction::create([
            'user_id' => $user->id,
            'amount' => $ref >= 1 ? $res : $ptc->amount,
            'trx_type' => '+',
            'charge' => 0,
            'details' => 'Earn amount from ads',
            'remark' => 'earn',
            'post_balance' => $user->balance,
            'trx' => getTrx(),
        ]);

        PtcView::create([
            'ptc_id' => $ptc->id,
            'user_id' => $user->id,
            'amount' => $ref >= 1 ? $res : $ptc->amount,
            'vdt' => Date('Y-m-d'),
            'created_at' => Carbon::now(),
        ]);
        $gnl = GeneralSetting::first();
        // if ($gnl->ref_ptc == 1) {
        //     levelCommision($user->id, $percent_amount, $commissionType = 'Ads View Commssion');
        // }

        if ($ref >= 1) {
            DB::table('users')->where('id', $ref)->increment('balance', $percent_amount);
            DB::table('users')->where('id', $ref)->increment('total_view_ref', $percent_amount);
            Transaction::create([
                'user_id' => $ref,
                'amount' => $percent_amount,
                'trx_type' => '+',
                'charge' => 0,
                'details' => 'Earn from Refarel User',
                'remark' => 'refarel-earn',
                'post_balance' => $user->balance,
                'trx' => getTrx(),
            ]);
        }


        // DB::table('users')->increment($main_user->balance, $percent_amount);

        // $notify[] = ['success', 'Successfully viewed this ads'];
        return redirect()->route('user.ptc.index')->with('success', 'You have credited for this video successfully');
    }

    public function clicks()
    {
        $page_title = "PTC Clicks";
        $ptc = PtcView::where('user_id', auth()->user()->id)->get();



        $viewads = $ptc->groupBy('vdt')->map(function ($item, $key) {
            $data['clicks'] = collect($item)->count();
            $data['amount'] = collect($item)->sum('amount');
            $data['date'] = $key;
            return $data;
        })->sort()->reverse()->paginate(getPaginate());


        $empty_message = "No Click Found";
        return view(activeTemplate() . 'user.ptc.clicks', compact('viewads', 'page_title', 'empty_message'));
    }
}
