<?php

namespace App\Http\Controllers\User;

use Session;
use Carbon\Carbon;
use App\Models\Ptc;
use App\Models\Plan;
use App\Models\User;
use App\Models\Deposit;
use App\Models\PtcView;
use App\Models\Voucher;
use App\Mail\DepositMail;
use App\Models\UserLogin;
use App\Models\PtcComment;
use App\Models\Withdrawal;
use App\Models\PtcReaction;
use App\Models\Transaction;
use Illuminate\Http\Request;
use App\Http\Livewire\Diposit;
use App\Models\GeneralSetting;
use App\Models\AdminNotification;
use Illuminate\Support\Facades\DB;
use App\Http\Controllers\Controller;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\Mail;
use Illuminate\Support\Facades\Crypt;

class UserController extends Controller
{
    public function dashboard()
    {
        $total_withdraw = Withdrawal::where('user_id', auth()->user()->id)->where('status', 1)->get();
        $plan_id = auth()->user()->plan_id;
        $plan_updated_at = auth()->user()->plan_updated_at;
        $plan = Plan::find($plan_id);
        if (!empty($plan)) {
            // plan expired days
            $user = auth()->user();
            $duration = $user->plan->duration;
            $expiredDate = Carbon::parse($user->plan_updated_at)->addDays($duration);
            if($expiredDate < Carbon::now()){
                $user->update([
                   'plan_id' => 0
                ]);
            };
            $expiredDays = $expiredDate->diffInDays(Carbon::now());

            if (!Session::has('displayExpire') || Session::get('displayExpireTime') < now()) {
                Session::put('displayExpire', true);
                Session::put('displayExpireTime', now()->addHours(24));
            }
            
            $expiredDate = Carbon::parse($expiredDate)->format('Y-m-d');

            $ads = Ptc::withCount('views')
            ->where('status', 1)
            ->where('remain', '>', 0)
            ->where('plan_id', $plan_id)
            ->paginate(10);

            // plan expired days end
            $viewed = PtcView::where('user_id', auth()->user()->id)->where('vdt', Date('Y-m-d'))->count();
            $limit = $plan->daily_ad_limit ?? 0 - $viewed;
            // dd($limit);

            $count = Ptc::where('status', 1)->where('remain', '>', 0)->where('plan_id', $plan_id)->limit($plan->daily_ad_limit)->get();
            $ads_count = count($count);

            $ads_remaning = $ads_count - $viewed;
            if ($ads_count == 0) {
                $ads_count = 1;
            }
            $adpercent =  100 / $ads_count;
            $ads_remaning_percent = (int) round($adpercent * $ads_remaning, 0);
        } else {
            $expiredDays = 0;
            $expiredDate = 0;
            $ads_remaning_percent = 100;
            $ads_remaning = 0;
        }
        $data['ads_remaning_percent'] = $ads_remaning_percent;
        $notice = GeneralSetting::first();
        $all_notice =  $notice->notice;
        //Chart Data
        $dailyData = Transaction::where('user_id', auth()->user()->id)->select(
            DB::raw('SUM(CASE WHEN remark = "refarel_earn" THEN amount ELSE 0 END) as video_income'),
            DB::raw('DATE(created_at) as day')
        )
            ->groupBy('day')
            ->get();

        $dailyUser = User::where('ref_id', auth()->user()->id)->select(
            DB::raw('COUNT(id) as row_count'),
            DB::raw('DATE(created_at) as day')
        )
            ->groupBy('day')
            ->get();
        $data['chartData'] = [
            'labels' => $dailyData->pluck('day'),
            'datasets' => [
                [
                    'label' => 'Refarel User',
                    'data' => $dailyUser->pluck('row_count'),
                    'fill' => false,
                ],
                [
                    'label' => 'Referral Income',
                    'data' => $dailyData->pluck('video_income'),
                    'fill' => false,
                ],
            ],
        ];
        //Daily Refarel Count 
        $referrals = User::where('ref_id', auth()->user()->id)->select(
            DB::raw('COUNT(id) as row_count'),
            DB::raw('DATE(created_at) as day')
        )
            ->groupBy('day')
            ->get();

        $labels = $referrals->pluck('day');
        $refareldata = $referrals->pluck('row_count');

        //Daily Views Chart
        $watchCounts = PtcView::where('user_id', auth()->user()->id)->selectRaw('DATE(created_at) as date, COUNT(*) as count')
            ->groupBy('date')
            ->get();

        $watchlabels = $watchCounts->pluck('date');
        $watchdata = $watchCounts->pluck('count');
        //Money Credited Chart
        $depositCounts = Deposit::where('user_id', auth()->user()->id)->selectRaw('DATE(created_at) as date, SUM(amount) as total_amount')
            ->groupBy('date')
            ->get();

        $creditedlabels = $depositCounts->pluck('date');
        $crediteddata = $depositCounts->pluck('total_amount');
        //latest
        $latest_balance_log = Auth::user()->transactions()->latest()->paginate(5);
        $latest_history_log = Withdrawal::where('user_id', auth()->user()->id)->latest()->paginate(5);
        $data['serverTime'] = Carbon::now();
        return view('user.dashboard', $data, compact('expiredDate', 'ads','all_notice', 'expiredDays', 'total_withdraw', 'labels', 'refareldata', 'watchlabels', 'watchdata', 'creditedlabels', 'crediteddata', 'latest_balance_log', 'latest_history_log'));
    }
    public function proofs()
    {
        $withdrawals = Withdrawal::where('status', 1)->latest()->paginate(8);
        return view('user.proofs');
    }

    public function planList()
    {
        return view('user.plan-list');
    }
    public function login()
    {
        return view('user.login');
    }
    public function showWithoutRefRegistrationForm()
    {
        $status = GeneralSetting::get();
        $status = $status->first()->registration;
        if ($status == 1) {
            return view('user.without-ref-register');
        } else {
            return back()->with('alert', 'Registration is currently not available!');
        }
    }
    public function register()
    {
        $status = GeneralSetting::get();
        $status = $status->first()->registration;
        if ($status == 1) {
            return view('user.register');
        } else {
            return back()->with('alert', 'Registration is currently not available!');
        }
    }
    public function deposit()
    {

        return view('user.deposit');
    }
    public function depositPost(Request $request)
    {
        $gnl = GeneralSetting::first();
        $data = Deposit::where('trx', $request->PAYMENT_ID)->first();
        if ($request->PAYMENT_BATCH_NUM != 0) {
            $data->status = 1;
            $data->save();
            $user = User::find($data->user_id);
            $user->total_invest += $data->amount;
            $user->save();
            $gateway = $data->gateway;
            $transaction = new Transaction();
            $transaction->user_id = $data->user_id;
            $transaction->amount = $data->amount;
            $transaction->post_balance = getAmount($user->total_invest);
            $transaction->charge = getAmount($data->charge);
            $transaction->trx_type = '+';
            $transaction->details = 'Deposit Via ' . $data->gateway_currency()->name;
            $transaction->trx = $data->trx;
            $transaction->save();
            //Send Mail To User

            Auth::login($user);
            $notify[] = ['success', 'Deposit Successfully Done. Deposit Amount Is:' . User::convertToUsdWithCurrency($data->amount) . ', And Deposit Charge Is : ' . User::convertToUsdWithCurrency($data->charge) ?? 0];

            return view('deposit_redirect');
        } else {
            $user = User::find($data->user_id);
            Auth::login($user);
            return redirect()->route('user.depositcancle');
        }
    }

    public function useVoucher()
    {
        $use_voucher = Voucher::where('rec_id', Auth::id())->get();
        return view('user.use-voucher', compact('use_voucher'));
    }
    public function useStore(Request $request)
    {

        $gnl = GeneralSetting::first();
        $user_id = Auth::user()->id;
        $voucher = voucher::where('voucher_code', $request->voucher_code)->where('rec_id', 0)->where('voucher_limit', 0)->first();
        if ($voucher) {

            $data = Voucher::find($voucher->id);

            $data->status = 1;
            $data->valid = 0;
            $data->rec_id = Auth::id();
            $data->voucher_limit = 1;
            $data->save();

            $characters = '0123456789ABCDEFGHIJKLMNOPQRSTUVWXYZ';

            $length = 12;
            $charactersLength = strlen($characters);
            $randomString = '';
            for ($i = 0; $i < $length; $i++) {
                $randomString .= $characters[rand(0, $charactersLength - 1)];
            }

            $trans = new Transaction;
            $trans->user_id = Auth::id();
            $trans->amount = $voucher->voucher_amount;
            $trans->charge = 0.00000000;
            $trans->post_balance = Auth::user()->balance + $voucher->voucher_amount;
            $trans->trx_type = '+';
            $trans->trx = $randomString;
            $trans->details = 'Voucher Recharge';
            $trans->save();

            User::where('id', Auth::id())->increment('total_invest', $voucher->voucher_amount);

            $voucher = $voucher->voucher_amount;
            $comission = $voucher / 100 * 10;

            $user = User::where('id', $data->user_id)->increment('balance', $comission);
            $user = User::where('id', $data->user_id)->first();



            $trans = new Transaction;
            $trans->user_id = $data->user_id;
            $trans->amount = $comission;
            $trans->charge = 0.00000000;
            $trans->post_balance = $user->balance;
            $trans->trx_type = '+';
            $trans->trx = $randomString;
            $trans->details = 'Voucher Comission';
            $trans->save();
            // Send email notification to the voucher receiver
            if ($gnl->mail_notification == 1) {
                $rec_user = User::find(auth()->user()->id);
                $subject = "Voucher Recharge Done. Voucher Amount Is :" . User::currency($data->voucher_amount);
                $message =
                    "Voucher Recharge Done. Voucher Amount Is : " . User::currency($data->voucher_amount);
                sendGeneralEmail($rec_user->email, $subject, $message, $rec_user->username);

                // Send email notification to the voucher sender
                $subject = "Your created voucher recharged successfully";
                $message = "Your created voucher recharged successfully. You have received a comission from " . $rec_user->username . '. Comission amount is ' . User::currency($comission);
                sendGeneralEmail($user->email, $subject, $message, $user->username);
            }

            session()->flash('success', 'Congrats ! Successfully used The voucher.');
            return back();
        } else {
            session()->flash('error', 'Oh ! Invalid Voucher.');
            return back();
        }
    }

    public function depositConfirm()
    {
        $track = Session::get('Track');
        $deposit = Deposit::where('trx', $track)->orderBy('id', 'DESC')->with('gateway')->first();
        if (is_null($deposit)) {
            $notify[] = ['error', 'Invalid Deposit Request'];
            return redirect()->route(gatewayRedirectUrl())->withNotify($notify);
        }
        if ($deposit->status != 0) {
            $notify[] = ['error', 'Invalid Deposit Request'];
            return redirect()->route(gatewayRedirectUrl())->withNotify($notify);
        }

        if ($deposit->method_code >= 1000) {
            $this->userDataUpdate($deposit);
            $notify[] = ['success', 'Your deposit request is queued for approval.'];
            return back()->withNotify($notify);
        }


        $dirName = $deposit->gateway->alias;
        $new = 'App\Http\Controllers\Gateway' . '\\' . $dirName . '\\ProcessController';

        $data = $new::process($deposit);
        $data = json_decode($data);


        if (isset($data->error)) {
            $notify[] = ['error', $data->message];
            return redirect()->route(gatewayRedirectUrl())->withNotify($notify);
        }
        if (isset($data->redirect)) {
            return redirect($data->redirect_url);
        }

        // for Stripe V3
        if (@$data->session) {
            $deposit->btc_wallet = $data->session->id;
            $deposit->save();
        }
        $page_title = 'Payment Confirm';
        return redirect()->route('user.dashboard');
        // return view($this->activeTemplate . $data->view, compact('data', 'page_title', 'deposit'));
    }
    public function manualDepositUpdate(Request $request)
    {
        $track = session()->get('Track');
        $data = Deposit::with('gateway')->where('status', 0)->where('trx', $track)->first();
        if (!$data) {
            return redirect()->route(gatewayRedirectUrl());
        }
        if ($data->status != 0) {
            return redirect()->route(gatewayRedirectUrl());
        }

        $params = json_decode($data->gateway_currency()->gateway_parameter);

        $rules = [];
        $inputField = [];
        $verifyImages = [];

        if ($params != null) {
            foreach ($params as $key => $cus) {
                $rules[$key] = [$cus->validation];
                if ($cus->type == 'file') {
                    array_push($rules[$key], 'image');
                    array_push($rules[$key], 'mimes:jpeg,jpg,png');
                    array_push($rules[$key], 'max:2048');

                    array_push($verifyImages, $key);
                }
                if ($cus->type == 'text') {
                    array_push($rules[$key], 'max:191');
                }
                if ($cus->type == 'textarea') {
                    array_push($rules[$key], 'max:300');
                }
                $inputField[] = $key;
            }
        }


        $this->validate($request, $rules);


        $directory = date("Y") . "/" . date("m") . "/" . date("d");
        $path = imagePath()['verify']['deposit']['path'] . '/' . $directory;
        $collection = collect($request);
        $reqField = [];
        if ($params != null) {
            foreach ($collection as $k => $v) {
                foreach ($params as $inKey => $inVal) {
                    if ($k != $inKey) {
                        continue;
                    } else {
                        if ($inVal->type == 'file') {
                            if ($request->hasFile($inKey)) {
                                try {
                                    $reqField[$inKey] = [
                                        // 'field_name' => $directory . '/' . uploadImage($request[$inKey], $path),
                                        'field_name' => $request[$inKey]->store('/', 'public'),
                                        'type' => $inVal->type,
                                    ];
                                } catch (\Exception $exp) {
                                    $notify[] = ['error', 'Could not upload your ' . $inKey];
                                    return back()->withNotify($notify)->withInput();
                                }
                            }
                        } else {
                            $reqField[$inKey] = $v;
                            $reqField[$inKey] = [
                                'field_name' => $v,
                                'type' => $inVal->type,
                            ];
                        }
                    }
                }
            }
            $data->detail = $reqField;
        } else {
            $data->detail = null;
        }
        $data->status = 2; // pending
        if($data->method_code == 1011){
            $data->btc_amo = $request->crypto_amount;
            $data->btc_wallet = $request->crypto_name;
        }
        $data->save();
        $adminNotification = new AdminNotification();
        $adminNotification->user_id = $data->user->id;
        $adminNotification->title = 'Deposit request from ' . $data->user->username;
        $adminNotification->click_url = route('admin.deposit.details', $data->id);
        $adminNotification->save();

        $gnl = GeneralSetting::first();
        //Send Mail To User
        if ($gnl->mail_notification == 1) {
            $id = $data->id;

            $deposit = Deposit::find($id);
            $subject = "Your deposite details";
            $message = 'Deposit Amount Is:' . User::convertToUsdWithCurrency($deposit->amount) . ', And Deposit Charge Is : ' . User::convertToUsdWithCurrency($deposit->charge) ?? 0;

            sendGeneralEmail(auth()->user()->email, $subject, $message, auth()->user()->username);
        }
        $notify[] = ['success', 'Deposit Request Successfully Send. Deposit Amount Is:' . User::convertToUsdWithCurrency($data->amount) . ', And Deposit Charge Is : ' . User::convertToUsdWithCurrency($data->charge) ?? 0];

        if($data->method_code == 1011){
            return redirect()->route('user.deposit.crypto.success');
        }

        return redirect()->route('user.dashboard')->withNotify($notify);
    }

    public function depositVoucher()
    {
        if (auth()->user()->is_agent == 2) {
            return view('user.deposit-voucher');
        } else {
            $notify[] = ['error', "Opps! You are not aligable for this link"];
            return redirect()->back()->withNotify($notify);
        }
    }
    public function watch2earn()
    {
        return view('user.watch2earn');
    }
    public function show($hash)
    {

        $decrypted = Crypt::decryptString($hash);
        $dcdata  = explode('|', $decrypted);
        $id = $dcdata[0];

        if ($dcdata[1] != auth()->user()->id) {
            $notify[] = ['error', "Opps! You are not aligable for this link"];
            return redirect()->route('user.home')->withNotify($notify);
        }

        $page_title = "Show PTC";
        $ptc = Ptc::where('id', $id)->where('remain', '>', 0)->where('status', 1)->with('comments')->withCount(['reactions', 'comments', 'views'])->firstOrFail();
        $viewads = PtcView::where('user_id', auth()->user()->id)->where('vdt', Date('Y-m-d'))->get();
        $plan = Plan::find(auth()->user()->plan_id);
        if ($viewads->count() == $plan->daily_ad_limit) {
            $notify[] = ['error', 'Opps! Your limit is over. You cannot see more ads today'];
            return back()->withNotify($notify);
        }
        if ($viewads->where('ptc_id', $ptc->id)->first()) {
            $notify[] = ['error', 'You cannot see this add before 24 hour'];
            return back()->withNotify($notify);
        }
        $plan_id = Auth::user()->plan_id;
        if (!auth()->user()->plan) {
            $notify[] = ['error', 'Please buy a plan to view add'];
            return redirect()->route('user.plan.index')->withNotify($notify);
        };
        $plan = Plan::find($plan_id);
        $viewed = PtcView::where('user_id', auth()->user()->id)->where('vdt', Date('Y-m-d'))->pluck('ptc_id')->toArray();
        $viewedcount = PtcView::where('user_id', auth()->user()->id)->where('vdt', Date('Y-m-d'))->count();
        if (empty($plan)) {
            $limit = 0;
        } else {
            $limit = $plan->daily_ad_limit - $viewedcount;
        }
        array_push($viewed, $ptc->id);
        $ads = Ptc::withCount('views')->whereNotIn('id', $viewed)->where('status', 1)->where('remain', '>', 0)->where('plan_id', $plan_id)->limit($limit)->get();
        return view('user.ptc-show', compact('ptc', 'ads', 'viewed'));
    }
    public function ptcConfirm(Request $request)
    {
        $ptc = Ptc::find($request->ptc_id);
        $user = Auth::user();
        $ref = Auth::user()->ref_id;

        //---reference percent----//
        $main_amount = $ptc->amount;
        if($ref >= 1){
            $ref_user = DB::table('users')->where('id', $ref)->first();
            $ref_plan_id = $ref_user->plan_id;
            $ref_plan = DB::table('plans')->where('id', $ref_plan_id)->first();
            
            $percent_amount = $main_amount * ($ref_plan->refarel_commision / 100);
            // $res = $main_amount - $percent_amount;
            //----End--------//
        }

        $ptc->increment('showed');
        $ptc->decrement('remain');
        $ptc->save();

        $user->balance += $ptc->amount;
        $user->save();


        Transaction::create([
            'user_id' => $user->id,
            'amount' => $ptc->amount,
            'trx_type' => '+',
            'charge' => 0,
            'details' => 'Earn amount from ads',
            'remark' => 'earn',
            'post_balance' => $user->balance,
            'trx' => getTrx(),
        ]);

        PtcView::create([
            'ptc_id' => $ptc->id,
            'user_id' => $user->id,
            'amount' => $ptc->amount,
            'vdt' => Date('Y-m-d'),
            'created_at' => Carbon::now(),
        ]);
        $gnl = GeneralSetting::first();
        // if ($gnl->ref_ptc == 1) {
        //     levelCommision($user->id, $percent_amount, $commissionType = 'Ads View Commssion');
        // }
        if ($ref >= 1) {
            DB::table('users')->where('id', $ref)->increment('balance', $percent_amount);
            Transaction::create([
                'user_id' => $ref,
                'amount' => $percent_amount,
                'trx_type' => '+',
                'charge' => 0,
                'details' => 'Earn amount from refarel user ads',
                'remark' => 'refarel_earn',
                'post_balance' => 0,
                'trx' => getTrx(),
            ]);
        }


        // DB::table('users')->increment($main_user->balance, $percent_amount);

        // $notify[] = ['success', 'Success! You Have Earned ' . $ptc->amount];
        // return redirect()->route('user.watch2earn')->withNotify($notify);
        // return 'Success! You Have Earned ' . $ptc->amount;
        return 'Success! You Have Earned ' . User::currency(number_format(floatval($ptc->amount), 2, '.', ','), 0, 1);
    }

    public function depositLog(){
        $data['page_title'] = "Deposit Log";
        $data['deposits'] = Deposit::where('user_id', Auth::id())->where('status', '!=', 0)->with('gateway')->latest()->paginate(20);
        $data['empty_message'] = "No Data Found!";
        return view('user.deposit.log', $data);
    }

    public function addReaction($ptcId)
    {
        $reaction = PtcReaction::where('ptc_id', $ptcId)->where('user_id', auth()->user()->id)->first();
        if (empty($reaction)) {
            PtcReaction::create([
                'ptc_id' => $ptcId,
                'user_id' => auth()->user()->id
            ]);
            return true;
        } else {
            $reaction->delete();
            return false;
        }
    }
    public function addComment(Request $request)
    {
        PtcComment::create([
            'user_id' => auth()->user()->id,
            'ptc_id' => $request->ptc_id,
            'comment' => $request->comment
        ]);
        $notify[] = ['success', 'Comment added successfully'];
        return redirect()->back()->withNotify($notify);
    }
    public function directRefarel()
    {
        $data['last_login'] = UserLogin::where('user_id', auth()->user()->id)->latest()->first();
        $data['refarel_users'] = User::where('ref_id', auth()->id())->latest()->get();
        $data['active_users'] = User::where('ref_id', auth()->id())->where('status', 1)->count();
        //Refarels direct deposit
        $data['refarels_deposit'] = Deposit::whereIn('user_id', $data['refarel_users']->pluck('id'))->get();
        $data['refarels_earn'] = Transaction::whereIn('remark', ['refarels_deposit', 'referral_commission', 'plan_update_refarel_comission', 'refarel_earn'])->where('user_id', auth()->user()->id)->get();
        return view('user.direct-refarel', $data);
    }
    public function promoMaterials()
    {
        return view('user.promo-materials');
    }
    public function depositVoucherDistributor()
    {
        return view('user.voucher-distributor');
    }
    public function agentByCountry($country)
    {
        $agents = User::where('country', $country)->where('is_agent', 2)->get();
        return view('user.agentlist', compact('agents', 'country'));
    }
    public function applyForAgent()
    {
        return view('user.apply-for-agent');
    }
    public function Statistics()
    {
        $myincome = Transaction::where('user_id', auth()->user()->id)->select(
            DB::raw('SUM(CASE WHEN details = "Earn amount from ads" THEN amount ELSE 0 END) as my_income'),
            DB::raw('DATE(created_at) as day')
        )
            ->groupBy('day')
            ->get();
        $myIncomeLabels = $myincome->pluck('day');
        $myIncomeData = $myincome->pluck('my_income');
        //Refarel Income
        $myincome = Transaction::where('user_id', auth()->user()->id)->select(
            DB::raw('SUM(CASE WHEN details = "Earn amount from refarel user ads" THEN amount ELSE 0 END) as my_income'),
            DB::raw('DATE(created_at) as day')
        )
            ->groupBy('day')
            ->get();
        $refarelIncomeLabels = $myincome->pluck('day');
        $refarelIncomeData = $myincome->pluck('my_income');
        return view('user.statistics', compact('myIncomeLabels', 'myIncomeData', 'refarelIncomeLabels', 'refarelIncomeData'));
    }
    public function profile()
    {
        return view('user.profile');
    }
    public function settings()
    {
        return view('user.settings');
    }
    public function transcationLog()
    {
        return view('user.transcation-log');
    }
    public function transfer()
    {
        return view('user.transfer');
    }
    public function logout()
    {
        $this->guard()->logout();

        request()->session()->invalidate();

        $notify[] = ['success', 'You have been logged out.'];
        return redirect('/')->withNotify($notify);
    }
}
