<?php

namespace App\Http\Controllers\User;

use App\Models\User;
use App\Mail\OtpMail;
use App\Models\Withdrawal;
use App\Models\Transaction;
use Illuminate\Support\Str;
use Illuminate\Http\Request;
use App\Models\GeneralSetting;
use App\Models\WithdrawMethod;
use App\Models\AdminNotification;
use App\Http\Controllers\Controller;
use App\Mail\WithdrawMail;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\Mail;

class WithdrawController extends Controller
{

    public function withdrawMoney()
    {
        $data['page_title'] = "Withdraw Money";
        return view('user.withdraw.methods', $data);
    }

    public function withdrawStore(Request $request)
    {
        $this->validate($request, [
            'method_code' => 'required',
            'amount' => 'required|numeric'
        ]);
        $amount = User::convertToUsd($request->amount);
        $method = WithdrawMethod::where('id', $amount)->where('status', 1)->firstOrFail();
        $user = auth()->user();
        if ($amount < $method->min_limit) {
            $notify[] = ['error', 'Your Requested Amount is Smaller Than Minimum Amount.'];
            return back()->withNotify($notify);
        }
        if ($amount > $method->max_limit) {
            $notify[] = ['error', 'Your Requested Amount is Larger Than Maximum Amount.'];
            return back()->withNotify($notify);
        }
        dd($amount);
        if ($amount > $user->balance) {
            $notify[] = ['error', 'Your do not have Sufficient Balance For Withdraw.'];
            return back()->withNotify($notify);
        }


        $charge = $method->fixed_charge + ($amount * $method->percent_charge / 100);
        $afterCharge = $amount - $charge;
        $finalAmount = getAmount($afterCharge * $method->rate);

        $withdraw = new Withdrawal();
        $withdraw->method_id = $method->id; // wallet method ID
        $withdraw->user_id = $user->id;
        $withdraw->amount = getAmount($amount);
        $withdraw->currency = $method->currency;
        $withdraw->rate = $method->rate;
        $withdraw->charge = $charge;
        $withdraw->final_amount = $finalAmount;
        $withdraw->after_charge = $afterCharge;
        $withdraw->trx = getTrx();
        $withdraw->save();
        session()->put('wtrx', $withdraw->trx);
        return redirect()->route('user.withdraw.preview');
    }

    public function withdrawVerify()
    {
        $data['page_title'] = "Withdraw Verify";
        return view('user.withdraw.verify', $data);
    }
    public function withdrawVerifySubmit(Request $request)
    {
        $withdraw = Withdrawal::with('method', 'user')->where('trx', session()->get('wtrx'))->where('status', 0)->latest()->firstOrFail();
        if ($withdraw->otp == $request->otp) {
            return redirect()->route('user.withdraw.preview');
        } else {
            $notify[] = ['error', 'Otp Doesnot Match'];
            return redirect()->back()->withNotify($notify);
        }
    }

    public function withdrawPreview()
    {
        $data['withdraw'] = Withdrawal::with('method', 'user')->where('trx', session()->get('wtrx'))->where('status', 4)->latest()->firstOrFail();
        $data['page_title'] = "Withdraw Preview";
        $method = $data['withdraw']->method->name;
        $paymentid = '';
        if ($method == 'Perfect Money') {
            $paymentid = auth()->user()->perfect_address;
        } else if ($method == 'Payeer') {
            $paymentid = auth()->user()->payeer_address;
        }
        $data['paymentid'] = $paymentid;
        return view('user.withdraw.preview', $data);
    }


    public function withdrawSubmit(Request $request)
     {

        $general = GeneralSetting::first();
        $withdraw = Withdrawal::with('method', 'user')->where('trx', session()->get('wtrx'))->where('status', 4)->latest()->firstOrFail();
        
        $rules = [];
        $inputField = [];
        if ($withdraw->method->user_data != null) {
            foreach ($withdraw->method->user_data as $key => $cus) {
                $rules[$key] = [$cus->validation];
                if ($cus->type == 'file') {
                    array_push($rules[$key], 'image');
                    array_push($rules[$key], 'mimes:jpeg,jpg,png');
                    array_push($rules[$key], 'max:2048');
                }
                if ($cus->type == 'text') {
                    array_push($rules[$key], 'max:191');
                }
                if ($cus->type == 'textarea') {
                    array_push($rules[$key], 'max:300');
                }
                $inputField[] = $key;
            }
        }
        $this->validate($request, $rules);
        $user = auth()->user();

        if (getAmount($withdraw->amount) > $user->balance) {
            $notify[] = ['error', 'Your Request Amount is Larger Then Your Current Balance.'];
            return back()->withNotify($notify);
        }

        $withdraw->withdraw_information = $request->account_id ?? '';
        $withdraw->status = 2;
        $withdraw->save();
        $user->balance  -=  $withdraw->amount;
        $user->save();



        $transaction = new Transaction();
        $transaction->user_id = $withdraw->user_id;
        $transaction->amount = getAmount($withdraw->amount);
        $transaction->post_balance = getAmount($user->balance);
        $transaction->charge = getAmount($withdraw->charge);
        $transaction->trx_type = '-';
        $transaction->details = getAmount($withdraw->final_amount) . ' ' . $withdraw->currency . ' Withdraw Via ' . $withdraw->method->name;
        $transaction->trx =  $withdraw->trx;
        $transaction->save();

        $adminNotification = new AdminNotification();
        $adminNotification->user_id = $user->id;
        $adminNotification->title = 'New withdraw request from ' . $user->username;
        $adminNotification->click_url = route('admin.withdraw.details', $withdraw->id);
        $adminNotification->save();

        //Send Mail To User
        if ($general->mail_notification == 1) {
            
              $id = $withdraw->id;
              $subject = "Your Withdraw details";
              $withdraw = Withdrawal::find($id);
              $message = 'Withdraw Amount Is:' . User::convertToUsdWithCurrency($withdraw->amount) . ', And Withdraw Charge Is : ' . User::convertToUsdWithCurrency($withdraw->charge) ?? 0;

              
              sendGeneralEmail($user->email, $subject, $message, $user->username);
        }
        $notify[] = ['success', 'Withdraw Request Successfully Send. Withdraw Amount Is:' . User::convertToUsdWithCurrency($withdraw->amount) . ', And Withdraw Charge Is : ' . User::convertToUsdWithCurrency($withdraw->charge) ?? 0];
        return redirect()->route('user.dashboard')->withNotify($notify);
     }

    public function withdrawLog()
    {
        $data['page_title'] = "Withdraw Log";
        $data['withdraws'] = Withdrawal::where('user_id', Auth::id())->where('status', '!=', 0)->with('method')->latest()->paginate(20);
        $data['empty_message'] = "No Data Found!";
        return view('user.withdraw.log', $data);
    }
}
