<?php

namespace App\Http\Controllers;

use Image;
use Validator;
use Carbon\Carbon;
use App\Models\Ptc;
use App\Models\Plan;
use App\Models\User;
use App\Models\BvLog;
use App\Models\Deposit;
use App\Models\PtcView;
use App\Models\Withdrawal;
use App\Models\Transaction;
use Illuminate\Http\Request;
use App\Models\GeneralSetting;
use App\Models\WithdrawMethod;
use App\Lib\GoogleAuthenticator;
use App\Models\AdminNotification;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\Hash;

class UserController extends Controller
{
    public function invite()
    {
        return view('templates.basic.user.invite_earn');
    }
    public function Statistics()
    {
        $users = User::all();
        foreach ($users as $user) {
            $duration = $user->plan->duration;
            $expiredDate = Carbon::parse($user->plan_updated_at)->addDays($duration);
            if ($expiredDate < Carbon::now()) {
                $user->update([
                    'plan_id' => 0,
                ]);
            }
        }
        $login_logs = auth()->user()->login_logs()->latest()->paginate(getPaginate(1));
        $withdrawals = Withdrawal::where('status', 1)->with(['user', 'method'])->latest()->paginate(getPaginate());
        $ptc = PtcView::where('user_id', auth()->user()->id)->get(['vdt', 'amount']);
        $data['page_title']         = "Dashboard";
        $data['totalDeposit']       = Deposit::where('user_id', auth()->id())->where('status', 1)->sum('amount');
        $data['totalWithdraw']      = Withdrawal::where('user_id', auth()->id())->where('status', 1)->sum('amount');
        $data['completeWithdraw']   = Withdrawal::where('user_id', auth()->id())->where('status', 1)->count();
        $data['pendingWithdraw']    = Withdrawal::where('user_id', auth()->id())->where('status', 2)->count();
        $data['rejectWithdraw']     = Withdrawal::where('user_id', auth()->id())->where('status', 3)->count();
        $data['total_ref']          = User::where('ref_id', auth()->id())->count();
        $data['totalBvCut']         = BvLog::where('user_id', auth()->id())->where('trx_type', '-')->sum('amount');
        $data['amount']             = $ptc->groupBy('vdt')->map(function ($item, $key) {
            return collect($item)->sum('amount');
        })->sort()->reverse()->take(7)->toArray();

        $chart['click'] = $ptc->groupBy('vdt')->map(function ($item, $key) {
            return collect($item)->count();
        })->sort()->reverse()->take(7)->toArray();

        $chart['amount'] = $ptc->groupBy('vdt')->map(function ($item, $key) {
            return collect($item)->sum('amount');
        })->sort()->reverse()->take(7)->toArray();

        $plan_id = auth()->user()->plan_id;
        $plan_updated_at = auth()->user()->plan_updated_at;
        if ($plan_id == 0 && !is_null($plan_updated_at)) {
            $data['planExpired'] = true;
        } else {
            $data['planExpired'] = false;
        }
        return view('templates.basic.user.statistics', $data, compact('chart', 'withdrawals', 'login_logs'));
    }
    public function __construct()
    {
        $this->activeTemplate = activeTemplate();
    }
    public function view()
    {
        $data['page_title'] = "Profile Setting";
        $data['user'] = Auth::user();
        $plan_id = Auth::user()->plan_id;
        $plan = Plan::find($plan_id);
        $top_rated_viewed = PtcView::where('user_id', auth()->user()->id)->where('vdt', Date('Y-m-d'))->pluck('ptc_id')->toArray();
        $viewedcount = PtcView::where('user_id', auth()->user()->id)->where('vdt', Date('Y-m-d'))->count();
        if (empty($plan)) {
            $limit = 0;
        } else {
            $limit = $plan->daily_ad_limit - $viewedcount;
        }
        $top_rated_ads = Ptc::whereNotIn('id', $top_rated_viewed)->withCount('reactions')->where('status', 1)->where('remain', '>', 0)->where('plan_id', $plan_id)->limit($limit)->orderBy('reactions_count', 'desc')->get();

        $users = User::all();
        // foreach ($users as $user) {
        //     $duration = $user->plan->duration;
        //     $expiredDate = Carbon::parse($user->plan_updated_at)->addDays($duration);
        //     if ($expiredDate < Carbon::now()) {
        //         $user->update([
        //             'plan_id' => 0,
        //         ]);
        //     }
        // }
        $data['totaluser'] = $users->count();
        $login_logs = auth()->user()->login_logs()->latest()->paginate(getPaginate(1));
        $withdrawals = Withdrawal::where('status', 1)->with(['user', 'method'])->latest()->paginate(getPaginate());
        $ptc = PtcView::where('user_id', auth()->user()->id)->get(['vdt', 'amount']);
        $data['page_title']         = "Dashboard";
        $data['totalDeposit']       = Deposit::where('user_id', auth()->id())->where('status', 1)->sum('amount');
        $data['totalWithdraw']      = Withdrawal::where('user_id', auth()->id())->where('status', 1)->sum('amount');
        $data['totalEarn']      = User::sum('total_view_ref');
        $data['completeWithdraw']   = Withdrawal::where('user_id', auth()->id())->where('status', 1)->count();
        $data['pendingWithdraw']    = Withdrawal::where('user_id', auth()->id())->where('status', 2)->count();
        $data['rejectWithdraw']     = Withdrawal::where('user_id', auth()->id())->where('status', 3)->count();
        $data['total_ref']          = User::where('ref_id', auth()->id())->count();
        $data['totalBvCut']         = BvLog::where('user_id', auth()->id())->where('trx_type', '-')->sum('amount');
        $data['amount']             = $ptc->groupBy('vdt')->map(function ($item, $key) {
            return collect($item)->sum('amount');
        })->sort()->reverse()->take(7)->toArray();

        $chart['click'] = $ptc->groupBy('vdt')->map(function ($item, $key) {
            return collect($item)->count();
        })->sort()->reverse()->take(7)->toArray();

        $chart['amount'] = $ptc->groupBy('vdt')->map(function ($item, $key) {
            return collect($item)->sum('amount');
        })->sort()->reverse()->take(7)->toArray();

        $plan_id = auth()->user()->plan_id;
        $plan_updated_at = auth()->user()->plan_updated_at;
        if ($plan_id == 0 && !is_null($plan_updated_at)) {
            $data['planExpired'] = true;
        } else {
            $data['planExpired'] = false;
        }

        $plan = Plan::find($plan_id);
        if (!empty($plan)) {
            // plan expired days
            $user = auth()->user();
            $duration = $user->plan->duration;
            $expiredDate = Carbon::parse($user->plan_updated_at)->addDays($duration);
            $expiredDays = $expiredDate->diffInDays(Carbon::now());
            $expiredDate = Carbon::parse($expiredDate)->format('Y-m-d');
            // plan expired days end
            $viewed = PtcView::where('user_id', auth()->user()->id)->where('vdt', Date('Y-m-d'))->count();
            $limit = $plan->daily_ad_limit ?? 0 - $viewed;
            // dd($limit);

            $count = Ptc::where('status', 1)->where('remain', '>', 0)->where('plan_id', $plan_id)->limit($plan->daily_ad_limit)->get();
            $ads_count = count($count);

            $ads_remaning = $ads_count - $viewed;
            if($ads_count == 0){
                $ads_count = 1;
            }
            $adpercent =  100 / $ads_count;
            $ads_remaning_percent = (int) round($adpercent * $ads_remaning, 0);
        } else {
            $expiredDays = 0;
            $expiredDate = 0;
            $ads_remaning_percent = 100;
            $ads_remaning = 0;
        }

        return view($this->activeTemplate . 'user.view_profile', $data, compact('top_rated_viewed', 'top_rated_ads', 'chart', 'expiredDays', 'expiredDate', 'withdrawals', 'login_logs', 'ads_remaning_percent', 'ads_remaning'));
    }
    public function home()
    {
        $plan_id = Auth::user()->plan_id;
        $plan = Plan::find($plan_id);
        $top_rated_viewed = PtcView::where('user_id', auth()->user()->id)->where('vdt', Date('Y-m-d'))->pluck('ptc_id')->toArray();
        $viewedcount = PtcView::where('user_id', auth()->user()->id)->where('vdt', Date('Y-m-d'))->count();
        if (empty($plan)) {
            $limit = 0;
        } else {
            $limit = $plan->daily_ad_limit - $viewedcount;
        }
        $top_rated_ads = Ptc::whereNotIn('id', $top_rated_viewed)->withCount('reactions')->where('status', 1)->where('remain', '>', 0)->where('plan_id', $plan_id)->limit($limit)->orderBy('reactions_count', 'desc')->get();

        $users = User::all();
        foreach ($users as $user) {
            $duration = $user->plan->duration;
            $expiredDate = Carbon::parse($user->plan_updated_at)->addDays($duration);
            if ($expiredDate < Carbon::now()) {
                $user->update([
                    'plan_id' => 0,
                ]);
            }
        }
        $data['totaluser'] = $users->count();
        $login_logs = auth()->user()->login_logs()->latest()->paginate(getPaginate(1));
        $withdrawals = Withdrawal::where('status', 1)->with(['user', 'method'])->latest()->paginate(getPaginate());
        $ptc = PtcView::where('user_id', auth()->user()->id)->get(['vdt', 'amount']);
        $data['page_title']         = "Dashboard";
        $data['totalDeposit']       = Deposit::where('user_id', auth()->id())->where('status', 1)->sum('amount');
        $data['totalWithdraw']      = Withdrawal::where('user_id', auth()->id())->where('status', 1)->sum('amount');
        $data['totalEarn']      = User::sum('total_view_ref');
        $data['completeWithdraw']   = Withdrawal::where('user_id', auth()->id())->where('status', 1)->count();
        $data['pendingWithdraw']    = Withdrawal::where('user_id', auth()->id())->where('status', 2)->count();
        $data['rejectWithdraw']     = Withdrawal::where('user_id', auth()->id())->where('status', 3)->count();
        $data['total_ref']          = User::where('ref_id', auth()->id())->count();
        $data['totalBvCut']         = BvLog::where('user_id', auth()->id())->where('trx_type', '-')->sum('amount');
        $data['amount']             = $ptc->groupBy('vdt')->map(function ($item, $key) {
            return collect($item)->sum('amount');
        })->sort()->reverse()->take(7)->toArray();

        $chart['click'] = $ptc->groupBy('vdt')->map(function ($item, $key) {
            return collect($item)->count();
        })->sort()->reverse()->take(7)->toArray();

        $chart['amount'] = $ptc->groupBy('vdt')->map(function ($item, $key) {
            return collect($item)->sum('amount');
        })->sort()->reverse()->take(7)->toArray();

        $plan_id = auth()->user()->plan_id;
        $plan_updated_at = auth()->user()->plan_updated_at;
        if ($plan_id == 0 && !is_null($plan_updated_at)) {
            $data['planExpired'] = true;
        } else {
            $data['planExpired'] = false;
        }

        $plan = Plan::find($plan_id);
        if (!empty($plan)) {
            // plan expired days
            $user = auth()->user();
            $duration = $user->plan->duration;
            $expiredDate = Carbon::parse($user->plan_updated_at)->addDays($duration);
            $expiredDays = $expiredDate->diffInDays(Carbon::now());
            $expiredDate = Carbon::parse($expiredDate)->format('Y-m-d');
            // plan expired days end
            $viewed = PtcView::where('user_id', auth()->user()->id)->where('vdt', Date('Y-m-d'))->count();
            $limit = $plan->daily_ad_limit ?? 0 - $viewed;
            // dd($limit);

            $count = Ptc::where('status', 1)->where('remain', '>', 0)->where('plan_id', $plan_id)->limit($plan->daily_ad_limit)->get();
            $ads_count = count($count);

            $ads_remaning = $ads_count - $viewed;
            if($ads_count == 0){
                $ads_count = 1;
            }
            $adpercent =  100 / $ads_count;
            $ads_remaning_percent = (int) round($adpercent * $ads_remaning, 0);
        } else {
            $expiredDays = 0;
            $expiredDate = 0;
            $ads_remaning_percent = 100;
            $ads_remaning = 0;
        }

        return view($this->activeTemplate . 'user.dashboard', $data, compact('top_rated_viewed', 'top_rated_ads', 'chart', 'expiredDays', 'expiredDate', 'withdrawals', 'login_logs', 'ads_remaning_percent', 'ads_remaning'));
    }
    public function balTransfer(Request $request)
    {
        $user = User::find(auth()->user()->id);
        $amount = User::convertToUsd($request->amount);
        if ($amount < $user->total_ref_com) {
            $user->decrement('total_ref_com', $amount);
            $user->increment('balance', $amount);
            $notify[] = ['success', 'Balance Transfer successfully.'];
            return back()->withNotify($notify);
        } else {
            $notify[] = ['error', 'Balance Transfer failed.'];
            return back()->withNotify($notify);
        }
    }

    public function profile()
    {
        $data['page_title'] = "Profile Setting";
        $data['user'] = Auth::user();
        return view($this->activeTemplate . 'user.profile-setting', $data);
    }

    public function submitProfile(Request $request)
    {
        $request->validate([
            'address' => "sometimes|required|max:80",
            'state' => 'sometimes|required|max:80',
            'zip' => 'sometimes|required|max:40',
            'city' => 'sometimes|required|max:50',
            'image' => 'mimes:png,jpg,jpeg'
        ]);


        $in['firstname'] = $request->firstname;
        $in['lastname'] = $request->lastname;
        
        $in['perfect_address'] = $request->perfect_address;
        $in['payeer_address'] = $request->payeer_address;
        $in['tetheru_address'] = $request->tetheru_address;
        $in['post'] = $request->post;
        $in['tethert_address'] = $request->tethert_address;

        $in['address'] = [
            'address' => $request->address,
            'state' => $request->state,
            'zip' => $request->zip,
            'country' => $request->country,
            'city' => $request->city,
        ];

        $in['country'] = $request->country;

        $user = Auth::user();

        if ($request->hasFile('image')) {
            // $image = $request->file('image');
            // $filename = time() . '_' . $user->username . '.jpg';
            // $location = 'assets/images/user/profile/' . $filename;
            // $in['image'] = $filename;

            // $path = './assets/images/user/profile/';
            // $link = $path . $user->image;
            // if (file_exists($link)) {
            //     @unlink($link);
            // }
            // $size = imagePath()['profile']['user']['size'];
            // $image = Image::make($image);
            // $size = explode('x', strtolower($size));
            // $image->resize($size[0], $size[1]);
            // $image->save($location);
            $file = $request->file('image');
            $extension = $file->getClientOriginalExtension();
            $filename = time() . '.' . $extension;
            $file->move(public_path('assets/images/user/profile/'), $filename);
            $in['image'] = $filename;

            //Remove Old Image
            $path = './assets/images/user/profile/';
            $link = public_path('assets/images/user/profile/') . $user->image;
            if (file_exists($link)) {
                @unlink($link);
            }
        }
        $user->fill($in)->save();
        $notify[] = ['success', 'Profile Updated successfully.'];
        return back()->withNotify($notify);
    }

    public function changePassword()
    {
        $data['page_title'] = "CHANGE PASSWORD";
        return view($this->activeTemplate . 'user.password', $data);
    }

    public function submitPassword(Request $request)
    {

        
        $this->validate($request, [
            'current_password' => 'required',
            'password' => 'required|min:5|confirmed'
        ]);
        try {
            $user = auth()->user();
            if (Hash::check($request->current_password, $user->password)) {
                $password = Hash::make($request->password);
                $user->password = $password;
                $user->save();
                $notify[] = ['success', 'Password Changes successfully.'];
                return back()->withNotify($notify);
            } else {
                $notify[] = ['error', 'Current password not match.'];
                return back()->withNotify($notify);
            }
        } catch (\PDOException $e) {
            $notify[] = ['error', $e->getMessage()];
            return back()->withNotify($notify);
        }
    }

    /*
     * Deposit History
     */
    public function depositHistory()
    {
        $page_title = 'Deposit History';
        $empty_message = 'No history found.';
        $logs = auth()->user()->deposits()->with(['gateway'])->latest()->paginate(getPaginate());
        return view($this->activeTemplate . 'user.deposit_history', compact('page_title', 'empty_message', 'logs'));
    }

    /*
     * Withdraw Operation
     */

    public function withdrawMoney()
    {
        $data['page_title'] = "Withdraw Money";
        return view(activeTemplate() . 'user.withdraw.methods', $data);
    }

    public function withdrawStore(Request $request)
    {
        $this->validate($request, [
            'method_code' => 'required',
            'amount' => 'required|numeric'
        ]);
        $amount = User::convertToUsd($request->amount);
        $method = WithdrawMethod::where('id', $amount)->where('status', 1)->firstOrFail();
        $user = auth()->user();
        if ($amount < $method->min_limit) {
            $notify[] = ['error', 'Your Requested Amount is Smaller Than Minimum Amount.'];
            return back()->withNotify($notify);
        }
        if ($amount > $method->max_limit) {
            $notify[] = ['error', 'Your Requested Amount is Larger Than Maximum Amount.'];
            return back()->withNotify($notify);
        }
        if ($amount > $user->balance) {
            $notify[] = ['error', 'Your do not have Sufficient Balance For Withdraw.'];
            return back()->withNotify($notify);
        }


        $charge = $method->fixed_charge + ($amount * $method->percent_charge / 100);
        $afterCharge = $amount - $charge;
        $finalAmount = getAmount($afterCharge * $method->rate);

        $withdraw = new Withdrawal();
        $withdraw->method_id = $method->id; // wallet method ID
        $withdraw->user_id = $user->id;
        $withdraw->amount = getAmount($amount);
        $withdraw->currency = $method->currency;
        $withdraw->rate = $method->rate;
        $withdraw->charge = $charge;
        $withdraw->final_amount = $finalAmount;
        $withdraw->after_charge = $afterCharge;
        $withdraw->trx = getTrx();
        $withdraw->save();
        session()->put('wtrx', $withdraw->trx);
        return redirect()->route('user.withdraw.preview');
    }

    public function withdrawVerify()
    {
        $data['page_title'] = "Withdraw Verify";
        return view($this->activeTemplate . 'user.withdraw.verify', $data);
    }
    public function withdrawVerifySubmit(Request $request)
    {
        $withdraw = Withdrawal::with('method', 'user')->where('trx', session()->get('wtrx'))->where('status', 0)->latest()->firstOrFail();
        if ($withdraw->otp == $request->otp) {
            return redirect()->route('user.withdraw.preview');
        } else {
            $notify[] = ['error', 'Otp Doesnot Match'];
            return redirect()->back()->withNotify($notify);
        }
    }

    public function withdrawPreview()
    {
                $data['withdraw'] = Withdrawal::with('method', 'user')->where('trx', session()->get('wtrx'))->where('status', 0)->latest()->firstOrFail();
        $data['page_title'] = "Withdraw Preview";
        $method = $data['withdraw']->method->name;
        $paymentid = '';
        if ($method == 'Perfect Money') {
            $paymentid = auth()->user()->perfect_address;
        } else if ($method == 'Payeer') {
            $paymentid = auth()->user()->payeer_address;
        }
        $data['paymentid'] = $paymentid;
        return view($this->activeTemplate . 'user.withdraw.preview', $data);

    }


    public function withdrawSubmit(Request $request)
    {
        $general = GeneralSetting::first();
        $withdraw = Withdrawal::with('method', 'user')->where('trx', session()->get('wtrx'))->where('status', 0)->latest()->firstOrFail();

        $rules = [];
        $inputField = [];
        if ($withdraw->method->user_data != null) {
            foreach ($withdraw->method->user_data as $key => $cus) {
                $rules[$key] = [$cus->validation];
                if ($cus->type == 'file') {
                    array_push($rules[$key], 'image');
                    array_push($rules[$key], 'mimes:jpeg,jpg,png');
                    array_push($rules[$key], 'max:2048');
                }
                if ($cus->type == 'text') {
                    array_push($rules[$key], 'max:191');
                }
                if ($cus->type == 'textarea') {
                    array_push($rules[$key], 'max:300');
                }
                $inputField[] = $key;
            }
        }
        $this->validate($request, $rules);
        $user = auth()->user();

        if (getAmount($withdraw->amount) > $user->balance) {
            $notify[] = ['error', 'Your Request Amount is Larger Then Your Current Balance.'];
            return back()->withNotify($notify);
        }

        $directory = date("Y") . "/" . date("m") . "/" . date("d");
        $path = imagePath()['verify']['withdraw']['path'] . '/' . $directory;
        $collection = collect($request);
        $reqField = [];
        if ($withdraw->method->user_data != null) {
            foreach ($collection as $k => $v) {
                foreach ($withdraw->method->user_data as $inKey => $inVal) {
                    if ($k != $inKey) {
                        continue;
                    } else {
                        if ($inVal->type == 'file') {
                            if ($request->hasFile($inKey)) {
                                try {
                                    $reqField[$inKey] = [
                                        'field_name' => $directory . '/' . uploadImage($request[$inKey], $path),
                                        'type' => $inVal->type,
                                    ];
                                } catch (\Exception $exp) {
                                    $notify[] = ['error', 'Could not upload your ' . $request[$inKey]];
                                    return back()->withNotify($notify)->withInput();
                                }
                            }
                        } else {
                            $reqField[$inKey] = $v;
                            $reqField[$inKey] = [
                                'field_name' => $v,
                                'type' => $inVal->type,
                            ];
                        }
                    }
                }
            }
            $withdraw['withdraw_information'] = $reqField;
        } else {
            $withdraw['withdraw_information'] = null;
        }


        $withdraw->status = 2;
        $withdraw->save();
        $user->balance  -=  $withdraw->amount;
        $user->save();



        $transaction = new Transaction();
        $transaction->user_id = $withdraw->user_id;
        $transaction->amount = getAmount($withdraw->amount);
        $transaction->post_balance = getAmount($user->balance);
        $transaction->charge = getAmount($withdraw->charge);
        $transaction->trx_type = '-';
        $transaction->details = getAmount($withdraw->final_amount) . ' ' . $withdraw->currency . ' Withdraw Via ' . $withdraw->method->name;
        $transaction->trx =  $withdraw->trx;
        $transaction->save();

        $adminNotification = new AdminNotification();
        $adminNotification->user_id = $user->id;
        $adminNotification->title = 'New withdraw request from ' . $user->username;
        $adminNotification->click_url = route('admin.withdraw.details', $withdraw->id);
        $adminNotification->save();

        notify($user, 'WITHDRAW_REQUEST', [
            'method_name' => $withdraw->method->name,
            'method_currency' => $withdraw->currency,
            'method_amount' => getAmount($withdraw->final_amount),
            'amount' => getAmount($withdraw->amount),
            'charge' => getAmount($withdraw->charge),
            'currency' => $general->cur_text,
            'rate' => getAmount($withdraw->rate),
            'trx' => $withdraw->trx,
            'post_balance' => getAmount($user->balance),
            'delay' => $withdraw->method->delay
        ]);

        $notify[] = ['success', 'Withdraw Request Successfully Send'];
        return redirect()->route('user.withdraw.history')->withNotify($notify);
    }

    public function withdrawLog()
    {
        $data['page_title'] = "Withdraw Log";
        $data['withdraws'] = Withdrawal::where('user_id', Auth::id())->where('status', '!=', 0)->with('method')->latest()->paginate(getPaginate());
        $data['empty_message'] = "No Data Found!";
        return view($this->activeTemplate . 'user.withdraw.log', $data);
    }



    public function show2faForm()
    {
        $gnl = GeneralSetting::first();
        $ga = new GoogleAuthenticator();
        $user = auth()->user();
        $secret = $ga->createSecret();
        $qrCodeUrl = $ga->getQRCodeGoogleUrl($user->username . '@' . $gnl->sitename, $secret);
        $prevcode = $user->tsc;
        $prevqr = $ga->getQRCodeGoogleUrl($user->username . '@' . $gnl->sitename, $prevcode);
        $page_title = 'Two Factor';
        return view($this->activeTemplate . 'user.twofactor', compact('page_title', 'secret', 'qrCodeUrl', 'prevcode', 'prevqr'));
    }

    public function create2fa(Request $request)
    {
        $user = auth()->user();
        $this->validate($request, [
            'key' => 'required',
            'code' => 'required',
        ]);

        $ga = new GoogleAuthenticator();
        $secret = $request->key;
        $oneCode = $ga->getCode($secret);

        if ($oneCode === $request->code) {
            $user->tsc = $request->key;
            $user->ts = 1;
            $user->tv = 1;
            $user->save();


            $userAgent = getIpInfo();
            $osBrowser = osBrowser();
            notify($user, '2FA_ENABLE', [
                'operating_system' => @$osBrowser['os_platform'],
                'browser' => @$osBrowser['browser'],
                'ip' => @$userAgent['ip'],
                'time' => @$userAgent['time']
            ]);


            $notify[] = ['success', 'Google Authenticator Enabled Successfully'];
            return back()->withNotify($notify);
        } else {
            $notify[] = ['error', 'Wrong Verification Code'];
            return back()->withNotify($notify);
        }
    }


    public function disable2fa(Request $request)
    {
        $this->validate($request, [
            'code' => 'required',
        ]);

        $user = auth()->user();
        $ga = new GoogleAuthenticator();

        $secret = $user->tsc;
        $oneCode = $ga->getCode($secret);
        $userCode = $request->code;

        if ($oneCode == $userCode) {

            $user->tsc = null;
            $user->ts = 0;
            $user->tv = 1;
            $user->save();


            $userAgent = getIpInfo();
            $osBrowser = osBrowser();
            notify($user, '2FA_DISABLE', [
                'operating_system' => @$osBrowser['os_platform'],
                'browser' => @$osBrowser['browser'],
                'ip' => @$userAgent['ip'],
                'time' => @$userAgent['time']
            ]);


            $notify[] = ['success', 'Two Factor Authenticator Disable Successfully'];
            return back()->withNotify($notify);
        } else {
            $notify[] = ['error', 'Wrong Verification Code'];
            return back()->with($notify);
        }
    }


    function indexTransfer()
    {
        $page_title = 'Balance Transfer';
        return view($this->activeTemplate . '.user.balanceTransfer', compact('page_title'));
    }

    function balanceTransfer(Request $request)
    {
        $this->validate($request, [
            'username' => 'required',
            'amount' => 'required|numeric|min:49',
        ]);
        $amount = User::convertToUsd($request->amount);
        $gnl = GeneralSetting::first();
        $user = User::find(Auth::id());
        $trans_user = User::where('username', $request->username)->orWhere('email', $request->username)->first();
        if ($trans_user == '') {
            $notify[] = ['error', 'Username Not Found'];
            return back()->withNotify($notify);
        }
        if ($trans_user->username == $user->username) {
            $notify[] = ['error', 'Balance Transfer Not Possible In Your Own Account'];
            return back()->withNotify($notify);
        }
        if ($trans_user->email == $user->email) {
            $notify[] = ['error', 'Balance Transfer Not Possible In Your Own Account'];
            return back()->withNotify($notify);
        }

        $charge = $gnl->bal_trans_fixed_charge + (($amount * $gnl->bal_trans_per_charge) / 100);
        $amount = $amount + $charge;
        if ($user->balance >= $amount) {
            $user->balance -= $amount;
            $user->save();

            $trx = getTrx();

            Transaction::create([
                'trx' => $trx,
                'user_id' => $user->id,
                'trx_type' => '-',
                'remark' => 'balance_transfer',
                'details' => 'Balance Transferred To ' . $trans_user->username,
                'amount' => getAmount($amount),
                'post_balance' => getAmount($user->balance),
                'charge' => $charge
            ]);

            notify($user, 'BAL_SEND', [
                'amount' => getAmount($amount),
                'username' => $trans_user->username,
                'trx' => $trx,
                'currency' => $gnl->cur_text,
                'charge' => getAmount($charge),
                'balance_now' => getAmount($user->balance),
            ]);

            $trans_user->balance += $amount;
            $trans_user->save();

            Transaction::create([
                'trx' => $trx,
                'user_id' => $trans_user->id,
                'remark' => 'balance_receive',
                'details' => 'Balance receive From ' . $user->username,
                'amount' => getAmount($amount),
                'post_balance' => getAmount($trans_user->balance),
                'charge' => 0,
                'trx_type' => '+'
            ]);

            notify($trans_user, 'BAL_RECEIVE', [
                'amount' => getAmount($amount),
                'currency' => $gnl->cur_text,
                'trx' => $trx,
                'username' => $user->username,
                'charge' => 0,
                'balance_now' => getAmount($trans_user->balance),
            ]);

            $notify[] = ['success', 'Balance Transferred Successfully.'];
            return back()->withNotify($notify);
        } else {
            $notify[] = ['error', 'Insufficient Balance.'];
            return back()->withNotify($notify);
        }
    }


    function searchUser(Request $request)
    {
        $trans_user = User::where('username', $request->username)->orwhere('email', $request->username)->count();
        if ($trans_user == 1) {
            return response()->json(['success' => true]);
        } else {
            return response()->json(['success' => false]);
        }
    }

    public function userLoginHistory()
    {
        $page_title = 'User Login History';
        $empty_message = 'No users login found.';
        $login_logs = auth()->user()->login_logs()->latest()->paginate(getPaginate());
        return view($this->activeTemplate . 'user.logins', compact('page_title', 'empty_message', 'login_logs'));
    }
}
