<?php

namespace App\Http\Controllers;

use App\Models\User;
use App\Models\Voucher;
use App\Models\Transaction;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\DB;
use Illuminate\Support\Facades\Auth;

class VoucherController extends Controller
{

    public function __construct()
    {
        $this->activeTemplate = activeTemplate();
    }

    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {
        $voucher = DB::table('vouchers')->where('user_id', Auth::id())->get();
        $users = User::where('is_agent', 0)->get();
        $reports = Transaction::where('user_id', Auth::id())->where('details', 'Voucher Comission')->get();
        return view(activeTemplate() . 'user.voucher.index', compact('voucher', 'users', 'reports'));
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        //
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {


        if (Auth::user()->total_invest >= $request->voucher_amount) {

            $user_id = Auth::user()->id;
            $voucher = $request->all();
            $voucher['user_id'] = $user_id;

            Voucher::create($voucher);

            User::where('id', $user_id)->decrement('total_invest', $request->voucher_amount);

            $trans = new Transaction;
            $trans->user_id = Auth::id();
            $trans->amount = $request->voucher_amount;
            $trans->charge = 0.00000000;
            $balance = Auth::user()->balance - $request->voucher_amount;
            $trans->post_balance = $balance;
            $trans->trx_type = '-';
            $trans->trx = $request->voucher_code;
            $trans->details = 'Voucher create';
            $trans->save();

            $notify[] = ['success', 'New Voucher Create successfully.'];
        } else {
            $notify[] = ['error', 'Oh ! Insufficent Balance.'];
        }

        return back()->withNotify($notify);
    }



    public function sendVoucher(Request $request)
    {
        $user_id = $request->user_id;
        $voucher = DB::table('vouchers')->where('voucher_code', $request->voucher_code)->first();
        if ($voucher) {

            $data = Voucher::find($voucher->id);

            $data->status = 1;
            $data->valid = 0;
            $data->rec_id = $user_id;
            $data->voucher_limit = 1;
            $data->save();

            $characters = '0123456789ABCDEFGHIJKLMNOPQRSTUVWXYZ';

            $length = 12;
            $charactersLength = strlen($characters);
            $randomString = '';
            for ($i = 0; $i < $length; $i++) {
                $randomString .= $characters[rand(0, $charactersLength - 1)];
            }

            $trans = new Transaction;
            $trans->user_id = $user_id;
            $trans->amount = $voucher->voucher_amount;
            $trans->charge = 0.00000000;
            $trans->post_balance = Auth::user()->balance + $voucher->voucher_amount;
            $trans->trx_type = '+';
            $trans->trx = $randomString;
            $trans->details = 'Voucher Recharge';
            $trans->save();

            User::where('id', $user_id)->increment('total_invest', $voucher->voucher_amount);

            $voucher = $voucher->voucher_amount;
            $comission = $voucher / 100 * 10;

            $user = User::where('id', $data->user_id)->increment('balance', $comission);
            $user = User::where('id', $data->user_id)->first();



            $trans = new Transaction;
            $trans->user_id = $data->user_id;
            $trans->amount = $comission;
            $trans->charge = 0.00000000;
            $trans->post_balance = $user->balance;
            $trans->trx_type = '+';
            $trans->trx = $randomString;
            $trans->details = 'Voucher Comission';
            $trans->save();

            $notify[] = ['success', 'Congrats ! Successfully Increment Balance'];
            return back()->withNotify($notify);
        } else {
            $notify[] = ['error', 'Oh ! Invalid Voucher'];
            return back()->withNotify($notify);
        }
    }
    /**
     * Display the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function show($id)
    {
        //
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function edit($id)
    {
        //
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, $id)
    {
        //
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function destroy($id)
    {
        voucher::find($id)->delete();
        $notify[] = ['success', 'Voucher Deleted successfully.'];
        return back()->withNotify($notify);
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function notUseDestroy($id)
    {
        $voucher = Voucher::where('id', $id)->first();

        User::where('id', Auth::id())->increment('total_invest', $voucher->voucher_amount);

        $characters = '0123456789ABCDEFGHIJKLMNOPQRSTUVWXYZ';

        $length = 12;
        $charactersLength = strlen($characters);
        $randomString = '';
        for ($i = 0; $i < $length; $i++) {
            $randomString .= $characters[rand(0, $charactersLength - 1)];
        }

        $trans = new Transaction;
        $trans->user_id = Auth::id();
        $trans->amount = $voucher->voucher_amount;
        $trans->charge = 0.00000000;
        $trans->post_balance = Auth::user()->balance + $voucher->voucher_amount;
        $trans->trx_type = '+';
        $trans->trx = $randomString;
        $trans->details = 'Voucher Return or Destroy';
        $trans->save();

        voucher::find($id)->delete();
        $notify[] = ['success', 'Voucher Deleted successfully & Return Voucher Balance Add your main balance.'];
        return back()->withNotify($notify);
    }



    /*--------Voucher Use----------*/


    /**
     * Display a listing of the use voucher resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function useIndex()
    {
        $use_voucher = Voucher::where('rec_id', Auth::id())->get();

        return view(activeTemplate() . 'user.voucher.use', compact('use_voucher'));
    }


    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function useStore(Request $request)
    {
        $user_id = Auth::user()->id;
        $voucher = voucher::where('voucher_code', $request->voucher_code)->where('rec_id', 0)->where('voucher_limit', 0)->first();
        if ($voucher) {

            $data = Voucher::find($voucher->id);

            $data->status = 1;
            $data->valid = 0;
            $data->rec_id = Auth::id();
            $data->voucher_limit = 1;
            $data->save();

            $characters = '0123456789ABCDEFGHIJKLMNOPQRSTUVWXYZ';

            $length = 12;
            $charactersLength = strlen($characters);
            $randomString = '';
            for ($i = 0; $i < $length; $i++) {
                $randomString .= $characters[rand(0, $charactersLength - 1)];
            }

            $trans = new Transaction;
            $trans->user_id = Auth::id();
            $trans->amount = $voucher->voucher_amount;
            $trans->charge = 0.00000000;
            $trans->post_balance = Auth::user()->balance + $voucher->voucher_amount;
            $trans->trx_type = '+';
            $trans->trx = $randomString;
            $trans->details = 'Voucher Recharge';
            $trans->save();

            User::where('id', Auth::id())->increment('total_invest', $voucher->voucher_amount);

            $voucher = $voucher->voucher_amount;
            $comission = $voucher / 100 * 10;

            $user = User::where('id', $data->user_id)->increment('balance', $comission);
            $user = User::where('id', $data->user_id)->first();



            $trans = new Transaction;
            $trans->user_id = $data->user_id;
            $trans->amount = $comission;
            $trans->charge = 0.00000000;
            $trans->post_balance = $user->balance;
            $trans->trx_type = '+';
            $trans->trx = $randomString;
            $trans->details = 'Voucher Comission';
            $trans->save();

            $notify[] = ['success', 'Congrats ! Successfully Sent Voucher'];
            return back()->withNotify($notify);
        } else {
            $notify[] = ['error', 'Oh ! Invalid Voucher'];
            return back()->withNotify($notify);
        }
    }
}
