<?php

namespace App\Http\Livewire\User;

use App\Models\User;
use App\Models\Voucher;
use Livewire\Component;
use App\Models\Transaction;
use App\Models\GeneralSetting;
use App\Mail\VoucherReceived;
use Livewire\WithPagination;
use Illuminate\Support\Facades\Mail;
use Illuminate\Support\Facades\DB;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\Validator;

class DepositVoucherComponent extends Component
{
    use WithPagination;
    protected $paginationTheme = 'bootstrap';

    public $currentTab, $amount, $send_user_id, $msg;

    protected $rules = [
        'amount' => ['required', 'regex:/^\d+$/', 'gt:0'],
    ];
    
    protected $messages = [
        'amount.required' => 'The amount field is required.',
        'amount.regex' => 'The amount must be a valid number.',
        'amount.gt' => 'The amount must be greater than 0.',
    ];
    
    public function mount()
    {
        $this->currentTab = 'tab1';
    }

    public function render()
    {
        return view('livewire.user.deposit-voucher-component', [
            'vouchers' => Voucher::where('user_id', Auth::id())->latest()->paginate(10),
            'users' => User::where('is_agent', 0)->get(),
            'reports' => Transaction::where('user_id', Auth::id())->whereIn('details', ['Voucher Comission', 'Voucher Commission'])->latest()->paginate(10)
        ]);
    }

    public function changeTab($tab)
    {
        $this->currentTab = $tab;
    }

    public function createVoucher()
    {
        $this->validate();
        $convertedAmount = User::currencyToUsd($this->amount);
        if (Auth::user()->total_invest >= $convertedAmount) {
            $characters = '0123456789ABCDEFGHIJKLMNOPQRSTUVWXYZ';

            $length = 12;
            $charactersLength = strlen($characters);
            $randomString = '';
            for ($i = 0; $i < $length; $i++) {
                $randomString .= $characters[rand(0, $charactersLength - 1)];
            }
            $user_id = Auth::user()->id;

            Voucher::create([
                'user_id' => auth()->user()->id,
                'voucher_code' => $randomString,
                'voucher_amount' => $convertedAmount,
                'status' => 0
            ]);

            User::where('id', $user_id)->decrement('total_invest', $convertedAmount);

            $trans = new Transaction;
            $trans->user_id = Auth::id();
            $trans->amount = $convertedAmount;
            $trans->charge = 0.00000000;
            $balance = Auth::user()->balance - $convertedAmount;
            $trans->post_balance = $balance;
            $trans->trx_type = '-';
            $trans->trx = $randomString;
            $trans->details = 'Voucher create';
            $trans->save();
            $create_voucher_amount = User::currency($convertedAmount, 0, 6);

            session()->flash('success', $create_voucher_amount . ' Voucher Create successfully.');


            // return redirect()->route('user.deposit.voucher')->with('notify', $notify);
            $this->emit('propertyUpdated');
            // $this->dispatchBrowserEvent('success', ['msg' => 'Voucher Created successfully.']);
        } else {
            session()->flash('error', 'Insufficient Balance.');
        }
        $this->reset([
            'amount',
        ]);
    }
    
    public function delete($id)
    {
        Voucher::find($id)->delete();
        $this->msg['status'] = 'success';
        $this->msg['message'] = 'Voucher Deleted successfully.';
        $this->dispatchBrowserEvent('success', ['msg' => 'Voucher Deleted successfully.']);
    }

    public function deleteNotUse($id)
    {
        $voucher = Voucher::where('id', $id)->first();

        User::where('id', Auth::id())->increment('total_invest', $voucher->voucher_amount);

        $characters = '0123456789ABCDEFGHIJKLMNOPQRSTUVWXYZ';

        $length = 12;
        $charactersLength = strlen($characters);
        $randomString = '';
        for ($i = 0; $i < $length; $i++) {
            $randomString .= $characters[rand(0, $charactersLength - 1)];
        }

        $trans = new Transaction;
        $trans->user_id = Auth::id();
        $trans->amount = $voucher->voucher_amount;
        $trans->charge = 0.00000000;
        $trans->post_balance = Auth::user()->balance + $voucher->voucher_amount;
        $trans->trx_type = '+';
        $trans->trx = $randomString;
        $trans->details = 'Voucher Return or Destroy';
        $trans->save();

        Voucher::find($id)->delete();
        $this->msg['status'] = 'success';
        $this->msg['message'] = 'Voucher Deleted successfully & Return Voucher Balance Add your main balance.';
        // $this->dispatchBrowserEvent('success', ['msg' => 'Voucher Deleted successfully & Return Voucher Balance Add your main balance.']);
    }
    public function sendVoucher($code)
    {
        $rev_user = User::where('username', $this->send_user_id)->first();

        if ($rev_user !== null) {
            $user_id = $rev_user->id;
            $voucher = DB::table('vouchers')->where('id', $code)->first();
            $gnl = GeneralSetting::first();

            if ($voucher) {
                $data = Voucher::find($voucher->id);

                if($rev_user->username == auth()->user()->username){
                    $this->msg['status'] = 'error';
                    $this->msg['message'] = 'ho!, you can not send voucher own account';
                }else{
                // Update voucher status and details
                $data->status = 1;
                $data->valid = 0;
                $data->rec_id = $user_id;
                $data->voucher_limit = 1;
                $data->save();

                // Generate a random transaction ID
                $characters = '0123456789ABCDEFGHIJKLMNOPQRSTUVWXYZ';
                $length = 12;
                $charactersLength = strlen($characters);
                $randomString = '';

                for ($i = 0; $i < $length; $i++) {
                    $randomString .= $characters[rand(0, $charactersLength - 1)];
                }

                // Increment user balance and create transaction record
                $trans = new Transaction;
                $trans->user_id = $user_id;
                $trans->amount = $voucher->voucher_amount;
                $trans->charge = 0.00000000;
                $trans->post_balance = Auth::user()->balance + $voucher->voucher_amount;
                $trans->trx_type = '+';
                $trans->trx = $randomString;
                $trans->details = 'Voucher Recharge';
                $trans->save();

                User::where('id', $user_id)->increment('total_invest', $voucher->voucher_amount);

                $voucherAmount = $voucher->voucher_amount;
                $commission = $voucherAmount / 100 * 10;

                $user = User::where('id', $data->user_id)->first();

                // Increment user balance with commission and create transaction record
                $user->balance += $commission;
                $user->save();

                $trans = new Transaction;
                $trans->user_id = $data->user_id;
                $trans->amount = $commission;
                $trans->charge = 0.00000000;
                $trans->post_balance = $user->balance;
                $trans->trx_type = '+';
                $trans->trx = $randomString;
                $trans->details = 'Voucher Commission';
                $trans->save();

                $voucherSender = User::where('id', $data->user_id)->first();
                $rec_user = User::find($user_id);
                // Send email notification to the voucher receiver
                if ($voucherSender && $gnl->mail_notification == 1) {
    
                    $subject = "Voucher Sent Done. You Got Comission:" . $commission;
                    $message = "Voucher Sent Done. You Got Comission:" . $commission;
                    sendGeneralEmail($rec_user->email, $subject, $message, $rec_user->username);

                    // Send email notification to the voucher sender
                    $subject = "You send a voucher";
                    $message = "Good news!You have received a voucher from " . $voucherSender->name . ' ' . $trans->amount;
                    sendGeneralEmail($user->email, $subject, $message, $user->username);
                }

                
                $send_voucher_amount = User::currency($voucher->voucher_amount, 0, 6);

                $this->msg['status'] = 'success';
                $this->msg['message'] = "The $send_voucher_amount Voucher code has been successfully send to $rec_user->username.";
                // $this->dispatchBrowserEvent('success', ['msg' => 'Congratulations! Balance has been successfully incremented.']);
                }
            } else {
                $this->msg['status'] = 'error';
                $this->msg['message'] = 'Invalid Voucher.';
                // $this->dispatchBrowserEvent('error', ['msg' => 'Invalid Voucher.']);
            }
        } else {
            $this->msg['status'] = 'error';
            $this->msg['message'] = 'Invalid Username, check again!';
        }
    }
}
