<?php

namespace App\Http\Livewire\User;

use App\Mail\AccountUpgradeMail;
use Carbon\Carbon;
use App\Models\Plan;
use App\Models\User;
use Livewire\Component;
use App\Models\GeneralSetting;
use App\Models\GatewayCurrency;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\Mail;

class PlanListComponent extends Component
{
    public $selected_plan, $plan_id, $last_price;
    public function mount()
    {
        // $this->dispatchBrowserEvent('show-modal', ['id' => 'myModal']);
    }
    public function render()
    {
        $res = Plan::find(auth()->user()->plan_id);
        if (blank($res)) {
            $plans = Plan::where('status', 1)->get();
        }elseif(auth()->user()->plan_id == 0){
            $plans = Plan::whereNotIn('id', [0, 1])
            ->where('status', 1)
            ->get();
        } else {
            $plans = Plan::where('price', '>=', $res->price)
                    ->where('status', 1)
                    ->get();
        }
        return view('livewire.user.plan-list-component', [
            'plans' => $plans,
            'methods' => GatewayCurrency::whereHas('method', function ($gate) {
                $gate->where('status', 1);
            })->with('method')->orderby('method_code')->get(),
        ]);
    }
    public function updated($propertyName)
    {
        if ($propertyName === 'plan_id') {
            $this->selected_plan = Plan::find($this->plan_id);
        }
    }
    public function chooseAccount($planId)
    {
        
        $selected_plan = Plan::find($planId);
        $this->selected_plan = $selected_plan;
        $this->plan_id = $selected_plan->id;

        $oldPlanId = auth()->user()->plan_id;
        $user = Auth()->user();
        $oldPlan = Plan::find($oldPlanId);
        $oldPlanPrice = $oldPlan->price;
        //Fee Section
        $olddate = Carbon::parse($user->plan_updated_at);
        $daysDifference = $olddate->diffInDays(Carbon::now());
        $feepercent = $this->feePercent($daysDifference);
        $fee = $this->calculatePercentage($oldPlanPrice, $feepercent);
        $this->last_price = ($this->selected_plan->price + $fee) - $oldPlanPrice;
        $this->dispatchBrowserEvent('show-modal', ['id' => 'myModal']);
    }
    public function payFromDeposit()
    {

        $this->dispatchBrowserEvent('hide-modal', ['id' => 'myModal']);
        $this->dispatchBrowserEvent('show-modal', ['id' => 'upgradeConfirmModal']);
    }
    public function confirmUpgrade()
    {
        $gnl = GeneralSetting::first();
        $user = User::find(Auth::id());
        $oldPlanId = $user->plan_id;
        // try {
        if ($oldPlanId) {
            $oldPlan = Plan::find($oldPlanId);
            $oldPlanPrice = $oldPlan->price;
            if ($oldPlanPrice > $this->selected_plan->price) {
                
                if ($user->total_invest >= $this->selected_plan->price) {

                    $user->plan_id = $this->selected_plan->id;
                    $user->plan_updated_at = now();
                    $user->total_invest -= $this->selected_plan->price;
                    $user->dpl  = $this->selected_plan->daily_ad_limit;
                    $user->save();

                    $trx = $user->transactions()->create([
                        'amount' => $this->selected_plan->price,
                        'trx_type' => '-',
                        'details' => 'Purchased ' . $this->selected_plan->name,
                        'remark' => 'purchased_plan',
                        'trx' => getTrx(),
                        'post_balance' => getAmount($user->total_invest),
                    ]);

                    //Add Pending Balance 
                    $this->pendingBalance($user);


                    // notify($user, 'plan_purchased', [
                    //     'plan' => $this->selected_plan->name,
                    //     'amount' => getAmount($this->selected_plan->price),
                    //     'currency' => $gnl->cur_text,
                    //     'trx' => $trx->trx,
                    //     'post_balance' => getAmount($user->total_invest) . ' ' . $gnl->cur_text,
                    // ]);
                    $gs = GeneralSetting::first();

                    $details = Auth::user()->username . ' Subscribed to ' . $this->selected_plan->name . ' plan.';

                    updateBV($user->id, $this->selected_plan->bv, $details);

                    if ($this->selected_plan->tree_com > 0) {
                        treeComission($user->id, $this->selected_plan->tree_com, $details);
                    }
                    //Refarel comission
                    $ref_user = User::find($user->ref_id);
                    if (!blank($ref_user)) {
                        $ref_user_plan = $ref_user->plan;
                        if ($ref_user_plan->id == 1 || $ref_user_plan->id == 2) {
                            $ref_user->pending_balance += $this->calculatePercentage($this->selected_plan->price, $gs->plan_update_ref_com);
                            $ref_user->save();
                        } else {
                            $ref_user->balance += $this->calculatePercentage($this->selected_plan->price, $gs->plan_update_ref_com);
                            $ref_user->save();

                            $trx = $ref_user->transactions()->create([
                                'amount' => $this->calculatePercentage($this->selected_plan->price, $gs->plan_update_ref_com),
                                'trx_type' => '-',
                                'details' => $details,
                                'remark' => 'plan_update_refarel_comission',
                                'trx' => getTrx(),
                                'post_balance' => getAmount($ref_user->balance),
                            ]);
                        }
                    }

                    //Send Mail To User
                    if ($gnl->mail_notification == 1) {
                        $subject = "Plan Update Details";
                        $message = $user->total_invest;
                        sendGeneralEmail(auth()->user()->email, $subject, $message, auth()->user()->username);
                    }
                    return redirect()->route('user.planredirect');
                }
            } else {
                //Fee Section
                $olddate = Carbon::parse($user->plan_updated_at);
                $daysDifference = $olddate->diffInDays(Carbon::now());
                $feepercent = $this->feePercent($daysDifference);
                $fee = $this->calculatePercentage($oldPlanPrice, $feepercent);
                $final_amount = (($this->selected_plan->price + $fee) - $oldPlanPrice);
                
                if ($user->total_invest >= (($this->selected_plan->price + $fee) - $oldPlanPrice)) {
                    $user->plan_id = $this->selected_plan->id;
                    $user->total_invest -= (($this->selected_plan->price + $fee) - $oldPlanPrice);
                    $user->plan_updated_at = now();

                    $user->dpl  = $this->selected_plan->daily_ad_limit;
                    $user->save();

                    $trx = $user->transactions()->create([
                        'amount' => (($this->selected_plan->price + $fee) - $oldPlanPrice),
                        'trx_type' => '-',
                        'details' => 'Purchased ' . $this->selected_plan->name,
                        'remark' => 'purchased_plan',
                        'trx' => getTrx(),
                        'post_balance' => getAmount($user->total_invest),
                    ]);
                    
                    //Add Pending Balance 
                    $this->pendingBalance($user);
                    notify($user, 'plan_purchased', [
                        'plan' => $this->selected_plan->name,
                        'amount' => getAmount((($this->selected_plan->price + $fee) - $oldPlanPrice)),
                        'currency' => $gnl->cur_text,
                        'trx' => $trx->trx,
                        'post_balance' => getAmount($user->total_invest) . ' ' . $gnl->cur_text,
                    ]);


                    $details = Auth::user()->username . ' Subscribed to ' . $this->selected_plan->name . ' plan.';

                    updateBV($user->id, $this->selected_plan->bv, $details);

                    if ($this->selected_plan->tree_com > 0) {
                        treeComission($user->id, $this->selected_plan->tree_com, $details);
                    }

                    // referralComission($user->id, $details);
                    $gs = GeneralSetting::first();
                    //refarel Comission
                    $ref_user = User::find($user->ref_id);
                    if (!blank($ref_user)) {
                        $ref_user_plan = $ref_user->plan;

                        if ($ref_user_plan->id == 0 || $ref_user_plan->id == 1) {
                            // $ref_user->pending_balance += $this->calculatePercentage($this->selected_plan->price + $fee, $gs->plan_update_ref_com);
                            $ref_user->pending_balance = 0 ;
                            
                            $ref_user->save();
                        } else {
                            // dd($this->calculatePercentage($final_amount, $gs->plan_update_ref_com));
                            // $ref_user->balance += $this->calculatePercentage($this->selected_plan->price + $fee, $gs->plan_update_ref_com);
                            $ref_user->balance += $this->calculatePercentage($final_amount, $gs->plan_update_ref_com);
                            $ref_user->save();

                            $trx = $ref_user->transactions()->create([
                                'amount' => $this->calculatePercentage($final_amount, $gs->plan_update_ref_com),
                                'trx_type' => '-',
                                'details' => $details,
                                'remark' => 'plan_update_refarel_comission',
                                'trx' => getTrx(),
                                'post_balance' => getAmount($ref_user->balance),
                            ]);
                        }
                    }
                    // $this->dispatchBrowserEvent('success', ['msg' => ['Your account upgraded successfully']]);
                    //Mail Send

                    //Send Mail To User
                    if ($gnl->mail_notification == 1) {
                        $subject = "Account Upgrade Mail";
                        $message = "Update plan Amount : " . '' . $user->total_invest;
                        sendGeneralEmail(auth()->user()->email, $subject, $message, auth()->user()->username);
                    }
                    return redirect()->route('user.planredirect');
                } else {
                    $this->dispatchBrowserEvent('error', ['msg' => ['Insuficient Balance']]);
                }
            }
        } else {
            if ($user->total_invest >= $this->selected_plan->price) {

                $user->plan_id = $this->selected_plan->id;
                $user->total_invest -= $this->selected_plan->price;
                $user->plan_updated_at = now();

                $user->dpl  = $this->selected_plan->daily_ad_limit;
                $user->save();

                $trx = $user->transactions()->create([
                    'amount' => $this->selected_plan->price,
                    'trx_type' => '-',
                    'details' => 'Purchased ' . $this->selected_plan->name,
                    'remark' => 'purchased_plan',
                    'trx' => getTrx(),
                    'post_balance' => getAmount($user->total_invest),
                ]);
                //Add Pending Balance 
                $this->pendingBalance($user);
                // notify($user, 'plan_purchased', [
                //     'plan' => $this->selected_plan->name,
                //     'amount' => getAmount($this->selected_plan->price),
                //     'currency' => $gnl->cur_text,
                //     'trx' => $trx->trx,
                //     'post_balance' => getAmount($user->total_invest) . ' ' . $gnl->cur_text,
                // ]);


                $details = Auth::user()->username . ' Subscribed to ' . $this->selected_plan->name . ' plan.';

                updateBV($user->id, $this->selected_plan->bv, $details);

                if ($this->selected_plan->tree_com > 0) {
                    treeComission($user->id, $this->selected_plan->tree_com, $details);
                }
                //Mail Send
                //Send Mail To User
                if ($gnl->mail_notification == 1) {
                    $subject = "Account Upgrade Mail";
                    $message = "Update plan Amount : " . '' . $user->total_invest;
                    sendGeneralEmail(auth()->user()->email, $subject, $message, auth()->user()->username);
                }
                $ref_user = User::find($user->ref_id);
                $gs = GeneralSetting::first();
                if (!blank($ref_user)) {
                    $ref_user_plan = $ref_user->plan;
                    if ($ref_user_plan->id == 1 || $ref_user_plan->id == 2) {
                        $ref_user->pending_balance += $this->calculatePercentage($this->selected_plan->price, $gs->plan_update_ref_com);
                        $ref_user->save();
                    } else {
                        $ref_user->balance += $this->calculatePercentage($this->selected_plan->price, $gs->plan_update_ref_com);
                        $ref_user->save();

                        $trx = $ref_user->transactions()->create([
                            'amount' => $this->calculatePercentage($this->selected_plan->price, $gs->plan_update_ref_com),
                            'trx_type' => '-',
                            'details' => $details,
                            'remark' => 'plan_update_refarel_comission',
                            'trx' => getTrx(),
                            'post_balance' => getAmount($ref_user->balance),
                        ]);
                    }
                }
                return redirect()->route('user.planredirect');
            }
        }
        // } catch (\Throwable $th) {
        //     $this->dispatchBrowserEvent('error', ['msg' => ['SomeThing Went Wrong']]);
        // }
    }
    public function feePercent($days)
    {
        if ($days <= 10) {
            return 5;
        } elseif ($days <= 20) {
            return 15;
        } elseif ($days <= 30) {
            return 20;
        } else {
            return 20;
        }
    }
    public function calculatePercentage($total, $percentage)
    {
        return $total * ($percentage / 100);
    }
    public function pendingBalance($user)
    {
        if ($user->pending_balance > 0) {
            $user->balance += $user->pending_balance;
            $user->transactions()->create([
                'amount' => $user->pending_balance,
                'trx_type' => '-',
                'details' => 'Pending Balance Added To Balance',
                'remark' => 'plan_update_refarel_comission',
                'trx' => getTrx(),
                'post_balance' => getAmount($user->balance),
            ]);
            $user->pending_balance = 0;
            $user->save();
        }
    }
}
