<?php

namespace App\Http\Livewire\User;

use App\Models\User;
use Livewire\Component;
use App\Models\GeneralSetting;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\Mail;
use Illuminate\Support\Facades\Session;
use App\Mail\RegisterEmailVerification;

class UserLoginComponent extends Component
{
    public $username, $tab, $otp, $password, $msg;
    public function mount()
    {
        $this->tab = 1;
    }
    public function render()
    {
        return view('livewire.user.user-login-component');
    }

    public function login()
    {
        $user = User::where('username', $this->username)->first();
        
        if (!$user) {
            $this->msg['status'] = 'error';
            $this->msg['message'] = 'This username is not registered in our system.';
            return redirect()->back();
        }

        $gnl = GeneralSetting::first();
        if ($gnl->ev == 1) {
            $user = User::where('username', $this->username)->first();
            if (!blank($user)) {
                if ($user->ev != 1) {
                    $randomNumber = mt_rand(1000, 9999);
                    $user->update([
                        'ver_code' => $randomNumber,
                        'ver_code_send_at' => now(),
                    ]);
                    //Send Mail
                    $subject = "Verify your email address";
                    $message = "Your one-time OTP for verifying your email: <strong>$randomNumber</strong>";
                    sendGeneralEmail($user->email, $subject, $message, $user->username);
                    $this->msg['status'] = 'success';
                    $this->msg['message'] = 'Otp Code Sent In Your Mail';
                    $this->tab = 2;
                } else {
                    $credentials = [
                        'username' => $this->username,
                        'password' => $this->password,
                    ];

                    if (Auth::attempt($credentials)) {
                        $user = Auth::user();

                        if ($user->status == 0) {
                            $this->msg['status'] = 'error';
                            $this->msg['message'] = 'Your account is inactive. Please contact the administrator';
                            Auth::logout();
                        } else {
                            session()->put('displayExpire', true);
                            session()->put('displayReminder', true);
                            return redirect()->intended('/user/dashboard.aspx');
                        }
                    } else {
                        $this->msg['status'] = 'error';
                        $this->msg['message'] = 'Invalid username or password';
                    }
                }
            }
        } else {
            $credentials = [
                'username' => $this->username,
                'password' => $this->password,
            ];

            if (Auth::attempt($credentials)) {
                $user = Auth::user();

                if ($user->status == 0) {
                    $this->msg['status'] = 'error';
                    $this->msg['message'] = 'Your account is inactive. Please contact the administrator';
                    Auth::logout();
                } else {
                    return redirect()->intended('/user/dashboard.aspx');
                }
            } else {
                $this->msg['status'] = 'error';
                $this->msg['message'] = 'Invalid username or password';
            }
        }
    }
    public function otpVerify()
    {
        if ($this->otp == null) {
            $this->msg['status'] = 'error';
            $this->msg['message'] = 'Otp Is Required';
        } else {
            $user = User::where('username', $this->username)->first();
            if ($user->ver_code == $this->otp) {
                $user->update([
                    'ev' => 1
                ]);
                $credentials = [
                    'username' => $user->username,
                    'password' => $this->password,
                ];
                if (Auth::attempt($credentials)) {
                    // Authentication passed
                    $this->msg['status'] = 'success';
                    $this->msg['message'] = 'Register successful';
                    return redirect()->route('user.dashboard');
                } else {
                    $this->msg['status'] = 'error';
                    $this->msg['message'] = 'Something went wrong';
                }
            }
        }
    }
}
