<?php

namespace App\Http\Livewire\User;

use App\Models\Ptc;
use App\Models\Plan;
use App\Models\PtcCategory;
use App\Models\PtcView;
use Livewire\Component;
use Illuminate\Support\Facades\Auth;
use Livewire\WithPagination;

class WatchToEarnComponent extends Component
{
    use WithPagination;
    protected $paginationTheme = 'bootstrap';
    public $category;
    public function mount()
    {
        $this->category = 'all';
    }
    public function render()
    {
        $plan_id = Auth::user()->plan_id;
        if (!auth()->user()->plan) {
            $notify[] = ['error', 'Please buy a plan to view add'];
            return redirect()->route('user.plan.index')->withNotify($notify);
        };
        $plan = Plan::find($plan_id);
        $viewed = PtcView::where('user_id', auth()->user()->id)->where('vdt', Date('Y-m-d'))->pluck('ptc_id')->toArray();
        $viewedcount = PtcView::where('user_id', auth()->user()->id)->where('vdt', Date('Y-m-d'))->count();
        if (empty($plan)) {
            $limit = 0;
        } else {
            $limit = $plan->daily_ad_limit - $viewedcount;
        }
        if ($this->category == 'all') {
            $ads = Ptc::withCount('views')
                ->whereNotIn('id', $viewed)
                ->where('status', 1)
                ->where('remain', '>', 0)
                ->where('plan_id', $plan_id)
                ->paginate(10);
        } else {
            $ads = Ptc::withCount('views')
                ->whereNotIn('id', $viewed)
                ->where('status', 1)
                ->where('remain', '>', 0)
                ->where('ptc_category_id', $this->category)
                ->where('plan_id', $plan_id)
                ->paginate(10);
        }
        return view('livewire.user.watch-to-earn-component', [
            'ads' => $ads,
            'viewed' => $viewed,
            'categories' => PtcCategory::all(),
        ]);
    }
    public function catChanged($id)
    {
        $this->category = $id;
    }
}
