<?php

namespace App\Http\Livewire\User;

use Session;
use App\Models\User;
use App\Mail\OtpMail;
use Livewire\Component;
use App\Models\Withdrawal;
use Illuminate\Support\Str;
use App\Models\WithdrawMethod;
use App\Models\GeneralSetting;
use App\Models\Transaction;
use App\Models\AdminNotification;
use Illuminate\Support\Facades\Mail;
use Livewire\WithPagination;

class WithdrawComponent extends Component
{
    use WithPagination;
    protected $paginationTheme = 'bootstrap';
    public $methodId;
    public $amount;
    public $method;
    public $activeTab;
    public $account_id;
    public $tabId, $pin, $otp, $withdraw, $paymentid;
    public $msg = [];

    protected $rules = [
        'account_id' => 'required',
    ];

    public function mount()
    {
        $this->methodId = 0;
        $this->activeTab = 'tab1';
        $this->tabId = Str::uuid()->toString();
        // Initialize account_id with paymentid
        $this->account_id = $this->paymentid;
    }
    public function render()
    {
        return view('livewire.user.withdraw-component', [
            'methods' => WithdrawMethod::whereStatus(1)->get(),
            'selectedMethod' => WithdrawMethod::where('id', $this->methodId)->first(),
            'history' => Withdrawal::where('user_id', auth()->user()->id)->latest()->paginate(5),
        ]);
    }
    public function methodChanged($id)
    {
        $this->methodId = $id;
        $this->method = $id;
    }
    public function store()
    {
        if ($this->method == "") {
            $this->msg['status'] = 'error';
            $this->msg['message'] = 'Please select a method';
            // $this->dispatchBrowserEvent('error', ['msg' => 'Please Select A Method']);
        }
        $method = WithdrawMethod::where('id', $this->method)->where('status', 1)->firstOrFail();
        $user = auth()->user();
        $amount = User::currencyToUsd($this->amount);
        if ($amount < $method->min_limit) {
            $this->msg['status'] = 'error';
            $this->msg['message'] = 'Your thised Amount is Smaller Than Minimum Amount.';
            // $this->dispatchBrowserEvent('error', ['msg' => 'Your thised Amount is Smaller Than Minimum Amount.']);
        } else if ($amount > $method->max_limit) {
            $this->msg['status'] = 'error';
            $this->msg['message'] = 'Your Requested Amount is Larger Than Maximum Amount.';
            // $this->dispatchBrowserEvent('error', ['msg' => 'Your Requested Amount is Larger Than Maximum Amount.']);
        } else if ($amount > $user->balance) {
            $this->msg['status'] = 'error';
            $this->msg['message'] = 'You do not have Sufficient Balance For Withdraw.';
            // $this->dispatchBrowserEvent('error', ['msg' => 'You do not have Sufficient Balance For Withdraw.']);
        } elseif ($this->pin != auth()->user()->personal_pin) {
            $this->msg['status'] = 'error';
            $this->msg['message'] = 'Your pin does not matched.';
        } elseif (auth()->user()->plan->id == 'Free') {
            $this->msg['status'] = 'error';
            $this->msg['message'] = 'Please Upgrate your plan for withdraw';
        } else {
            $charge = $method->fixed_charge + ($amount * $method->percent_charge / 100);
            $afterCharge = $amount - $charge;
            $finalAmount = getAmount($afterCharge * $method->rate);

            $withdraw = new Withdrawal();
            $withdraw->method_id = $method->id; // wallet method ID
            $withdraw->user_id = $user->id;
            $withdraw->amount = getAmount($amount);
            $withdraw->currency = $method->currency;
            $withdraw->rate = $method->rate;
            $withdraw->charge = $charge;
            $withdraw->final_amount = $finalAmount;
            $withdraw->after_charge = $afterCharge;
            $withdraw->trx = getTrx();
            $withdraw->otp = random_int(100000, 999999);
            $withdraw->status = 4;
            $withdraw->save();
            session()->put('wtrx', $withdraw->trx);

            $this->withdraw = $withdraw;
            $method = $withdraw->method->name;

            $paymentid = '';
            if ($method == 'Perfect Money') {
                $paymentid = auth()->user()->perfect_money;
            } else if ($method == 'Payeer') {
                $paymentid = auth()->user()->payeer;
            }

            $this->paymentid = $paymentid;
            
            $this->account_id = $paymentid; // Update the account_id with paymentid000

            $this->reset('msg');
            $this->activeTab = 'tab2';
        }
    }
    public function verifySubmit()
    {
        $withdraw = $this->withdraw;
        if ($withdraw->otp == $this->otp) {
            $general = GeneralSetting::first();
            $withdraw = Withdrawal::with('method', 'user')->where('trx', session()->get('wtrx'))->where('status', 4)->latest()->firstOrFail();
            $rules = [];
            $inputField = [];
            if ($withdraw->method->user_data != null) {
                foreach ($withdraw->method->user_data as $key => $cus) {
                    $rules[$key] = [$cus->validation];
                    if ($cus->type == 'file') {
                        array_push($rules[$key], 'image');
                        array_push($rules[$key], 'mimes:jpeg,jpg,png');
                        array_push($rules[$key], 'max:2048');
                    }
                    if ($cus->type == 'text') {
                        array_push($rules[$key], 'max:191');
                    }
                    if ($cus->type == 'textarea') {
                        array_push($rules[$key], 'max:300');
                    }
                    $inputField[] = $key;
                }
            }
     
            $user = auth()->user();
     
            if (getAmount($withdraw->amount) > $user->balance) {
                $notify = [
                    ['error', 'Your Request Amount is Larger Than Your Current Balance.']
                ];

                session()->flash('notify', $notify);
                return back();
            }
     
            $withdraw->withdraw_information = $this->account_id ?? '';
            $withdraw->status = 2;
            $withdraw->save();
            $user->balance  -=  $withdraw->amount;
            $user->save();
     
     
            $transaction = new Transaction();
            $transaction->user_id = $withdraw->user_id;
            $transaction->amount = getAmount($withdraw->amount);
            $transaction->post_balance = getAmount($user->balance);
            $transaction->charge = getAmount($withdraw->charge);
            $transaction->trx_type = '-';
            $transaction->details = getAmount($withdraw->final_amount) . ' ' . $withdraw->currency . ' Withdraw Via ' . $withdraw->method->name;
            $transaction->trx =  $withdraw->trx;
            $transaction->save();
     
            $adminNotification = new AdminNotification();
            $adminNotification->user_id = $user->id;
            $adminNotification->title = 'New withdraw request from ' . $user->username;
            $adminNotification->click_url = route('admin.withdraw.details', $withdraw->id);
            $adminNotification->save();
     
            //Send Mail To User
            if ($general->mail_notification == 1) {
     
                  $id = $withdraw->id;
                  $subject = "Your Withdraw details";
                  $withdraw = Withdrawal::find($id);
                  $message = 'Withdraw Amount Is:' . User::convertToUsdWithCurrency($withdraw->amount) . ', And Withdraw Charge Is : ' . User::convertToUsdWithCurrency($withdraw->charge) ?? 0;
     
                  
                  sendGeneralEmail($user->email, $subject, $message, $user->username);
            }
            $notify = [
                ['success', 'Withdraw Request Successfully Send. Withdraw Amount Is:' . User::convertToUsdWithCurrency($withdraw->amount) . ', And Withdraw Charge Is : ' . User::convertToUsdWithCurrency($withdraw->charge) ?? 0]
            ];
        
            return redirect()->route('user.dashboard')->with('notify', $notify);
        } else {
            $this->msg['status'] = 'error';
            $this->msg['message'] = 'Check again! Verification Code Invalid ';
        }
    }

    public function withdrawSubmit(){
        $user = auth()->user();
        $withdraw = $this->withdraw;
        $subject = "Withdrawal Verification Code";
        $message = "
        <p>Here is your verification code for withdrawing your balance:</p>
        <p><strong>{$withdraw->otp}</strong></p>
        <p>Please enter this code on the withdrawal page to complete your transaction.</p>
        <p>Thank you.</p>";
        sendGeneralEmail($user->email, $subject, $message, $user->username);
        $this->activeTab = 'tab3';
    }
}
