<?php

namespace App\Http\Livewire\User;

use App\Models\User;
use App\Models\Country;
use Livewire\Component;
use App\Models\GeneralSetting;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\Hash;
use Illuminate\Support\Facades\Mail;
use App\Mail\RegisterEmailVerification;

class WithoutRefRegisterComponent extends Component
{
    public $username, $user_id, $otp, $tab, $msg, $firstname, $lastname, $email, $password, $personal_pin, $mobile, $country, $country_code;
    protected $rules = [
        'username' => 'required|unique:users,username',
        'personal_pin' => 'required|digits:4',
        'firstname' => 'required',
        'lastname' => 'required',
        'email' => 'required|unique:users,email',
        'password' => 'required',
        'mobile' => 'required|unique:users,mobile',
        'country' => 'required',
    ];
    public function mount()
    {
        $location = geoip()->getLocation($_SERVER['REMOTE_ADDR']);
        // dd($location->country);
        $country  = Country::where('nicename', $location->country)->first();
        $this->country_code = $country->phonecode;
        $this->country = $country->nicename;
        $this->tab = 1;
        // dd($this->country_code);
    }
    public function render()
    {
        return view('livewire.user.without-ref-register-component', [
            'countries' => Country::all(),
            'location' => geoip()->getLocation($_SERVER['REMOTE_ADDR'])
        ]);
    }
    public function register()
    {
        $this->validate();
        $latestUser = User::latest()->first();
        if (blank($latestUser)) {
            $uniqueId = 1111;
        } else {
            $uniqueId = $latestUser->uniqueid + 1;
        }
        $user = User::create([
            'uniqueid' => $uniqueId,
            'plan_id' => 1,
            'username' => $this->username,
            'personal_pin' => $this->personal_pin,
            'firstname' => $this->firstname,
            'lastname' => $this->lastname,
            'email' => $this->email,
            'mobile' => $this->country_code . $this->mobile,
            'country' => $this->country,
            'password' => Hash::make($this->password),
        ]);
        $credentials = [
            'username' => $user->username,
            'password' => $this->password,
        ];
        $gnl = GeneralSetting::first();
        if ($gnl->ev == 1) {
            $randomNumber = mt_rand(1000, 9999);
            $user->update([
                'ver_code' => $randomNumber,
                'ver_code_send_at' => now(),
            ]);
            //Send Mail
            $this->user_id = $user->id;
            $subject = "Verify your email address";
            $message = "Your one-time OTP for verifying your email: <strong>$randomNumber</strong>";
            sendGeneralEmail($user->email, $subject, $message, $user->username);
            $this->msg['status'] = 'success';
            $this->msg['message'] = 'Otp Code Sent In Your Mail';
            $this->tab = 2;
        } else {
            if (Auth::attempt($credentials)) {
                // Authentication passed
                $this->msg['status'] = 'success';
                $this->msg['message'] = 'Register successful';
                // $this->dispatchBrowserEvent('success', ['msg' => 'Register successful']);
                return redirect()->route('user.dashboard');
            } else {
                $this->msg['status'] = 'error';
                $this->msg['message'] = 'Something went wrong';
                // $this->dispatchBrowserEvent('error', ['msg' => 'Something went wrong']);
            }
        }
    }
    public function otpVerify()
    {
        if ($this->otp == null) {
            $this->msg['status'] = 'error';
            $this->msg['message'] = 'Otp Is Required';
        } else {
            $user = User::find($this->user_id);
            if ($user->ver_code == $this->otp) {
                $user->update([
                    'ev' => 1
                ]);
                $credentials = [
                    'username' => $user->username,
                    'password' => $this->password,
                ];
                if (Auth::attempt($credentials)) {
                    // Authentication passed
                    $this->msg['status'] = 'success';
                    $this->msg['message'] = 'Register successful';
                    return redirect()->route('user.dashboard');
                } else {
                    $this->msg['status'] = 'error';
                    $this->msg['message'] = 'Something went wrong';
                }
            }
        }
    }
}
