<?php

namespace App\Http\Livewire;

use App\Models\User;
use App\Models\Deposit;
use Livewire\Component;
use App\Models\GatewayCurrency;

class Diposit extends Component
{
    public $amount;
    public $method_code;
    public $methodId;
    public $currency = 'USD';
    public function mount()
    {
        $this->methodId = 1004;
    }
    public function render()
    {
        return view('livewire.diposit', [
            'methods' => GatewayCurrency::whereHas('method', function ($gate) {
                $gate->where('status', 1);
            })->with('method')->orderby('method_code')->get(),
            'selectedMethod' => GatewayCurrency::where('method_code', $this->methodId)->first(),
        ]);
    }
    public function methodChanged($id)
    {
        $this->methodId = $id;
    }
    public function store()
    {
        $amount = User::currencyToUsd($this->amount);
        if ($this->method_code == "") {
            $this->dispatchBrowserEvent('error', ['message' => 'Please Select A Method']);
        } else if ($this->currency == "") {
            $this->dispatchBrowserEvent('error', ['message' => 'Please Select A Currency']);
        } else {


            $user = auth()->user();
            $gate = GatewayCurrency::where('method_code', $this->method_code)->where('currency', $this->currency)->first();
            if (!$gate) {
                $this->dispatchBrowserEvent('error', ['message' => 'Invalid Gateway']);
            } else if ($gate->min_amount > $amount || $gate->max_amount < $amount) {
                $this->dispatchBrowserEvent('error', ['message' => 'Please Follow Deposit Limit']);
            } else {
                $charge = getAmount($gate->fixed_charge + ($amount * $gate->percent_charge / 100));
                $payable = getAmount($amount + $charge);
                $final_amo = getAmount($payable * $gate->rate);

                $data = new Deposit();
                $data->user_id = $user->id;
                $data->method_code = $gate->method_code;
                $data->method_currency = strtoupper($gate->currency);
                $data->amount = $amount;
                $data->charge = $charge;
                $data->rate = $gate->rate;
                $data->final_amo = getAmount($final_amo);
                $data->btc_amo = 0;
                $data->btc_wallet = "";
                $data->trx = getTrx();
                $data->try = 0;
                $data->status = 0;
                $data->save();
                session()->put('Track', $data['trx']);
                return redirect()->route('user.deposit.preview');
            }
        }
    }
}
