<?php

namespace App\Http\Livewire\User;

use App\Models\User;
use Livewire\Component;
use App\Models\Transaction;
use App\Models\GeneralSetting;
use Illuminate\Support\Facades\Auth;
use App\Mail\BalanceTransferNotification;
use Illuminate\Support\Facades\Mail;

class BalanceTransferComponent extends Component
{
    public $username, $amount, $msg;
    protected $rules = [
        'username' => 'required',
        'amount' => 'required',
    ];
    public function render()
    {
        return view('livewire.user.balance-transfer-component');
    }
    public function transfer()
    {
        $this->validate();
        $amount = User::convertToUsd($this->amount);
        $gnl = GeneralSetting::first();
        $user = User::find(Auth::id());
        $trans_user = User::where('username', $this->username)->orWhere('email', $this->username)->first();
        if ($trans_user == '') {
            // Handle username not found
            $this->msg['status'] = 'error';
            $this->msg['message'] = 'Username Not Found';
        } elseif ($trans_user->username == $user->username || $trans_user->email == $user->email) {
            // Handle transfer not possible in own account
            $this->msg['status'] = 'error';
            $this->msg['message'] = 'Balance Transfer Not Possible In Your Own Account';
        } else {
            // Perform balance transfer
            $charge = $gnl->bal_trans_fixed_charge + (($amount * $gnl->bal_trans_per_charge) / 100);
            $amount = $amount + $charge;
            if ($user->balance >= $amount) {
                $user->balance -= $amount;
                $user->save();

                $trx = getTrx();

                Transaction::create([
                    'trx' => $trx,
                    'user_id' => $user->id,
                    'trx_type' => '-',
                    'remark' => 'balance_transfer',
                    'details' => 'Balance Transferred To ' . $trans_user->username,
                    'amount' => getAmount($amount),
                    'post_balance' => getAmount($user->balance),
                    'charge' => $charge
                ]);

                $trans_user->balance += $amount;
                $trans_user->save();

                Transaction::create([
                    'trx' => $trx,
                    'user_id' => $trans_user->id,
                    'remark' => 'balance_receive',
                    'details' => 'Balance receive From ' . $user->username,
                    'amount' => getAmount($amount),
                    'post_balance' => getAmount($trans_user->balance),
                    'charge' => 0,
                    'trx_type' => '+'
                ]);

                // Send email notification to the balance receiver
                if ($gnl->mail_notification == 1) {
                    $subject = "You have been Received banlance From ".''.$user->username;
                    $message = "<p>Here are the details:</p>
                    <ul>
                        <li><h3><strong>Sender Username:</strong> " . $user->username . "</h3></li><hr>
                        <li><strong>Username:</strong> " . $trans_user->username . "</li>
                        <li><strong>First Name:</strong> " . $trans_user->firstname . "</li>
                        <li><strong>Last Name:</strong> " . $trans_user->lastname . "</li>
                        <li><strong>Amount:</strong> " . User::currency($amount)."</li>
                        <li><strong>Detail:</strong> " . $trx . "</li>
                    </ul>
                    <p>Thank you for referring new users to our platform!</p>";
                    sendGeneralEmail($trans_user->email, $subject, $message, $trans_user->username);
                }

                $this->msg['status'] = 'success';
                $this->msg['message'] = 'Balance Transferred Successfully.';
            } else {
                // Handle insufficient balance
                $this->msg['status'] = 'error';
                $this->msg['message'] = 'Insufficient Balance.';
            }
            $this->reset('username');
        }
    }
}
