<?php

namespace App\Mail;

use Illuminate\Bus\Queueable;
use Illuminate\Contracts\Queue\ShouldQueue;
use Illuminate\Mail\Mailable;
use Illuminate\Queue\SerializesModels;

class BalanceTransferNotification extends Mailable
{
    use Queueable, SerializesModels;

    public $senderName;
    public $amount;
    public $trx;
    public $currency;
    public $senderUsername;

    /**
     * Create a new message instance.
     *
     * @param  string  $senderName
     * @param  float  $amount
     * @param  string  $trx
     * @param  string  $currency
     * @param  string  $senderUsername
     * @return void
     */
    public function __construct($senderName, $amount, $trx, $currency, $senderUsername)
    {
        $this->senderName = $senderName;
        $this->amount = $amount;
        $this->trx = $trx;
        $this->currency = $currency;
        $this->senderUsername = $senderUsername;
    }

    /**
     * Build the message.
     *
     * @return $this
     */
    public function build()
    {
        $subject = 'Balance Transfer Notification';
    
        return $this->subject($subject)
                    ->view('emails.transfer_notification')
                    ->with([
                        'senderName' => $this->senderName,
                        'amount' => $this->amount,
                        'trx' => $this->trx,
                        'currency' => $this->currency,
                        'senderUsername' => $this->senderUsername,
                    ]);
    }
    
}
