<?php

namespace App\Models;

use Illuminate\Support\Facades\DB;
use Illuminate\Support\Facades\Session;
use Illuminate\Support\Facades\Storage;
use Illuminate\Notifications\Notifiable;
use Illuminate\Contracts\Auth\MustVerifyEmail;
use Illuminate\Foundation\Auth\User as Authenticatable;

class User extends Authenticatable
{
    use Notifiable;
    /**
     * The attributes that are mass assignable.
     *
     * @var array
     */

    protected $guarded = ['id'];

    /**
     * The attributes that should be hidden for arrays.
     *
     * @var array
     */
    protected $hidden = [
        'password', 'remember_token',
    ];

    /**
     * The attributes that should be cast to native types.
     *
     * @var array
     */
    protected $casts = [
        'email_verified_at' => 'datetime',
        'address' => 'object',
        'ver_code_send_at' => 'datetime'
    ];

    protected $data = [
        'data' => 1
    ];
    public function getImageUrlAttribute()
    {
        if ($this->image) {
            return Storage::disk('public')->url($this->image);
        }
    }
    public static function countrycode($name)
    {
        $data = DB::table('country')->where('nicename', $name)->first();
        return $data->iso;
    }
    public static function allCurrencyCode()
    {
        return Currency::all();
    }
    public static function currencyCode()
    {
        $sessionCurrency = Session::get('currency');
        if ($sessionCurrency != "") {
            $currency_code = $sessionCurrency;
        } else {
            $currency_code = geoip()->getLocation($_SERVER['REMOTE_ADDR'])->currency;
        }
        if ($currency_code == "") {
            return "USD";
        } else {
            return $currency_code;
        }
    }
    public static function currency($balance)
    {
         $cleanedNumber = str_replace(',', '', $balance);
        $balance = floatval($cleanedNumber); // Use floatval to support decimal values
        $sessionCurrency = Session::get('currency');
        if ($sessionCurrency != "") {
            $currency_code = $sessionCurrency;
        } else {
            $currency_code = geoip()->getLocation($_SERVER['REMOTE_ADDR'])->currency;
        }

        if ($currency_code == "USD") {
            // Format balance with 2 decimal places
        return number_format($balance, 2) . " USD";
        } else {
            $currency = Currency::where('currency_code', $currency_code)->first();
            if ($currency == "") {
                return number_format($balance, 2) . " USD";
            }

            if (is_numeric($balance)) {
                // Calculate the converted balance and format it with 2 decimal places
            $convertedBalance = number_format($balance * $currency->exchange_rate, 2);
            return $convertedBalance . " " . $currency_code;
        } else {
            return "Invalid balance";
        }
    }
}

    public static function convertToUsd($balance)
    {
        $cleanedNumber = str_replace(',', '', $balance);
        $balance = intval($cleanedNumber);
        $sessionCurrency = Session::get('currency');
        // echo  $sessionCurrency;
        if ($sessionCurrency != "") {
            $currency_code = $sessionCurrency;
        } else {
            $currency_code = geoip()->getLocation($_SERVER['REMOTE_ADDR'])->currency;
        }
        if ($currency_code == "USD") {
            return substr($balance, 0, 6);
        } else {
            $currency = Currency::where('currency_code', $currency_code)->first();
            if ($currency == "") {
                return substr($balance, 0, 6);
            }
            return substr($balance, 0, 6) / $currency->exchange_rate;
        }
    }
    public static function currencyToUsd($balance)
    {
         $cleanedNumber = str_replace(',', '', $balance);
        $balance = intval($cleanedNumber);
        $sessionCurrency = Session::get('currency');
        // echo  $sessionCurrency;
        if ($sessionCurrency != "") {
            $currency_code = $sessionCurrency;
        } else {
            $currency_code = geoip()->getLocation($_SERVER['REMOTE_ADDR'])->currency;
        }
        if ($currency_code == "USD") {
            return substr($balance, 0, 6);
        } else {
            $currency = Currency::where('currency_code', $currency_code)->first();
            if ($currency == "") {
                return substr($balance, 0, 6);
            }
            return substr($balance, 0, 6) / $currency->exchange_rate;
        }
    }
    public static function convertToUsdWithCurrency($balance)
    {
        // Remove commas from the balance
        $cleanedNumber = str_replace(',', '', $balance);
        $balance = (float) $cleanedNumber;  // Convert the balance to a float
    
        // Get the currency from the session or geoip
        $sessionCurrency = Session::get('currency');
        $currency_code = $sessionCurrency ? $sessionCurrency : geoip()->getLocation($_SERVER['REMOTE_ADDR'])->currency;
    
        if ($currency_code == "USD") {
            return number_format($balance, 2) . ' USD';  // Format to 2 decimal places and add 'USD'
        } else {
            $currency = Currency::where('currency_code', $currency_code)->first();
    
            if (!$currency) {
                return number_format($balance, 2) . ' USD';  // Default to USD if currency not found
            }
    
            $convertedAmount = $balance * $currency->exchange_rate;  // Convert to the target currency
            return number_format($convertedAmount, 2) . ' ' . $currency_code;  // Format and append currency code
        }
    }
    
    public function login_logs()
    {
        return $this->hasMany(UserLogin::class);
    }

    public function transactions()
    {
                return $this->hasMany(Transaction::class, 'user_id', 'id')->orderBy('id', 'desc');

    }

    public function deposits()
    {
        return $this->hasMany(Deposit::class)->where('status', '!=', 0);
    }

    public function withdrawals()
    {
        return $this->hasMany(Withdrawal::class)->where('status', '!=', 0);
    }

    //mlm
    public function userExtra()
    {
        return $this->hasOne(UserExtra::class);
    }

    public function plan()
    {
        return $this->belongsTo(Plan::class)->withDefault([
            'name' => 'No Plan',
            'refarel_commision' => 0,
        ]);
    }

    public function clicks()
    {
        return $this->hasMany(PtcView::class);
    }


    // SCOPES

    public function getFullnameAttribute()
    {
        return $this->firstname . ' ' . $this->lastname;
    }

    public function scopeActive()
    {
        return $this->where('status', 1);
    }

    public function scopeBanned()
    {
        return $this->where('status', 0);
    }

    public function scopeEmailUnverified()
    {
        return $this->where('ev', 0);
    }

    public function scopeSmsUnverified()
    {
        return $this->where('sv', 0);
    }
    public function scopeEmailVerified()
    {
        return $this->where('ev', 1);
    }

    public function scopeSmsVerified()
    {
        return $this->where('sv', 1);
    }
    public function upline()
    {
        return $this->belongsTo(User::class, 'ref_id', 'id')
            ->withDefault([
                'username' => 'Not Found',
            ]);
    }
    public static function getAddRemaning()
    {
        $viewed = PtcView::where('user_id', auth()->user()->id)->where('vdt', Date('Y-m-d'))->count();
        $count = Ptc::where('status', 1)->where('remain', '>', 0)->where('plan_id', auth()->user()->plan->id)->limit(auth()->user()->plan->daily_ad_limit)->get();
        $ads_count = count($count);
        return $ads_count - $viewed;
    }
}
