@extends('backend.layout.layout')

@section('content')
<div class="container">
    @if(session('success'))
        <div class="alert alert-success">
            {{ session('success') }}
        </div>
    @endif

    @if ($errors->any())
        <div class="alert alert-danger">
            <ul>
                @foreach ($errors->all() as $error)
                    <li>{{ $error }}</li>
                @endforeach
            </ul>
        </div>
    @endif
</div>

<div class="app-main flex-column flex-row-fluid" id="kt_app_main">
    <div class="d-flex flex-column flex-column-fluid">
        <div id="kt_app_toolbar" class="app-toolbar py-3 py-lg-6">
            <div id="kt_app_toolbar_container" class="app-container container-xxl d-flex flex-stack">
                <div class="page-title d-flex flex-column justify-content-center flex-wrap me-3">
                    <h1 class="page-heading d-flex text-dark fw-bold fs-3 flex-column justify-content-center my-0">Cryptocurrencies</h1>
                    <ul class="breadcrumb breadcrumb-separatorless fw-semibold fs-7 my-0 pt-1">
                        <li class="breadcrumb-item text-muted">
                            <a href="{{ route('admin.dashboard') }}" class="text-muted text-hover-primary">Home</a>
                        </li>
                        <li class="breadcrumb-item">
                            <span class="bullet bg-gray-400 w-5px h-2px"></span>
                        </li>
                        <li class="breadcrumb-item text-muted">Cryptocurrencies</li>
                    </ul>
                </div>
                <div class="d-flex align-items-center gap-2 gap-lg-3">
                    <button type="button" class="btn btn-sm fw-bold btn-primary" data-bs-toggle="modal" data-bs-target="#addCurrencyModal">Add Cryptocurrency</button>
                </div>
            </div>
        </div>

        <div id="kt_app_content" class="app-content flex-column-fluid">
            <div id="kt_app_content_container" class="app-container container-xxl">
                <div class="card">
                    <div class="card-body">
                        <table class="table table-striped">
                            <thead>
                                <tr>
                                    <th>#</th>
                                    <th>Name</th>
                                    <th>Code</th>
                                    <th>Exchange Rate</th>
                                    <th>Address</th>
                                    <th>Icon</th>
                                    <th>QR Code</th>
                                    <th>Actions</th>
                                </tr>
                            </thead>
                            <tbody>
                                @foreach($cryptoCurrencies as $cryptoCurrency)
                                    <tr>
                                        <td>{{ $loop->iteration }}</td>
                                        <td>{{ $cryptoCurrency->currency_name }}</td>
                                        <td>{{ $cryptoCurrency->currency_code }}</td>
                                        <td>{{ $cryptoCurrency->exchange_rate }}</td>
                                        <td>{{ $cryptoCurrency->address }}</td>
                                        <td><img src="{{ asset('storage/' . $cryptoCurrency->currency_icon) }}" alt="icon" width="50"></td>
                                        <td><img src="{{ asset('storage/' . $cryptoCurrency->currency_qr_code) }}" alt="qr code" width="50"></td>
                                        <td>
                                            <button type="button" class="btn btn-sm btn-warning" data-bs-toggle="modal" data-bs-target="#editCurrencyModal{{ $cryptoCurrency->id }}">Edit</button>
                                            <button type="button" class="btn btn-sm btn-danger" data-bs-toggle="modal" data-bs-target="#deleteCurrencyModal{{ $cryptoCurrency->id }}">Delete</button>
                                        </td>
                                    </tr>

                                    <!-- Edit Modal -->
                                    <div class="modal fade" id="editCurrencyModal{{ $cryptoCurrency->id }}" tabindex="-1" aria-labelledby="editCurrencyModalLabel{{ $cryptoCurrency->id }}" aria-hidden="true">
                                        <div class="modal-dialog">
                                            <div class="modal-content">
                                                <div class="modal-header">
                                                    <h5 class="modal-title" id="editCurrencyModalLabel{{ $cryptoCurrency->id }}">Edit Cryptocurrency</h5>
                                                    <button type="button" class="btn-close" data-bs-dismiss="modal" aria-label="Close"></button>
                                                </div>
                                                <form action="{{ route('admin.crypto-currencies.update', $cryptoCurrency) }}" method="POST" enctype="multipart/form-data">
                                                    @csrf
                                                    @method('PUT')
                                                    <div class="modal-body">
                                                        <div class="mb-3">
                                                            <label for="currency_name" class="form-label">Currency Name</label>
                                                            <input type="text" class="form-control" id="currency_name" name="currency_name" value="{{ $cryptoCurrency->currency_name }}" required>
                                                        </div>
                                                        <div class="mb-3">
                                                            <label for="currency_code" class="form-label">Currency Code</label>
                                                            <input type="text" class="form-control" id="currency_code" name="currency_code" value="{{ $cryptoCurrency->currency_code }}" required>
                                                        </div>
                                                        <div class="mb-3">
                                                            <label for="exchange_rate" class="form-label">Exchange Rate == (USDT)</label>
                                                            <input type="number" step="0.00000001" class="form-control" id="exchange_rate" name="exchange_rate" value="{{ $cryptoCurrency->exchange_rate }}" required>
                                                        </div>
                                                        <div class="mb-3">
                                                            <label for="address" class="form-label">Address</label>
                                                            <input type="text" class="form-control" id="address" name="address" value="{{ $cryptoCurrency->address }}" required>
                                                        </div>
                                                        <div class="mb-3">
                                                            <label for="currency_icon" class="form-label">Currency Icon</label>
                                                            <input type="file" class="form-control" id="currency_icon" name="currency_icon">
                                                        </div>
                                                        <div class="mb-3">
                                                            <label for="currency_qr_code" class="form-label">Currency QR Code</label>
                                                            <input type="file" class="form-control" id="currency_qr_code" name="currency_qr_code">
                                                        </div>
                                                    </div>
                                                    <div class="modal-footer">
                                                        <button type="button" class="btn btn-secondary" data-bs-dismiss="modal">Close</button>
                                                        <button type="submit" class="btn btn-primary">Save changes</button>
                                                    </div>
                                                </form>
                                            </div>
                                        </div>
                                    </div>

                                    <!-- Delete Modal -->
                                    <div class="modal fade" id="deleteCurrencyModal{{ $cryptoCurrency->id }}" tabindex="-1" aria-labelledby="deleteCurrencyModalLabel{{ $cryptoCurrency->id }}" aria-hidden="true">
                                        <div class="modal-dialog">
                                            <div class="modal-content">
                                                <div class="modal-header">
                                                    <h5 class="modal-title" id="deleteCurrencyModalLabel{{ $cryptoCurrency->id }}">Delete Cryptocurrency</h5>
                                                    <button type="button" class="btn-close" data-bs-dismiss="modal" aria-label="Close"></button>
                                                </div>
                                                <div class="modal-body">
                                                    Are you sure you want to delete this cryptocurrency?
                                                </div>
                                                <div class="modal-footer">
                                                    <form action="{{ route('admin.crypto-currencies.destroy', $cryptoCurrency) }}" method="POST">
                                                        @csrf
                                                        @method('DELETE')
                                                        <button type="button" class="btn btn-secondary" data-bs-dismiss="modal">Close</button>
                                                        <button type="submit" class="btn btn-danger">Delete</button>
                                                    </form>
                                                </div>
                                            </div>
                                        </div>
                                    </div>
                                @endforeach
                            </tbody>
                        </table>
                    </div>
                </div>
            </div>
        </div>
    </div>
</div>

<!-- Add Modal -->
<div class="modal fade" id="addCurrencyModal" tabindex="-1" aria-labelledby="addCurrencyModalLabel" aria-hidden="true">
    <div class="modal-dialog">
        <div class="modal-content">
            <div class="modal-header">
                <h5 class="modal-title" id="addCurrencyModalLabel">Add Cryptocurrency</h5>
                <button type="button" class="btn-close" data-bs-dismiss="modal" aria-label="Close"></button>
            </div>
            <form action="{{ route('admin.crypto-currencies.store') }}" method="POST" enctype="multipart/form-data">
                @csrf
                <div class="modal-body">
                    <div class="mb-3">
                        <label for="currency_name" class="form-label">Currency Name</label>
                        <input type="text" class="form-control" id="currency_name" name="currency_name" required>
                    </div>
                    <div class="mb-3">
                        <label for="currency_code" class="form-label">Currency Code</label>
                        <input type="text" class="form-control" id="currency_code" name="currency_code" required>
                    </div>
                    <div class="mb-3">
                        <label for="exchange_rate" class="form-label">Exchange Rate == (USDT)</label>
                        <input type="number" step="0.00000001" class="form-control" id="exchange_rate" name="exchange_rate" required>
                    </div>
                    <div class="mb-3">
                        <label for="address" class="form-label">Address</label>
                        <input type="text" class="form-control" id="address" name="address" required>
                    </div>
                    <div class="mb-3">
                        <label for="currency_icon" class="form-label">Currency Icon</label>
                        <input type="file" class="form-control" id="currency_icon" name="currency_icon">
                    </div>
                    <div class="mb-3">
                        <label for="currency_qr_code" class="form-label">Currency QR Code</label>
                        <input type="file" class="form-control" id="currency_qr_code" name="currency_qr_code">
                    </div>
                </div>
                <div class="modal-footer">
                    <button type="button" class="btn btn-secondary" data-bs-dismiss="modal">Close</button>
                    <button type="submit" class="btn btn-primary">Add Cryptocurrency</button>
                </div>
            </form>
        </div>
    </div>
</div>

@endsection