<?php

use App\Http\Controllers\Gateway\PaymentController;
use App\Http\Controllers\User\UserController;
use App\Http\Controllers\PtcController;
use App\Http\Controllers\User\WithdrawController;
use Illuminate\Support\Facades\Route;

/*
|--------------------------------------------------------------------------
| Start Admin Area
|--------------------------------------------------------------------------
*/
Route::post('/deposit/post', [UserController::class, 'depositPost'])->name('user.deposit.post');

Route::get('reminder-session', function(){
    session()->put('displayReminder', false);
    return back();
})->name('reminder.session');

Route::get('expire-session', function() {
    session()->forget('displayExpire');
    session()->forget('displayExpireTime');
    return back();
})->name('expire.session');



Route::group(['prefix' => 'user', 'as' => 'user.', 'middleware' => ['auth']], function () {
    Route::get('/dashboard.aspx', [UserController::class, 'dashboard'])->name('dashboard');
    Route::get('/proofs.aspx', [UserController::class, 'proofs'])->name('proofs');

    Route::get('plan.aspx', [UserController::class, 'planList'])->name('plan.list');

    //Deposit Route
    Route::get('deposit.aspx', [UserController::class, 'deposit'])->name('deposit');
    Route::get('deposit/confirm.aspx', [PaymentController::class, 'depositConfirm'])->name('deposit.confirm');

    Route::get('deposit/crypto/select-crypto.aspx', [PaymentController::class, 'manualCryptoConfirm'])->name('deposit.crypto.confirm');
    Route::post('deposit/crypto/paynow.aspx', [PaymentController::class, 'manualCryptoPaynow'])->name('deposit.crypto.paynow');
    
    Route::get('deposit/manual/confirm.aspx', [PaymentController::class, 'manualDepositConfirm'])->name('deposit.manual.confirm');
    Route::get('deposit/crypto-success.aspx', [PaymentController::class, 'cryptoSuccess'])->name('deposit.crypto.success');
    
    Route::post('manual-deposit-confirm', [UserController::class, 'manualDepositUpdate'])->name('deposit.manual.update');
    //Deposit Voucher
    Route::get('deposit-voucher.aspx', [UserController::class, 'depositVoucher'])->name('deposit.voucher');
    Route::get('use-voucher.aspx', [UserController::class, 'useVoucher'])->name('voucher.use');
    Route::post('/voucher/use/store', [UserController::class, 'useStore'])->name('voucher.use.store');
    Route::get('deposit/history.aspx', [UserController::class, 'depositLog'])->name('deposit.history');
    //Withdraw Route
    Route::get('/withdraw.aspx', [WithdrawController::class, 'withdrawMoney'])->name('withdraw');
    Route::post('/withdraw', [WithdrawController::class, 'withdrawStore'])->name('withdraw.money');
    Route::get('/withdraw/verify.aspx', [WithdrawController::class, 'withdrawVerify'])->name('withdraw.verify');
    Route::post('/withdraw/verify', [WithdrawController::class, 'withdrawVerifySubmit'])->name('withdraw.verify.submit');
    Route::get('/withdraw/preview.aspx', [WithdrawController::class, 'withdrawPreview'])->name('withdraw.preview');
    Route::post('/withdraw/preview', [WithdrawController::class, 'withdrawSubmit'])->name('withdraw.submit');
    Route::get('/withdraw/history.aspx', [WithdrawController::class, 'withdrawLog'])->name('withdraw.history');


    Route::get('/watch2earn.aspx', [UserController::class, 'watch2earn'])->name('watch2earn');
    Route::get('earn-show/{hash}.aspx', [UserController::class, 'show'])->name('ptc.show');
    Route::post('earn-confirm', [UserController::class, 'ptcConfirm'])->name('ptc.confirm');
    Route::get('add/reaction/{ptcId}', [UserController::class, 'addReaction'])->name('ptc.add.reaction');
    Route::post('add/comment', [UserController::class, 'addComment'])->name('ptc.add.comment');

    //Direct Refarel
    Route::get('/direct-refarel.aspx', [UserController::class, 'directRefarel'])->name('direct.refarel');
    Route::get('/reffer/promo-materials.aspx', [UserController::class, 'promoMaterials'])->name('refarel.promo');

    //Deposit Voucher Distributor
    Route::get('/deposit-voucher-distributor.aspx', [UserController::class, 'depositVoucherDistributor'])->name('depositvoucherdistributor');
    Route::get('/agent/{country}', [UserController::class, 'agentByCountry'])->name('agent.country');

    Route::get('apply-for-agent.aspx', [UserController::class, 'applyForAgent'])->name('applyforagent');

    //Transcation Log
    Route::get('transcation/log.aspx', [UserController::class, 'transcationLog'])->name('transcation.log');
    Route::get('transfer.aspx', [UserController::class, 'transfer'])->name('transfer');
    Route::get('statistics.aspx', [UserController::class, 'Statistics'])->name('statistics');
    Route::get('profile.aspx', [UserController::class, 'profile'])->name('profile');
    Route::get('setting.aspx', [UserController::class, 'settings'])->name('settings');
    Route::get('logout', [UserController::class, 'logout'])->name('logout');
});




// Route::name('user.')->prefix('user')->group(function () {
//     Route::middleware('auth')->group(function () {
//         Route::get('authorization', 'AuthorizationController@authorizeForm')->name('authorization');
//         Route::get('resend-verify', 'AuthorizationController@sendVerifyCode')->name('send_verify_code');
//         Route::post('verify-email', 'AuthorizationController@emailVerification')->name('verify_email');
//         Route::post('verify-sms', 'AuthorizationController@smsVerification')->name('verify_sms');
//         Route::post('verify-g2fa', 'AuthorizationController@g2faVerification')->name('go2fa.verify');

//         Route::middleware(['checkStatus'])->group(function () {
//             Route::get('dashboard', 'UserController@home')->name('home');
//             Route::post('balancetransfer', 'UserController@balTransfer')->name('balanceTransfer');
//             Route::get('profile', 'UserController@view')->name('view');
//             Route::get('profile-setting', 'UserController@profile')->name('profile-setting');
//             Route::post('profile-setting', 'UserController@submitProfile')->name('profile-update');
//             Route::get('change-password', 'UserController@changePassword')->name('change-password');
//             Route::post('change-password', 'UserController@submitPassword')->name('password-update');
//             Route::get('invite', 'UserController@invite')->name('invite');
//             Route::get('statistics', 'UserController@Statistics')->name('statistics');

//             //2FA
//             Route::get('twofactor', 'UserController@show2faForm')->name('twofactor');
//             Route::post('twofactor/enable', 'UserController@create2fa')->name('twofactor.enable');
//             Route::post('twofactor/disable', 'UserController@disable2fa')->name('twofactor.disable');
//             Route::get('login/history', 'UserController@userLoginHistory')->name('login.history');


//             //plan
//             Route::get('/plan', 'PlanController@planIndex')->name('plan.index');
//             Route::get('/upgrade', 'PlanController@upgradIndex')->name('upgrad.index');
//             Route::post('/plan-upgrade', 'PlanController@planUpgrade')->name('plan.upgrade');
//             Route::post('/plan', 'PlanController@planStore')->name('plan.purchase');
//             Route::post('/plan-gatewaye', 'PlanController@planStoreGatewaye')->name('plan.purchasebyGatewaye');
//             Route::get('/referral-log', 'UserController@referralCom')->name('referral.log');

//             Route::get('/binary-log', 'PlanController@binaryCom')->name('binary.log');
//             Route::get('/binary-summery', 'PlanController@binarySummery')->name('binary.summery');
//             Route::get('/bv-log', 'PlanController@bvlog')->name('bv.log');
//             Route::get('/referrals', 'PlanController@myRefLog')->name('my.ref');
//             Route::get('/tree', 'PlanController@myTree')->name('my.tree');
//             Route::get('/tree/{user}', 'PlanController@otherTree')->name('other.tree');
//             Route::get('/tree/search', 'PlanController@otherTree')->name('other.tree.search');

//             //balance transfer
//             Route::get('/transfer', 'UserController@indexTransfer')->name('balance.transfer');
//             Route::post('/transfer', 'UserController@balanceTransfer')->name('balance.transfer.post');
//             Route::post('/search-user', 'UserController@searchUser')->name('search.user');

//             //voucher create
//             Route::get('/voucher/create', 'VoucherController@index')->name('index.voucher');
//             Route::post('/voucher/store', 'VoucherController@store')->name('voucher.store');
//             Route::post('/voucher/send', 'VoucherController@sendVoucher')->name('voucher.send');
//             Route::delete('/voucher/delete/{id}', 'VoucherController@destroy')->name('voucher.delete');
//             Route::delete('/vouchers/delete/{id}', 'VoucherController@notUseDestroy')->name('voucher.notuse.delete');


//             //voucher Use
//             Route::middleware('vouchercheck')->group(function () {


//                 Route::get('/voucher/use', 'VoucherController@useIndex')->name('use.voucher');
//                 Route::post('/voucher/use/store', 'VoucherController@useStore')->name('voucher.use.store');
//                 Route::delete('/voucher/delete/{id}', 'VoucherController@destroy')->name('voucher.delete');
//             });

//             //Make Agent
//             Route::get('/all/agent', 'AgentController@userIndex')->name('all.agent');
//             Route::get('/agent/{country}', 'AgentController@agentByCountry')->name('agent.country');
//             Route::get('/request/agent', 'AgentController@create')->name('agent.form');
//             Route::post('/make/agent', 'AgentController@store')->name('make.agent');
//             Route::get('/agent/cancel/', 'AgentController@update')->name('cancel.agent');

//             //PTC
//             Route::get('earn', 'PtcController@index')->name('ptc.index');
//             Route::get('earn-show/{hash}', 'PtcController@show')->name('ptc.show');
//             Route::get('add/reaction/{ptcId}', 'PtcController@addReaction')->name('ptc.add.reaction');
//             Route::post('add/comment', 'PtcController@addComment')->name('ptc.add.comment');
//             Route::post('earn-confirm', 'PtcController@confirm')->name('ptc.confirm');
//             Route::get('earn-clicks', 'PtcController@clicks')->name('ptc.clicks');


//             //Report
//             Route::get('report/deposit/log', 'UserReportController@depositHistory')->name('report.deposit');
//             Route::get('report/invest/log', 'UserReportController@investLog')->name('report.invest');
//             Route::get('report/transactions/log', 'UserReportController@transactions')->name('report.transactions');
//             Route::get('report/withdraw/log', 'UserReportController@withdrawLog')->name('report.withdraw');
//             Route::get('report/referral/commission', 'UserReportController@refCom')->name('report.refCom');
//             Route::get('report/binary/commission', 'UserReportController@binaryCom')->name('report.binaryCom');



//             // Deposit
//             Route::any('/deposit', 'Gateway\PaymentController@deposit')->name('deposit');
//             Route::post('deposit/insert', 'Gateway\PaymentController@depositInsert')->name('deposit.insert');
//             Route::get('deposit/preview', 'Gateway\PaymentController@depositPreview')->name('deposit.preview');
//             Route::get('deposit/confirm', 'Gateway\PaymentController@depositConfirm')->name('deposit.confirm');
//             Route::get('deposit/manual', 'Gateway\PaymentController@manualDepositConfirm')->name('deposit.manual.confirm');
//             Route::post('deposit/manual', 'Gateway\PaymentController@manualDepositUpdate')->name('deposit.manual.update');
//             Route::get('deposit/history', 'UserController@depositHistory')->name('deposit.history');

//             // Withdraw
//             Route::get('/withdraw', 'UserController@withdrawMoney')->name('withdraw');
//             Route::post('/withdraw', 'UserController@withdrawStore')->name('withdraw.money');
//             Route::get('/withdraw/verify', 'UserController@withdrawVerify')->name('withdraw.verify');
//             Route::post('/withdraw/verify', 'UserController@withdrawVerifySubmit')->name('withdraw.verify.submit');
//             Route::get('/withdraw/preview', 'UserController@withdrawPreview')->name('withdraw.preview');
//             Route::post('/withdraw/preview', 'UserController@withdrawSubmit')->name('withdraw.submit');
//             Route::get('/withdraw/history', 'UserController@withdrawLog')->name('withdraw.history');
//         });
//     });
// });
    Route::name('user.')->group(function () {
    Route::get('plan-redirect', function () {
            return view('plan-redirect');
        })->name('planredirect');
    
    Route::get('deposit-redirect', function () {
        return view('deposit_redirect');
    })->name('depositredirect');
    Route::get('deposit-redirect', function () {
        return view('deposit_cancle');
    })->name('depositcancle');
    
    Route::get('/login.aspx', [UserController::class, 'login'])->name('login');
    Route::get('logout.aspx', 'Auth\LoginController@logout')->name('logout');

    Route::get('register/without/referral.aspx', [UserController::class, 'showWithoutRefRegistrationForm'])->name('without.ref.register');
    Route::post('register/without/referral', 'Auth\RegisterController@withoutRefRegister')->middleware('regStatus');
    Route::get('register.aspx', [UserController::class, 'register'])->name('register');
    
    Route::get('newconfig', [PtcController::class, 'newconfig']);
    
    // Route::post('register', 'Auth\RegisterController@register')->middleware('regStatus');

    Route::get('password/reset.aspx', 'Auth\ForgotPasswordController@showLinkRequestForm')->name('password.request');
    Route::post('password/email', 'Auth\ForgotPasswordController@sendResetLinkEmail')->name('password.email');
    Route::get('password/code-verify.aspx', 'Auth\ForgotPasswordController@codeVerify')->name('password.code_verify');
    Route::post('password/reset', 'Auth\ResetPasswordController@reset')->name('password.update');
    Route::get('password/reset/{token}.aspx', 'Auth\ResetPasswordController@showResetForm')->name('password.reset');
    Route::post('password/verify-code', 'Auth\ForgotPasswordController@verifyCode')->name('password.verify-code');
});
Route::namespace('Gateway')->prefix('ipn')->name('ipn.')->group(function () {
    Route::post('paypal', 'paypal\ProcessController@ipn')->name('paypal');
    Route::get('paypal_sdk', 'paypal_sdk\ProcessController@ipn')->name('paypal_sdk');
    Route::post('perfect_money', 'perfect_money\ProcessController@ipn')->name('perfect_money');
    Route::post('stripe', 'stripe\ProcessController@ipn')->name('stripe');
    Route::post('stripe_js', 'stripe_js\ProcessController@ipn')->name('stripe_js');
    Route::post('stripe_v3', 'stripe_v3\ProcessController@ipn')->name('stripe_v3');
    Route::post('skrill', 'skrill\ProcessController@ipn')->name('skrill');
    Route::post('paytm', 'paytm\ProcessController@ipn')->name('paytm');
    Route::post('payeer', 'payeer\ProcessController@ipn')->name('payeer');
    Route::post('paystack', 'paystack\ProcessController@ipn')->name('paystack');
    Route::post('voguepay', 'voguepay\ProcessController@ipn')->name('voguepay');
    Route::get('flutterwave/{trx}/{type}', 'flutterwave\ProcessController@ipn')->name('flutterwave');
    Route::post('razorpay', 'razorpay\ProcessController@ipn')->name('razorpay');
    Route::post('instamojo', 'instamojo\ProcessController@ipn')->name('instamojo');
    Route::get('blockchain', 'blockchain\ProcessController@ipn')->name('blockchain');
    Route::get('blockio', 'blockio\ProcessController@ipn')->name('blockio');
    Route::post('coinpayments', 'coinpayments\ProcessController@ipn')->name('coinpayments');
    Route::post('coinpayments_fiat', 'coinpayments_fiat\ProcessController@ipn')->name('coinpayments_fiat');
    Route::post('coingate', 'coingate\ProcessController@ipn')->name('coingate');
    Route::post('coinbase_commerce', 'coinbase_commerce\ProcessController@ipn')->name('coinbase_commerce');
    Route::get('mollie', 'mollie\ProcessController@ipn')->name('mollie');
    Route::post('cashmaal', 'cashmaal\ProcessController@ipn')->name('cashmaal');
});
